@@ -40,6 +40,7 @@
  */
 
 /* revision history:
+ * gimp    2.1.0a;  2004/09/25  hof: gap_arr_create_vindex_permission
  * gimp    1.3.20a; 2003/09/29  hof: gap_arr_overwrite_file_dialog
  * gimp    1.3.16b; 2003/07/04  hof: new gap_arr_confirm_dialog
  * gimp    1.3.14a; 2003/05/15  hof: new GAP_ARR_WGT_FONTSEL
@@ -59,6 +60,7 @@
 /* GIMP includes */
 #include "gtk/gtk.h"
 #include "libgimp/gimp.h"
+#include "libgimp/gimpui.h"
 
 typedef enum
 {
@@ -78,6 +80,7 @@ typedef enum
   ,GAP_ARR_WGT_OPT_ENTRY
   ,GAP_ARR_WGT_DEFAULT_BUTTON
   ,GAP_ARR_WGT_FONTSEL       
+  ,GAP_ARR_WGT_HELP_BUTTON
 } GapArrWidget;
 
 typedef int (*t_action_func) ( gpointer action_data);
@@ -91,8 +94,10 @@ typedef struct {
   GapArrWidget widget_type;
 
   /* common fields for all widget types */
-  char    *label_txt;
-  char    *help_txt;
+  const char    *label_txt;
+  const char    *help_txt;  /* help for tooltips */
+  const char    *help_id;   /* help_id for the help page that should be displayed via help button */
+  GimpHelpFunc   help_func;
   gint     entry_width;  /* for all Widgets with  an entry */
   gint     scale_width;  /* for the Widgets with a scale */
   gint     constraint;   /* TRUE: check for min/max values */
@@ -138,7 +143,7 @@ typedef struct {
   GtkWidget  *text_filesel; /* for private (arr_dialog.c) use only */
   GtkWidget  *text_entry;   /* for private (arr_dialog.c) use only */
   GtkWidget  *check_button;   /* for private (arr_dialog.c) use only */
-  GtkWidget  *option_menu;    /* for private (arr_dialog.c) use only */
+  GtkWidget  *combo;          /* for private (arr_dialog.c) use only */
   GtkObject  *adjustment;     /* for private (arr_dialog.c) use only */
   gpointer    radiogroup;     /* for private (arr_dialog.c) use only */
 
@@ -164,38 +169,45 @@ typedef struct {
 void     gap_arr_arg_init  (GapArrArg *arr_ptr,
                           gint       widget_type);
  
-gint     gap_arr_ok_cancel_dialog  (char     *title_txt,
-                          char     *frame_txt,
+gint     gap_arr_ok_cancel_dialog  (const char     *title_txt,
+                          const char     *frame_txt,
                           int       argc,
                           GapArrArg argv[]);
 
-long     gap_arr_slider_dialog(char *title_txt,
-                         char *frame_txt,
-                         char *label_txt,
-                         char *tooltip_txt,
-                         long min, long max, long curr, long constraint);
+long     gap_arr_slider_dialog(const char *title_txt,
+                         const char *frame_txt,
+                         const char *label_txt,
+                         const char *tooltip_txt,
+                         long min, long max, long curr, long constraint,
+                         const char *help_id);
 
 
 
-gint     gap_arr_buttons_dialog (char *title_txt,
-                         char *frame_txt,
+gint     gap_arr_buttons_dialog (const char *title_txt,
+                         const char *frame_txt,
                          int        b_argc,
                          GapArrButtonArg  b_argv[],
                          gint       b_def_val);
 
 
-gint     gap_arr_std_dialog  (char     *title_txt,
-                          char     *frame_txt,
+gint     gap_arr_std_dialog  (const char     *title_txt,
+                          const char     *frame_txt,
                           int       argc,
                           GapArrArg argv[],
                           int       b_argc,
                           GapArrButtonArg b_argv[],
                           gint      b_def_val);
 
-gboolean gap_arr_confirm_dialog(char *msg_txt, char *title_txt, char *frame_txt);
+gboolean gap_arr_confirm_dialog(const char *msg_txt, const char *title_txt, const char *frame_txt);
 
 gboolean gap_arr_overwrite_file_dialog(const char *filename);
 
-void gap_arr_msg_win(GimpRunMode run_mode, char *msg);
+void gap_arr_msg_win(GimpRunMode run_mode, const char *msg);
+void gap_arr_msg_popup(GimpRunMode run_mode, const char *msg);
+
+gboolean gap_arr_create_vindex_permission(const char *videofile
+      , const char *vindex_file
+      , gint32 seek_status
+      );
 
 #endif
