@@ -35,11 +35,12 @@
  */
 
 /* SYTEM (UNIX) includes */
-#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <errno.h>
 
+#include <glib/gstdio.h>
+
 /* GIMP includes */
 #include "gtk/gtk.h"
 #include "libgimp/gimp.h"
@@ -50,13 +51,14 @@
 #include "config.h"
 #include "gap-intl.h"
 #include "gap_lib.h"
-#include "gap_vin.h"
+#include "gap_val_file.h"
 #include "gap_filter.h"
 #include "gap_filter_pdb.h"
+#include "gap_fmac_name.h"
+#include "gap_fmac_base.h"
 #include "gap_dbbrowser_utils.h"
 #include "gap_lastvaldesc.h"
-
-static char *gap_fmac_version = "2.1.0; 2004/11/12";
+#include "gap_fmac_context.h"
 
 /* revision history:
  * gimp   1.3.26b;  2004/02/29  hof: bugfix NONINTERACTIVE call did crash
@@ -64,7 +66,8 @@ static char *gap_fmac_version = "2.1.0; 2004/11/12";
  * gimp   1.3.22b;  2003/11/09  hof: created (based on old unpublished patches for gimp-1.2)
  */
 
-#define PLUG_IN_NAME_FMAC            "plug_in_filter_macro"
+
+/* from gap_fmac_name.h: GAP_FMACNAME_PLUG_IN_NAME_FMAC */
 #define HELP_ID_NAME_FMAC            "plug-in-filter-macro"
 #define GAP_DB_BROWSER_FMAC_HELP_ID  "gap-filtermacro-db-browser"
 
@@ -127,6 +130,7 @@ static void  p_setbutton_sensitivity(fmac_globalparams_t *gpp);
 static gboolean  p_chk_filtermacro_file(const char *filtermacro_file);
 static void      p_print_and_free_msg(char *msg, GimpRunMode run_mode);
 static gchar *   p_get_gap_filter_data_string(const char *plugin_name);
+static gchar *   p_get_mapped_gap_filter_data_string(const char *plugin_name, const char *filtermacro_file);
 static gint      p_fmac_add_filter_to_file(const char *filtermacro_file, const char *plugin_name);
 static gint      p_fmac_add_filter(const char *filtermacro_file, gint32 image_id);
 static int       p_fmac_pdb_constraint_proc(gchar *proc_name, gint32 image_id);
@@ -134,20 +138,15 @@ static int       p_fmac_pdb_constraint_proc_sel1(gchar *proc_name, gint32 image_
 static int       p_fmac_pdb_constraint_proc_sel2(gchar *proc_name, gint32 image_id);
 
 
-gint             p_fmac_execute(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id, const char *filtermacro_file);
-gint             gap_fmac_execute(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id, const char *filtermacro_file);
-
-
-
 /* ############################################################# */
 
 
 static void query(void);
 static void run(const gchar *name
               , gint n_params
-	      , const GimpParam *param
+              , const GimpParam *param
               , gint *nreturn_vals
-	      , GimpParam **return_vals);
+              , GimpParam **return_vals);
 
 GimpPlugInInfo PLUG_IN_INFO =
 {
@@ -185,35 +184,36 @@ query ()
   gimp_plugin_domain_register (GETTEXT_PACKAGE, LOCALEDIR);
 
   /* registration for last values buffer structure (useful for animated filter apply) */
-  gimp_lastval_desc_register(PLUG_IN_NAME_FMAC,
+  gimp_lastval_desc_register(GAP_FMACNAME_PLUG_IN_NAME_FMAC,
                              &filtermacro_file[0],
                              sizeof(filtermacro_file),
                              G_N_ELEMENTS (lastvals),
                              lastvals);
 
-  gimp_install_procedure(PLUG_IN_NAME_FMAC,
-			 "This plug-in can create and execute filtermacro scriptfiles",
-			 "This plug-in allows the user to pick one or more filters "
-			 "that have already been called before in the current Gimp session. "
-			 "The internal PDB-name of the picked filter is stored in a "
+  gimp_install_procedure(GAP_FMACNAME_PLUG_IN_NAME_FMAC,
+                         "This plug-in can create and execute filtermacro scriptfiles",
+                         "This plug-in allows the user to pick one or more filters "
+                         "that have already been called before in the current Gimp session. "
+                         "The internal PDB-name of the picked filter is stored in a "
                          "filtermacro scriptfile, along with the parameter buffer that was "
                          "used at the last call.\n"
-			 "You can execute a filtermacro scriptfile on the Input drawable "
-			 "(in the current or in any further Gimp session). "
-			 "The non-interactive API is limited to filtermacro script execution "
-			 "and does not allow creation or modification of filtermacro scripts "
-			 "WARNING: filtermacro scriptfiles are a temporary solution. "
-			 "They are machine dependent. Support may be dropped in future gimp "
+                         "You can execute a filtermacro scriptfile on the Input drawable "
+                         "(in the current or in any further Gimp session). "
+                         "The non-interactive API is limited to filtermacro script execution "
+                         "and does not allow creation or modification of filtermacro scripts "
+                         "WARNING: filtermacro scriptfiles are a temporary solution. "
+                         "They are machine dependent. Support may be dropped in future gimp "
                          "versions.",
-			 "Wolfgang Hofer (hof@gimp.org)",
-			 "Wolfgang Hofer",
-			 gap_fmac_version,
-			 N_("<Image>/Filters/Filtermacro..."),
-			 "RGB*, INDEXED*, GRAY*",
-			 GIMP_PLUGIN,
-			 G_N_ELEMENTS (args_fmac_dialog), nreturn_vals,
-			 args_fmac_dialog, return_vals);
+                         "Wolfgang Hofer (hof@gimp.org)",
+                         "Wolfgang Hofer",
+                         GAP_VERSION_WITH_DATE,
+                         N_("Filtermacro..."),
+                         "RGB*, INDEXED*, GRAY*",
+                         GIMP_PLUGIN,
+                         G_N_ELEMENTS (args_fmac_dialog), nreturn_vals,
+                         args_fmac_dialog, return_vals);
 
+  gimp_plugin_menu_register (GAP_FMACNAME_PLUG_IN_NAME_FMAC, N_("<Image>/Filters/"));
 }  /* end query */
 
 
@@ -255,7 +255,7 @@ run(const gchar *name
 
   if(gap_debug) fprintf(stderr, "\n\ngap_filter_main: debug name = %s\n", name);
 
-  if (strcmp (name, PLUG_IN_NAME_FMAC) == 0)
+  if (strcmp (name, GAP_FMACNAME_PLUG_IN_NAME_FMAC) == 0)
   {
       if (run_mode == GIMP_RUN_INTERACTIVE)
       {
@@ -263,41 +263,46 @@ run(const gchar *name
       }
       else
       {
-	if (run_mode == GIMP_RUN_NONINTERACTIVE)
-	{
-	  if(n_params == 4)
-	  {
-	    filtermacro_file = param[3].data.d_string;
-	    if(filtermacro_file == NULL)
-	    {
+        if (run_mode == GIMP_RUN_NONINTERACTIVE)
+        {
+          if(n_params == 4)
+          {
+            filtermacro_file = param[3].data.d_string;
+            if(filtermacro_file == NULL)
+            {
               status = GIMP_PDB_CALLING_ERROR;
-	    }
-	  }
-	  else
-	  {
+            }
+          }
+          else
+          {
             status = GIMP_PDB_CALLING_ERROR;
-	  }
-	}
-	else
-	{
-	  gint l_len;
+          }
+        }
+        else
+        {
+          gint l_len;
 
-	  l_len = gimp_get_data_size(PLUG_IN_NAME_FMAC);
-	  if(l_len > 0)
-	  {
-	    filtermacro_file = g_malloc0(l_len);
-	    gimp_get_data(PLUG_IN_NAME_FMAC, filtermacro_file);
-	  }
-	  else
-	  {
-	    filtermacro_file = g_strdup("\0");
-	  }
-	}
+          l_len = gimp_get_data_size(GAP_FMACNAME_PLUG_IN_NAME_FMAC);
+          if(l_len > 0)
+          {
+            filtermacro_file = g_malloc0(l_len);
+            gimp_get_data(GAP_FMACNAME_PLUG_IN_NAME_FMAC, filtermacro_file);
+          }
+          else
+          {
+            filtermacro_file = g_strdup("\0");
+          }
+        }
 
-	if(status == GIMP_PDB_SUCCESS)
-	{
-          l_rc = gap_fmac_execute(run_mode, image_id, drawable_id, filtermacro_file);
-	}
+        if(status == GIMP_PDB_SUCCESS)
+        {
+          l_rc = gap_fmac_execute(run_mode, image_id, drawable_id
+                   , filtermacro_file
+                   , NULL  /* filtermacro_file2 */
+                   , 1.0   /* current_step */
+                   , 1     /* total_steps */
+                   );
+        }
       }
   }
   else
@@ -334,7 +339,7 @@ p_chk_filtermacro_file(const char *filtermacro_file)
 
   l_buf[0] = '\0';
   l_rc = FALSE;
-  l_fp = fopen(filtermacro_file, "r");
+  l_fp = g_fopen(filtermacro_file, "r");
   if (l_fp)
   {
     /* file exists, check for header */
@@ -395,7 +400,10 @@ p_get_gap_filter_data_string(const char *plugin_name)
   plugin_data = NULL;
 
 
-   if(gap_debug) printf("p_get_gap_lastfilter: plugin_name:%s:\n", plugin_name);
+   if(gap_debug)
+   {
+     printf("p_get_gap_filter_data_string: plugin_name:%s:\n", plugin_name);
+   }
 
    plugin_data_len = gimp_get_data_size (plugin_name);
    if (plugin_data_len > 0)
@@ -423,7 +431,10 @@ p_get_gap_filter_data_string(const char *plugin_name)
         l_str = g_strdup_printf("%s\n", l_str_tmp);
         g_free(l_str_tmp);
 
-        if (gap_debug) printf("p_get_gap_lastfilter: %s", l_str);
+        if (gap_debug)
+        {
+          printf("p_get_gap_filter_data_string: %s", l_str);
+        }
 
         data_string = l_str;
         g_free(plugin_data);
@@ -435,6 +446,121 @@ p_get_gap_filter_data_string(const char *plugin_name)
 }  /* end p_get_gap_filter_data_string */
 
 
+/* -----------------------------------
+ * p_get_mapped_gap_filter_data_string
+ * -----------------------------------
+ *   return a textstring with the plugin_name
+ *   and its values as textstring
+ *   that has format like this:
+ *      "plug_in_name" len hexbyte1 hexbyte2 .......\n
+ *   example:
+ *      "plug_in_sharpen"    4  0a 00 00 00
+ *
+ *
+ *  In case the plugin has at least one iterable drawable id within its last values parameters
+ *  those values are mapped to persistent_drawable_id's with the help of a special
+ *  iterator call with a filtermacro context and a corresponding .fmref file in recording mode.
+ *
+ * return data_string or  NULL pointer if nothing was found.
+ *        the returned data_string should be g_free'd by the caller (if it was not NULL)
+ * 
+ */
+static gchar *
+p_get_mapped_gap_filter_data_string(const char *plugin_name, const char *filtermacro_file)
+{
+  static char l_key_from[512];
+  static char l_key_to[512];
+  gint plugin_data_len;
+  guchar *plugin_data_bck;
+  gchar  *data_string;
+  const char *l_iteratorname;
+  gint l_count;
+
+
+  data_string = NULL;
+ 
+  if(plugin_name == NULL)
+  {
+    return (NULL);
+  }
+  plugin_data_len = gimp_get_data_size (plugin_name);
+
+  if(gap_debug)
+  {
+    printf("p_get_mapped_gap_filter_data_string: plugin_name:%s:  plugin_data_len:%d\n"
+       , plugin_name
+       , plugin_data_len
+       );
+  }
+
+  /* assign the matching Iterator PluginProcedures (if there is any) */
+  l_iteratorname = gap_filt_pdb_get_iterator_proc(plugin_name, &l_count);
+
+  if ((plugin_data_len > 0) && (l_iteratorname != NULL))
+  {
+    GapFmacContext theFmacContext;
+    GapFmacContext *fmacContext;
+
+    fmacContext = &theFmacContext;
+
+    if(gap_debug)
+    {
+      printf("p_get_mapped_gap_filter_data_string: l_iteratorname:%s:\n"
+         , l_iteratorname
+         );
+    }
+    gap_fmct_setup_GapFmacContext(fmacContext
+                                 , TRUE  /* recording_mode */
+                                 , filtermacro_file
+                                 );
+
+
+    /* retrieve the data (to backup original data) */
+    plugin_data_bck = g_malloc0(plugin_data_len);
+    gimp_get_data(plugin_name, plugin_data_bck);
+
+
+    /* Set FROM and TO buffers. 
+     * (in recording mode we use all the same data as the backup of the original buffer)
+     * those buffers are not relevant in recording mode, but are required
+     * for the iterator call interface.
+     */
+    g_snprintf(l_key_from, sizeof(l_key_from), "%s%s", plugin_name, GAP_ITER_TO_SUFFIX);
+    gimp_set_data(l_key_from, plugin_data_bck, plugin_data_len);
+
+    g_snprintf(l_key_to, sizeof(l_key_to), "%s%s", plugin_name, GAP_ITER_FROM_SUFFIX);
+    gimp_set_data(l_key_to, plugin_data_bck, plugin_data_len);
+
+    /* call the iterator in recording mode
+     * this triggers the mapping of drawable ids in the persistent .fmref file.
+     * (but only in case the called plugin has at least one an iterable drawable_id in its last_values paramters,
+     * otherwise the las values buffer shall not change by the iteratorcall,
+     * due to same settings for from and to values) 
+     */
+    gap_filter_iterator_call(l_iteratorname
+       , 1       /* total_steps */
+       , 1.0     /* current_step */
+       , plugin_name
+       , plugin_data_len
+       );
+
+    data_string = p_get_gap_filter_data_string(plugin_name);
+
+    /* restore original data from backup buffer */
+    gimp_set_data(plugin_name, plugin_data_bck, plugin_data_len);
+
+    g_free(plugin_data_bck);
+    
+    /* disable the sessionwide filtermacro context */
+    gap_fmct_disable_GapFmacContext();
+
+  }
+
+  return (data_string);
+
+}  /* end p_get_mapped_gap_filter_data_string */
+
+
 /* -------------------------
  * p_fmac_add_filter_to_file
  * -------------------------
@@ -449,7 +575,7 @@ p_fmac_add_filter_to_file(const char *filtermacro_file, const char *plugin_name)
   if(gap_lib_file_exists(filtermacro_file) == 0 )
   {
     /*  file does not exist, or is empty */
-    fp = fopen(filtermacro_file, "w");
+    fp = g_fopen(filtermacro_file, "w");
     if(fp)
     {
       fprintf(fp, "# FILTERMACRO FILE (GIMP-GAP-1.3)\n");
@@ -462,14 +588,19 @@ p_fmac_add_filter_to_file(const char *filtermacro_file, const char *plugin_name)
   }
   else
   {
-    fp = fopen(filtermacro_file, "a");
+    fp = g_fopen(filtermacro_file, "a");
   }
 
   if (fp)
   {
     char *data_string;
+    char *canonical_plugin_name;
+
+    canonical_plugin_name = gimp_canonicalize_identifier(plugin_name);
+
+    data_string = p_get_mapped_gap_filter_data_string(canonical_plugin_name, filtermacro_file);
+    g_free(canonical_plugin_name);
 
-    data_string = p_get_gap_filter_data_string(plugin_name);
     if(data_string)
     {
       fprintf(fp, "%s", data_string);
@@ -504,8 +635,8 @@ p_fmac_add_filter(const char *filtermacro_file, gint32 image_id)
                           , p_fmac_pdb_constraint_proc_sel2
                           , &l_browser_result
                           , image_id
-			  , GAP_DB_BROWSER_FMAC_HELP_ID
-			  )
+                          , GAP_DB_BROWSER_FMAC_HELP_ID
+                          )
     < 0)
   {
     if(gap_debug) printf("DEBUG: gap_db_browser_dialog cancelled\n");
@@ -544,7 +675,7 @@ gap_fmac_dialog(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id)
   gpp->selected_number = -1;
 
   /* probably get filtermacro_file (form a previous call in the same GIMP-session) */
-  gimp_get_data(PLUG_IN_NAME_FMAC, gpp->filtermacro_file);
+  gimp_get_data(GAP_FMACNAME_PLUG_IN_NAME_FMAC, gpp->filtermacro_file);
 
   gpp->filesel = NULL;
   gpp->image_id = image_id;
@@ -562,7 +693,7 @@ gap_fmac_dialog(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id)
 
   vbox = gtk_vbox_new (FALSE, 4);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (gpp->dialog)->vbox),
-		      vbox, TRUE, TRUE, 0);
+                      vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
   /* table */
@@ -593,8 +724,8 @@ gap_fmac_dialog(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id)
                          ,NULL);
   gtk_widget_show(entry);
   g_signal_connect(G_OBJECT(entry), "changed",
-		   G_CALLBACK (p_file_entry_update_callback),
-		   gpp);
+                   G_CALLBACK (p_file_entry_update_callback),
+                   gpp);
 
   /* Button  to invoke filebrowser */
   button = gtk_button_new_with_label ("...");
@@ -602,20 +733,20 @@ gap_fmac_dialog(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id)
                          , _("Open filebrowser window to select a filename")
                          ,NULL);
   gtk_table_attach( GTK_TABLE(table), button, 2, 3, row, row +1,
-		    0, 0, 0, 0 );
+                    0, 0, 0, 0 );
   gtk_widget_show (button);
   g_signal_connect (G_OBJECT (button), "clicked",
-		    G_CALLBACK (p_filebrowser_button_callback),
-		    gpp);
+                    G_CALLBACK (p_filebrowser_button_callback),
+                    gpp);
 
   /* list : list in a scrolled_win */
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
-				       GTK_SHADOW_IN);
+                                       GTK_SHADOW_IN);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-				  GTK_POLICY_AUTOMATIC,
-				  GTK_POLICY_ALWAYS);
+                                  GTK_POLICY_AUTOMATIC,
+                                  GTK_POLICY_ALWAYS);
   gtk_box_pack_start (GTK_BOX (vbox), scrolled_window, TRUE, TRUE, 0);
   gtk_widget_show (scrolled_window);
 
@@ -626,22 +757,22 @@ gap_fmac_dialog(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id)
     (GTK_CELL_RENDERER_TEXT (renderer), 1);
 
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (gpp->tv),
-					       -1, _("Nr"),
-					       renderer,
-					       "text", 1,
-					       NULL);
+                                               -1, _("Nr"),
+                                               renderer,
+                                               "text", 1,
+                                               NULL);
 
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (gpp->tv),
-					       -1, _("PDB Name"),
-					       renderer,
-					       "text", 2,
-					       NULL);
+                                               -1, _("PDB Name"),
+                                               renderer,
+                                               "text", 2,
+                                               NULL);
 
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (gpp->tv),
-					       -1, _("Menu Path"),
-					       renderer,
-					       "text", 3,
-					       NULL);
+                                               -1, _("Menu Path"),
+                                               renderer,
+                                               "text", 3,
+                                               NULL);
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (gpp->tv), TRUE);
 
   gtk_widget_set_size_request (gpp->tv, 320 /*WIDTH*/, 100 /*HEIGHT*/);
@@ -667,16 +798,21 @@ gap_fmac_dialog(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id)
 
   if(gpp->filtermacro_file[0] != '\0')
   {
-    gimp_set_data(PLUG_IN_NAME_FMAC, gpp->filtermacro_file, FMAC_FILE_LENGTH);
+    gimp_set_data(GAP_FMACNAME_PLUG_IN_NAME_FMAC, gpp->filtermacro_file, FMAC_FILE_LENGTH);
 
     if(gpp->run_flag)
     {
       if(gap_debug) printf("gap_fmac_dialog: RUN image_id:%d drawable_id:%d, filtermacro_file:%s\n"
                               ,(int)image_id
-			      ,(int)drawable_id
-			      ,gpp->filtermacro_file
-			      );
-      return(gap_fmac_execute(run_mode, image_id, drawable_id, gpp->filtermacro_file));
+                              ,(int)drawable_id
+                              ,gpp->filtermacro_file
+                              );
+      return(gap_fmac_execute(run_mode, image_id, drawable_id
+              , gpp->filtermacro_file
+              , NULL  /* filtermacro_file2 */
+              , 1.0   /* current_step */
+              , 1     /* total_steps */
+              ));
     }
   }
 
@@ -735,8 +871,8 @@ p_procedure_select_callback (GtkTreeSelection *sel, fmac_globalparams_t *gpp)
   {
     /* get column 0 (the invisible intenal number) from the store */
     gtk_tree_model_get (GTK_TREE_MODEL (gpp->store), &iter
-		       ,0, &numtxt
-		       , -1);
+                       ,0, &numtxt
+                       , -1);
     if (gap_debug) printf("p_procedure_select_callback (3) numtxt:%s\n", numtxt);
     gpp->selected_number = atoi(numtxt);
     g_free (numtxt);
@@ -756,14 +892,14 @@ p_tree_fill (fmac_globalparams_t *gpp)
   gint          count_elem;
   gboolean      parse_file;
 
-  GapVinTextFileLines *txf_ptr;
-  GapVinTextFileLines *txf_ptr_root;
+  GapValTextFileLines *txf_ptr;
+  GapValTextFileLines *txf_ptr_root;
 
 
   gpp->store = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
   gtk_tree_view_set_model (GTK_TREE_VIEW (gpp->tv)
                           ,GTK_TREE_MODEL (gpp->store)
-			  );
+                          );
   g_object_unref (gpp->store);
 
   /* read filternames from filtermacro_file
@@ -781,8 +917,8 @@ p_tree_fill (fmac_globalparams_t *gpp)
 
   if(parse_file)
   {
-    txf_ptr_root = gap_vin_load_textfile(gpp->filtermacro_file);
-    for(txf_ptr = txf_ptr_root; txf_ptr != NULL; txf_ptr = (GapVinTextFileLines *) txf_ptr->next)
+    txf_ptr_root = gap_val_load_textfile(gpp->filtermacro_file);
+    for(txf_ptr = txf_ptr_root; txf_ptr != NULL; txf_ptr = (GapValTextFileLines *) txf_ptr->next)
     {
        gchar *pdb_name;
 
@@ -791,23 +927,23 @@ p_tree_fill (fmac_globalparams_t *gpp)
        {
          gchar *numtxt;
          gchar *label;
-	 gchar *menu_path;
+         gchar *menu_path;
 
          menu_path = gap_db_get_plugin_menupath(pdb_name);
-	 if(menu_path == NULL)
-	 {
-	   menu_path = g_strdup(_("** No menu path available **"));
-	 }
+         if(menu_path == NULL)
+         {
+           menu_path = g_strdup(_("** No menu path available **"));
+         }
          label = g_strdup_printf("%3d.", (int)count_elem +1);
          numtxt = g_strdup_printf("%d", (int)count_elem);
 
          gtk_list_store_append (gpp->store, &iter);
          gtk_list_store_set (gpp->store, &iter
-    		            ,0, numtxt            /* internal invisible number starting at 0 */
-    		            ,1, label             /* visible number starting at 1 */
-		            ,2, pdb_name
-			    ,3, menu_path
-		            ,-1);
+                            ,0, numtxt            /* internal invisible number starting at 0 */
+                            ,1, label             /* visible number starting at 1 */
+                            ,2, pdb_name
+                            ,3, menu_path
+                            ,-1);
          g_free (numtxt);
          g_free (label);
          g_free (menu_path);
@@ -818,7 +954,7 @@ p_tree_fill (fmac_globalparams_t *gpp)
 
     if(txf_ptr_root)
     {
-      gap_vin_free_textfile_lines(txf_ptr_root);
+      gap_val_free_textfile_lines(txf_ptr_root);
     }
   }
 
@@ -830,20 +966,20 @@ p_tree_fill (fmac_globalparams_t *gpp)
     || (gap_lib_file_exists(gpp->filtermacro_file) == 0 ))
     {
          gtk_list_store_set (gpp->store, &iter
-    		            ,0, "-1"
-			    ,1, " "
-			    ,2, _("** Empty **")
-    		            ,3, " "
-		            ,-1);
+                            ,0, "-1"
+                            ,1, " "
+                            ,2, _("** Empty **")
+                            ,3, " "
+                            ,-1);
     }
     else
     {
          gtk_list_store_set (gpp->store, &iter
-    		            ,0, "-1"
-			    ,1, " "
-			    ,2, _("** File is not a filtermacro **")
-		            ,3, " "
-		            ,-1);
+                            ,0, "-1"
+                            ,1, " "
+                            ,2, _("** File is not a filtermacro **")
+                            ,3, " "
+                            ,-1);
     }
   }
 
@@ -874,17 +1010,19 @@ p_create_action_area_buttons(fmac_globalparams_t *gpp)
 
 
   /* Button HELP */
-  button = gtk_button_new_from_stock ( GTK_STOCK_HELP);
-  gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
-  gimp_help_set_help_data(button
-                          ,_("Show help page")
-                          , NULL);
-  g_signal_connect (G_OBJECT (button), "clicked"
-		   ,G_CALLBACK (p_help_callback)
-                   ,gpp
-                   );
-  gtk_widget_show (button);
-
+  if (gimp_show_help_button ())
+    {
+      button = gtk_button_new_from_stock ( GTK_STOCK_HELP);
+      gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+      gimp_help_set_help_data(button
+                              ,_("Show help page")
+                              , NULL);
+      g_signal_connect (G_OBJECT (button), "clicked"
+                        ,G_CALLBACK (p_help_callback)
+                        ,gpp
+                        );
+      gtk_widget_show (button);
+    }
 
   /* Button Delete All */
   button = gtk_button_new_with_label (_("Delete All"));
@@ -894,7 +1032,7 @@ p_create_action_area_buttons(fmac_globalparams_t *gpp)
                           ,_("Delete the filtermacro scriptfile")
                           , NULL);
   g_signal_connect (G_OBJECT (button), "clicked"
-		   ,G_CALLBACK (p_delete_all_callback)
+                   ,G_CALLBACK (p_delete_all_callback)
                    ,gpp
                    );
   gtk_widget_show (button);
@@ -907,7 +1045,7 @@ p_create_action_area_buttons(fmac_globalparams_t *gpp)
                           ,_("Delete the selected filtercall")
                           , NULL);
   g_signal_connect (G_OBJECT (button), "clicked"
-		   ,G_CALLBACK (p_delete_callback)
+                   ,G_CALLBACK (p_delete_callback)
                    ,gpp
                    );
   gtk_widget_show (button);
@@ -918,15 +1056,15 @@ p_create_action_area_buttons(fmac_globalparams_t *gpp)
   gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
   gimp_help_set_help_data(button
                           ,_("Open PDB-browser window to add a new filter "
-			     "to the filtermacro scriptfile.\n"
-			     "Important:\n"
-			     "The PDB-browser shows only filters "
-			     "that have already been used in the current session "
-			     "and have setup the internal buffer with the "
-			     "parameter settings of the last call")
+                             "to the filtermacro scriptfile.\n"
+                             "Important:\n"
+                             "The PDB-browser shows only filters "
+                             "that have already been used in the current session "
+                             "and have setup the internal buffer with the "
+                             "parameter settings of the last call")
                           , NULL);
   g_signal_connect (G_OBJECT (button), "clicked"
-		   ,G_CALLBACK (p_add_callback)
+                   ,G_CALLBACK (p_add_callback)
                    ,gpp
                    );
   gtk_widget_show (button);
@@ -940,7 +1078,7 @@ p_create_action_area_buttons(fmac_globalparams_t *gpp)
                           ,_("Close window")
                           , NULL);
   g_signal_connect (G_OBJECT (button), "clicked"
-		   ,G_CALLBACK (p_close_callback)
+                   ,G_CALLBACK (p_close_callback)
                    ,gpp
                    );
   gtk_widget_show (button);
@@ -954,7 +1092,7 @@ p_create_action_area_buttons(fmac_globalparams_t *gpp)
                           ,_("Apply filtermacro script on current drawable and close window")
                           , NULL);
   g_signal_connect (G_OBJECT (button), "clicked"
-		   ,G_CALLBACK (p_ok_callback)
+                   ,G_CALLBACK (p_ok_callback)
                    ,gpp
                    );
   gtk_widget_show (button);
@@ -1069,49 +1207,49 @@ p_delete_callback (GtkWidget *widget, fmac_globalparams_t *gpp)
 
       if(gpp->selected_number >= 0)
       {
-        GapVinTextFileLines *txf_ptr;
-        GapVinTextFileLines *txf_ptr_root;
-	gint count_elem;
+        GapValTextFileLines *txf_ptr;
+        GapValTextFileLines *txf_ptr_root;
+        gint count_elem;
         gchar *label;
         FILE  *fp;
-	gboolean copy_line;
+        gboolean copy_line;
 
-	/* rewrite the filtermacro file
-	 * without the line that corresponds to gpp->selected_number
-	 */
-        txf_ptr_root = gap_vin_load_textfile(gpp->filtermacro_file);
-	fp = fopen(gpp->filtermacro_file, "w");
-	if(fp)
-	{
-	  count_elem = 0;
-	  for(txf_ptr = txf_ptr_root; txf_ptr != NULL; txf_ptr = (GapVinTextFileLines *) txf_ptr->next)
-	  {
-	    copy_line = TRUE;
+        /* rewrite the filtermacro file
+         * without the line that corresponds to gpp->selected_number
+         */
+        txf_ptr_root = gap_val_load_textfile(gpp->filtermacro_file);
+        fp = g_fopen(gpp->filtermacro_file, "w");
+        if(fp)
+        {
+          count_elem = 0;
+          for(txf_ptr = txf_ptr_root; txf_ptr != NULL; txf_ptr = (GapValTextFileLines *) txf_ptr->next)
+          {
+            copy_line = TRUE;
 
             label = p_get_filtername(txf_ptr->line);
             if(label)
-	    {
-	      if(count_elem == gpp->selected_number)
-	      {
-		copy_line = FALSE;
-	      }
-	      g_free(label);
-	      count_elem++;
-	    }
+            {
+              if(count_elem == gpp->selected_number)
+              {
+                copy_line = FALSE;
+              }
+              g_free(label);
+              count_elem++;
+            }
 
-	    if(gap_debug) printf("%4d  %s", (int)count_elem, txf_ptr->line);
+            if(gap_debug) printf("%4d  %s", (int)count_elem, txf_ptr->line);
 
-	    if(copy_line)
-	    {
-	      fprintf(fp, "%s", txf_ptr->line);
-	    }
-	  }
-	  fclose(fp);
-	}
-	if(txf_ptr_root)
-	{
-	  gap_vin_free_textfile_lines(txf_ptr_root);
-	}
+            if(copy_line)
+            {
+              fprintf(fp, "%s", txf_ptr->line);
+            }
+          }
+          fclose(fp);
+        }
+        if(txf_ptr_root)
+        {
+          gap_val_free_textfile_lines(txf_ptr_root);
+        }
 
       }
     }
@@ -1130,7 +1268,7 @@ p_delete_all_callback (GtkWidget *widget, fmac_globalparams_t *gpp)
   {
     if(p_chk_filtermacro_file(gpp->filtermacro_file))
     {
-      remove(gpp->filtermacro_file);
+      g_remove(gpp->filtermacro_file);
     }
     p_tree_fill (gpp);
   }
@@ -1155,8 +1293,8 @@ p_add_callback (GtkWidget *widget, fmac_globalparams_t *gpp)
       if((l_rc < 0) && (errno != 0))
       {
         g_message(_("ERROR: Could not write filtermacro script\n"
-	        "filename: '%s'\n%s")
-	       ,gpp->filtermacro_file, g_strerror (errno));
+                "filename: '%s'\n%s")
+               ,gpp->filtermacro_file, g_strerror (errno));
       }
     }
     p_tree_fill (gpp);
@@ -1184,25 +1322,25 @@ p_filebrowser_button_callback (GtkWidget *widget, fmac_globalparams_t *gpp)
   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
 
   g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-		   "clicked",
+                   "clicked",
                     G_CALLBACK (p_filesel_ok_callback),
-		    gpp);
+                    gpp);
 
   g_signal_connect(G_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-		  "clicked",
+                  "clicked",
                    G_CALLBACK (p_filesel_close_callback),
-	           gpp);
+                   gpp);
 
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel),
-				   gpp->filtermacro_file);
+                                   gpp->filtermacro_file);
 
   gtk_widget_show (filesel);
   /* "destroy" has to be the last signal,
    * (otherwise the other callbacks are never called)
    */
   g_signal_connect (G_OBJECT (filesel), "destroy",
-		    G_CALLBACK (p_filesel_close_callback),
-		    gpp);
+                    G_CALLBACK (p_filesel_close_callback),
+                    gpp);
 }
 
 /* ----------------------------
@@ -1211,7 +1349,7 @@ p_filebrowser_button_callback (GtkWidget *widget, fmac_globalparams_t *gpp)
  */
 static void
 p_filesel_close_callback(GtkWidget *widget,
-		   fmac_globalparams_t *gpp)
+                   fmac_globalparams_t *gpp)
 {
   GtkWidget        *filesel;
 
@@ -1230,7 +1368,7 @@ p_filesel_close_callback(GtkWidget *widget,
  */
 static void
 p_filesel_ok_callback(GtkWidget *widget,
-		   fmac_globalparams_t *gpp)
+                   fmac_globalparams_t *gpp)
 {
   const gchar        *filename;
 
@@ -1252,7 +1390,7 @@ p_filesel_ok_callback(GtkWidget *widget,
  */
 static void
 p_file_entry_update_callback(GtkWidget *widget,
-		   fmac_globalparams_t *gpp)
+                   fmac_globalparams_t *gpp)
 {
  if(gpp)
  {
@@ -1285,7 +1423,7 @@ p_fmac_pdb_constraint_proc(gchar *proc_name, gint32 image_id)
      return 0;
   }
 
-  if(strcmp(proc_name, PLUG_IN_NAME_FMAC) == 0)
+  if(strcmp(proc_name, GAP_FMACNAME_PLUG_IN_NAME_FMAC) == 0)
   {
      /* Do not add the filtermacro plugin itself */
      return 0;
@@ -1333,177 +1471,3 @@ p_fmac_pdb_constraint_proc_sel2(gchar *proc_name, gint32 image_id)
   return (p_fmac_pdb_constraint_proc_sel1 (proc_name, image_id));
 }
 
-
-
-/* ----------------
- * p_fmac_execute
- * ----------------
- */
-gint
-p_fmac_execute(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id, const char *filtermacro_file)
-{
-  int      l_rc;
-  int      l_idx;
-  long int l_data_len;
-  long int l_data_byte;
-  char    *l_plugin_name;
-  char    *l_scan_ptr;
-  char    *l_scan_ptr2;
-  guchar  *l_lastvalues_data_buffer;
-  guchar  *l_lastvalues_bck_buffer;
-  gchar   *l_msg;
-  gint     l_bck_len;
-
-  GapVinTextFileLines *txf_ptr;
-  GapVinTextFileLines *txf_ptr_root;
-
-
-  l_lastvalues_bck_buffer = NULL;
-  l_bck_len = 0;
-
-  if (!p_chk_filtermacro_file(filtermacro_file))
-  {
-      l_msg = g_strdup_printf("file: %s is not a filtermacro file !", filtermacro_file);
-      p_print_and_free_msg(l_msg, run_mode);
-      return -1;
-  }
-
-  /* process filtermacro file (scann line by line and apply filter ) */
-  txf_ptr_root = gap_vin_load_textfile(filtermacro_file);
-  for(txf_ptr = txf_ptr_root; txf_ptr != NULL; txf_ptr = (GapVinTextFileLines *) txf_ptr->next)
-  {
-    gchar *l_buf;
-
-    l_buf = txf_ptr->line;
-
-     /* handle lines starting with double quotes */
-    if (l_buf[0] == '"')
-    {
-      /* scan plugin-name */
-      l_scan_ptr=&l_buf[0];
-      l_plugin_name = &l_buf[1];
-      for(l_idx=1; l_idx < 4000;l_idx++)
-      {
-        if (l_buf[l_idx] == '"')
-        {
-          l_buf[l_idx] = '\0';
-          l_scan_ptr=&l_buf[l_idx+1];
-          break;
-        }
-      }
-
-      if(gap_debug) printf("p_fmac_execute: ##l_plugin_name:%s\n", l_plugin_name);
-
-
-      /* scan for data length */
-      l_data_len = strtol(l_scan_ptr, &l_scan_ptr2, 10);
-
-      if (l_scan_ptr != l_scan_ptr2)
-      {
-         l_bck_len = gimp_get_data_size(l_plugin_name);
-
-         if(l_bck_len > 0)
-         {
-           if(l_bck_len != l_data_len)
-           {
-              l_msg = g_strdup_printf ("parameter data buffer for plugin: '%s' differs in size\n"
-                                       "actual size: %d\n"
-                                       "recorded size: %d"
-                                      , l_plugin_name
-                                      , (int)l_bck_len
-                                      , (int)l_data_len
-                                      );
-              p_print_and_free_msg(l_msg, run_mode);
-              gap_vin_free_textfile_lines(txf_ptr_root);
-              return -1;
-           }
-           l_lastvalues_bck_buffer = g_malloc0(l_bck_len);
-           gimp_get_data (l_plugin_name, l_lastvalues_bck_buffer);
-         }
-
-         if(gap_debug) printf("p_fmac_execute: ##l_data_len:%d\n", (int)l_data_len);
-
-
-         l_lastvalues_data_buffer = g_malloc0(l_data_len);
-         l_scan_ptr = l_scan_ptr2;
-         for(l_idx=0; l_idx < l_data_len;l_idx++)
-         {
-            l_data_byte = strtol(l_scan_ptr, &l_scan_ptr2, 16);
-            /* if(gap_debug) printf("p_fmac_execute: l_data_byte:%d\n", (int)l_data_byte); */
-
-            if ((l_data_byte < 0) || (l_data_byte > 255) || (l_scan_ptr == l_scan_ptr2))
-            {
-              g_free(l_lastvalues_data_buffer);
-              l_msg = g_strdup_printf ("filtermacro_file: '%s' is corrupted, could not scan databytes", filtermacro_file);
-              p_print_and_free_msg(l_msg, run_mode);
-              gap_vin_free_textfile_lines(txf_ptr_root);
-              return -1;
-            }
-            l_lastvalues_data_buffer[l_idx] = l_data_byte;
-            l_scan_ptr = l_scan_ptr2;
-         }
-         gimp_set_data(l_plugin_name, l_lastvalues_data_buffer, (gint)l_data_len);
-         g_free(l_lastvalues_data_buffer);
-      }
-
-      if(gap_debug) printf("p_fmac_execute: # before p_call_plugin: image_id:%d drawable_id:%d\n", (int)image_id ,(int)drawable_id );
-
-      /* check for the Plugin */
-      l_rc = gap_filt_pdb_procedure_available(l_plugin_name, GAP_PTYP_CAN_OPERATE_ON_DRAWABLE);
-      if(l_rc < 0)
-      {
-         l_msg = g_strdup_printf(_("Plug-in not available or has wrong type\n"
-                                   "plug-in name: '%s'")
-                                  , l_plugin_name);
-         p_print_and_free_msg(l_msg, run_mode);
-         gap_vin_free_textfile_lines(txf_ptr_root);
-         return -1;
-      }
-
-      /* execute one filtermacro step on image/drawable */
-      l_rc = gap_filt_pdb_call_plugin(l_plugin_name, image_id, drawable_id, GIMP_RUN_WITH_LAST_VALS);
-      if(l_rc < 0)
-      {
-         l_msg = g_strdup_printf("Plug-in call failed\n"
-                                 "plug-in name: '%s'"
-                                 , l_plugin_name);
-         p_print_and_free_msg(l_msg, run_mode);
-         gap_vin_free_textfile_lines(txf_ptr_root);
-         return -1;
-      }
-
-      if(l_lastvalues_bck_buffer)
-      {
-        gimp_set_data(l_plugin_name, l_lastvalues_bck_buffer, l_bck_len);
-        g_free(l_lastvalues_bck_buffer);
-        l_lastvalues_bck_buffer = NULL;
-      }
-
-    }
-
-  }
-
-  if(txf_ptr_root)
-  {
-    gap_vin_free_textfile_lines(txf_ptr_root);
-  }
-
-  return 0;
-}  /* end p_fmac_execute */
-
-
-
-/* ----------------
- * gap_fmac_execute
- * ----------------
- */
-gint
-gap_fmac_execute(GimpRunMode run_mode, gint32 image_id, gint32 drawable_id, const char *filtermacro_file)
-{
-  gint l_rc;
-
-  gimp_image_undo_group_start(image_id);
-  l_rc = p_fmac_execute(run_mode, image_id,  drawable_id, filtermacro_file);
-  gimp_image_undo_group_end(image_id);
-  return (l_rc);
-}
