@@ -104,7 +104,7 @@ gint32 gap_layer_copy_to_dest_image (gint32 dst_image_id,
   if(gap_debug) printf("GAP gap_layer_copy_to_dest_image: ret %d\n", (int)l_ret_id);
 
   return l_ret_id;
-}	/* end gap_layer_copy_to_dest_image */
+}       /* end gap_layer_copy_to_dest_image */
 
 
 /* -----------------------
@@ -153,11 +153,11 @@ gap_layer_copy_to_image (gint32 dst_image_id, gint32 src_layer_id)
 
   l_new_layer_id = gap_layer_copy_to_dest_image(dst_image_id
                                                ,src_layer_id
-					       ,l_src_opacity
-					       ,l_src_mode
-					       ,&l_src_offset_x
-					       ,&l_src_offset_y
-					       );
+                                               ,l_src_opacity
+                                               ,l_src_mode
+                                               ,&l_src_offset_x
+                                               ,&l_src_offset_y
+                                               );
   if(l_new_layer_id < 0)
   {
      return -1;
@@ -185,7 +185,7 @@ gap_layer_copy_to_image (gint32 dst_image_id, gint32 src_layer_id)
  */
 static void
 p_copy_rgn_render_region (const GimpPixelRgn *srcPR
-		    ,const GimpPixelRgn *dstPR)
+                    ,const GimpPixelRgn *dstPR)
 {
   guint    row;
   guchar* src  = srcPR->data;
@@ -229,25 +229,27 @@ gap_layer_copy_content (gint32 dst_drawable_id, gint32 src_drawable_id)
            ,(int)src_drawable->width
            ,(int)src_drawable->height
            ,(int)src_drawable->bpp
-	   );
+           );
     printf("dst: w:%d h:%d bpp:%d\n"
            ,(int)dst_drawable->width
            ,(int)dst_drawable->height
            ,(int)dst_drawable->bpp
-	   );
+           );
+    gimp_drawable_detach(src_drawable);
+    gimp_drawable_detach(dst_drawable);
     return FALSE;
   }
 
   gimp_pixel_rgn_init (&srcPR, src_drawable, 0, 0
                       , src_drawable->width, src_drawable->height
-		      , FALSE     /* dirty */
-		      , FALSE     /* shadow */
-		       );
+                      , FALSE     /* dirty */
+                      , FALSE     /* shadow */
+                       );
   gimp_pixel_rgn_init (&dstPR, dst_drawable, 0, 0
                       , dst_drawable->width, dst_drawable->height
-		      , TRUE      /* dirty */
-		      , FALSE     /* shadow */
-		       );
+                      , TRUE      /* dirty */
+                      , FALSE     /* shadow */
+                       );
 
 
   for (pr = gimp_pixel_rgns_register (2, &srcPR, &dstPR);
@@ -272,9 +274,9 @@ gap_layer_copy_content (gint32 dst_drawable_id, gint32 src_drawable_id)
  */
 static void
 p_pick_rgn_render_region (const GimpPixelRgn *srcPR
-		    ,const GimpPixelRgn *dstPR
-		    ,guint src_channel_pick
-		    ,guint dst_channel_pick)
+                    ,const GimpPixelRgn *dstPR
+                    ,guint src_channel_pick
+                    ,guint dst_channel_pick)
 {
   guint    row;
   guchar* src  = srcPR->data;
@@ -282,16 +284,16 @@ p_pick_rgn_render_region (const GimpPixelRgn *srcPR
 
   for (row = 0; row < dstPR->h; row++)
     {
-	guchar* l_src  = src;
-	guchar* l_dest = dest;
-	guint   col = dstPR->w;
+        guchar* l_src  = src;
+        guchar* l_dest = dest;
+        guint   col = dstPR->w;
 
-	while (col--)
-	  {
+        while (col--)
+          {
             l_dest[dst_channel_pick] = l_src[src_channel_pick];
-	    l_src += srcPR->bpp;
-	    l_dest += dstPR->bpp;
-	  }
+            l_src += srcPR->bpp;
+            l_dest += dstPR->bpp;
+          }
 
       src  += srcPR->rowstride;
       dest += dstPR->rowstride;
@@ -317,7 +319,7 @@ p_pick_rgn_render_region (const GimpPixelRgn *srcPR
 gboolean
 gap_layer_copy_picked_channel (gint32 dst_drawable_id,  guint dst_channel_pick
                               , gint32 src_drawable_id, guint src_channel_pick
-			      , gboolean shadow)
+                              , gboolean shadow)
 {
   GimpPixelRgn srcPR, dstPR;
   GimpDrawable *src_drawable;
@@ -338,12 +340,14 @@ gap_layer_copy_picked_channel (gint32 dst_drawable_id,  guint dst_channel_pick
            ,(int)src_drawable->width
            ,(int)src_drawable->height
            ,(int)src_drawable->bpp
-	   );
+           );
     printf("dst: w:%d h:%d bpp:%d\n"
            ,(int)dst_drawable->width
            ,(int)dst_drawable->height
            ,(int)dst_drawable->bpp
-	   );
+           );
+    gimp_drawable_detach(src_drawable);
+    gimp_drawable_detach(dst_drawable);
     return FALSE;
   }
 
@@ -353,14 +357,14 @@ gap_layer_copy_picked_channel (gint32 dst_drawable_id,  guint dst_channel_pick
 
   gimp_pixel_rgn_init (&srcPR, src_drawable, x1, y1
                       , (x2 - x1), (y2 - y1)
-		      , FALSE     /* dirty */
-		      , FALSE     /* shadow */
-		       );
+                      , FALSE     /* dirty */
+                      , FALSE     /* shadow */
+                       );
   gimp_pixel_rgn_init (&dstPR, dst_drawable, x1, y1
                       ,  (x2 - x1), (y2 - y1)
-		      , TRUE      /* dirty */
-		      , shadow    /* shadow */
-		       );
+                      , TRUE      /* dirty */
+                      , shadow    /* shadow */
+                       );
 
   if(shadow)
   {
@@ -375,19 +379,19 @@ gap_layer_copy_picked_channel (gint32 dst_drawable_id,  guint dst_channel_pick
 
      gimp_pixel_rgn_init (&origPR, dst_drawable, x1, y1
                       ,  (x2 - x1), (y2 - y1)
-		      , FALSE    /* dirty */
-		      , FALSE    /* shadow */
-		       );
+                      , FALSE    /* dirty */
+                      , FALSE    /* shadow */
+                       );
      gimp_pixel_rgn_init (&shadowPR, dst_drawable, x1, y1
                       ,  (x2 - x1), (y2 - y1)
-		      , TRUE    /* dirty */
-		      , TRUE    /* shadow */
-		       );
+                      , TRUE    /* dirty */
+                      , TRUE    /* shadow */
+                       );
      for (pr = gimp_pixel_rgns_register (2, &origPR, &shadowPR);
-	  pr != NULL;
-	  pr = gimp_pixel_rgns_process (pr))
+          pr != NULL;
+          pr = gimp_pixel_rgns_process (pr))
      {
-	 p_copy_rgn_render_region (&origPR, &shadowPR);
+         p_copy_rgn_render_region (&origPR, &shadowPR);
      }
   }
 
@@ -429,10 +433,10 @@ gap_layer_copy_picked_channel (gint32 dst_drawable_id,  guint dst_channel_pick
 gint32 
 gap_layer_new_from_buffer(gint32 image_id
                                     , gint32 width
-				    , gint32 height
-				    , gint32 bpp
-				    , guchar *data
-				    )
+                                    , gint32 height
+                                    , gint32 bpp
+                                    , guchar *data
+                                    )
 {
   gint32 layer_id;
   GimpImageBaseType l_basetype;
@@ -455,12 +459,12 @@ gap_layer_new_from_buffer(gint32 image_id
 
   layer_id = gimp_layer_new(image_id
                 , "dummy"
-		, width
-		, height
-		, l_type
-		, 100.0   /* full opacity */
-		, 0       /* normal mode */
-		);
+                , width
+                , height
+                , l_type
+                , 100.0   /* full opacity */
+                , 0       /* normal mode */
+                );
 
   if(layer_id >= 0)
   {
@@ -469,17 +473,17 @@ gap_layer_new_from_buffer(gint32 image_id
     gimp_pixel_rgn_init (&dstPR, dst_drawable
                       , 0, 0     /* x1, y1 */
                       , width
-		      , height
-		      , TRUE     /* dirty */
-		      , FALSE    /* shadow */
-		       );
+                      , height
+                      , TRUE     /* dirty */
+                      , FALSE    /* shadow */
+                       );
     
     gimp_pixel_rgn_set_rect(&dstPR
                            ,data
                            ,0
                            ,0
                            ,width
-			   ,height
+                           ,height
                            );
 
     /*  update the processed region  */
@@ -571,19 +575,19 @@ gap_layer_flip(gint32 layer_id, gint32 flip_request)
       axis = (gdouble)(gimp_drawable_width(layer_id)) / 2.0;
       layer_id = gimp_drawable_transform_flip_simple(layer_id
                                    ,GIMP_ORIENTATION_HORIZONTAL
-				   ,TRUE    /* auto_center */
-				   ,axis
-				   ,TRUE    /* clip_result */
-				   );
+                                   ,TRUE    /* auto_center */
+                                   ,axis
+                                   ,TRUE    /* clip_result */
+                                   );
       break;
     case GAP_STB_FLIP_VER:
       axis = (gdouble)(gimp_drawable_height(layer_id)) / 2.0;
       layer_id = gimp_drawable_transform_flip_simple(layer_id
                                    ,GIMP_ORIENTATION_VERTICAL
-				   ,TRUE    /* auto_center */
-				   ,axis
-				   ,TRUE    /* clip_result */
-				   );
+                                   ,TRUE    /* auto_center */
+                                   ,axis
+                                   ,TRUE    /* clip_result */
+                                   );
       break;
     case GAP_STB_FLIP_BOTH:
       center_x = gimp_drawable_width(layer_id) / 2;
@@ -591,11 +595,11 @@ gap_layer_flip(gint32 layer_id, gint32 flip_request)
   
       layer_id = gimp_drawable_transform_rotate_simple(layer_id
                                   ,GIMP_ROTATE_180
-				  ,TRUE      /* auto_center */
-				  ,center_x
-				  ,center_y
-				  ,TRUE      /* clip_result */
-				  );
+                                  ,TRUE      /* auto_center */
+                                  ,center_x
+                                  ,center_y
+                                  ,TRUE      /* clip_result */
+                                  );
       break;
     default:
       break;
@@ -603,3 +607,243 @@ gap_layer_flip(gint32 layer_id, gint32 flip_request)
   
   return(layer_id);
 }  /* end gap_layer_flip */
+
+
+
+/* -----------------------------
+ * gap_layer_copy_paste_drawable
+ * -----------------------------
+ * copy specified dst_drawable into src_drawable using
+ * gimp copy paste procedures.
+ * The selection in the specified image will be removed
+ * (e.g. is ignored for copying)
+ * the caller shall specify image_id == -1 in case where selection
+ * shall be respected.
+ */
+void
+gap_layer_copy_paste_drawable(gint32 image_id, gint32 dst_drawable_id, gint32 src_drawable_id)
+{
+  gint32   l_fsel_layer_id;
+  
+  if (image_id >= 0)
+  {
+    gimp_selection_none(image_id);
+  }
+        gimp_edit_copy(src_drawable_id);
+  l_fsel_layer_id = gimp_edit_paste(dst_drawable_id, FALSE);
+  gimp_floating_sel_anchor(l_fsel_layer_id);
+}  /* end gap_layer_copy_paste_drawable */
+
+
+/* ---------------------------------
+ * gap_layer_get_stackposition
+ * ---------------------------------
+ * get stackposition index of the specified layer.
+ * return -1 if the layer is not part of the specified image
+ */
+gint32
+gap_layer_get_stackposition(gint32 image_id, gint32 ref_layer_id)
+{
+  gint          l_nlayers;
+  gint32       *l_layers_list;
+  gint32        l_idx;
+
+  l_layers_list = gimp_image_get_layers(image_id, &l_nlayers);
+  if(l_layers_list != NULL)
+  {
+    for(l_idx = 0; l_idx < l_nlayers; l_idx++)
+    {
+      if(l_layers_list[l_idx] == ref_layer_id)
+      {
+        g_free (l_layers_list);
+        return(l_idx);   
+      }
+    }
+    g_free (l_layers_list);
+  }
+
+  return (-1);
+  
+}  /* end gap_layer_get_stackposition */
+
+
+/* ---------------------------------
+ * gap_layer_get_id_by_stackposition
+ * ---------------------------------
+ * return -1 if the specified image has no layer at specified stackposition
+ */
+gint32
+gap_layer_get_id_by_stackposition(gint32 image_id, gint32 stackposition)
+{
+  gint          l_nlayers;
+  gint32       *l_layers_list;
+  gint32        l_layer_id;
+
+  l_layer_id = -1;
+  l_layers_list = gimp_image_get_layers(image_id, &l_nlayers);
+  if(l_layers_list != NULL)
+  {
+    if ((stackposition >= 0) && (stackposition < l_nlayers))
+    {
+      l_layer_id = l_layers_list[stackposition];
+    }
+    g_free (l_layers_list);
+  }
+
+  return (l_layer_id);
+
+}  /* end gap_layer_get_id_by_stackposition */
+
+
+/* ------------------------
+ * gap_layer_make_duplicate
+ * ------------------------
+ *
+ */
+gint32
+gap_layer_make_duplicate(gint32 src_layer_id, gint32 image_id
+  , const char *name_prefix, const char *name_suffix)
+{  
+  gint32         l_new_layer_id;
+  gint32         l_stackposition;
+  const char    *l_suffix;
+  const char    *l_prefix;
+  char          *l_new_name;
+  char          *l_old_name;
+
+
+  /* make a copy of the layer  */
+  l_new_layer_id = gimp_layer_copy(src_layer_id);
+  
+  /* and add at stackposition above src_layer */
+  l_stackposition = gap_layer_get_stackposition(image_id, src_layer_id);
+  gimp_image_add_layer (image_id, l_new_layer_id, l_stackposition);
+
+  /* build name with optional prefix and/or suffix */  
+  l_suffix = "\0";
+  l_prefix = "\0";
+  if (name_suffix != NULL)
+  {
+    l_suffix = name_suffix;
+  }
+  if (name_prefix != NULL)
+  {
+    l_prefix = name_prefix;
+  }
+  l_old_name = gimp_drawable_get_name(src_layer_id);
+  
+  l_new_name = g_strdup_printf("%s%s%s", l_prefix, l_old_name, l_suffix);
+  
+  gimp_drawable_set_name(l_new_layer_id, l_new_name);
+  g_free(l_old_name);
+  g_free(l_new_name);
+  
+  return (l_new_layer_id);
+}  /* end gap_layer_make_duplicate */
+
+
+
+/* -----------------------------------------------
+ * gap_layer_create_layer_from_layermask
+ * -----------------------------------------------
+ * create a new layer as copy of the layermask of the
+ * specified src_layer_id.
+ * The name is built as copy of the src_layer_id's name
+ * with optional prefix and/or suffix.
+ * (specify NULL to omit name_prefix and/or name_suffix)
+ *
+ * the new layer is added to the image at top
+ * of layerstack
+ * or above the src_layer if src_layer is in the same image.
+ * 
+ * return the id of the newly created layer.
+ */
+gint32
+gap_layer_create_layer_from_layermask(gint32 src_layer_id
+  , gint32 image_id
+  , const char *name_prefix, const char *name_suffix)
+{
+  gboolean       l_has_already_layermask;
+  gint32         l_layermask_id;
+  gint32         l_new_layer_id;
+  gint32         l_new_layermask_id;
+
+  /* make a copy of the layer (but without the layermask) */
+  l_new_layer_id = gap_layer_make_duplicate(src_layer_id, image_id
+    , name_prefix, name_suffix);
+  l_new_layermask_id = gimp_layer_get_mask(l_new_layer_id);
+  if (l_new_layermask_id >= 0)
+  {
+    /* copy the layermask into the new layer */
+    gap_layer_copy_paste_drawable(image_id
+                           , l_new_layer_id      /* dst_drawable_id */
+                           , l_new_layermask_id  /* src_drawable_id */
+                           );
+    gimp_layer_remove_mask (l_new_layer_id, GIMP_MASK_DISCARD);
+  }
+  else
+  {
+    /* create white layer (in case no layermask was present) */
+    gap_layer_clear_to_color(l_new_layer_id
+                              ,1.0 /* red */
+                              ,1.0 /* green  */
+                              ,1.0 /* blue */
+                              ,1.0 /* alpha */
+                              );
+  }
+
+  return (l_new_layer_id);
+}  /* end gap_layer_create_layer_from_layermask */
+
+
+/* ---------------------------------
+ * gap_layer_create_layer_from_alpha
+ * ---------------------------------
+ *
+ */
+gint32
+gap_layer_create_layer_from_alpha(gint32 src_layer_id, gint32 image_id
+  , const char *name_prefix, const char *name_suffix
+  , gboolean applyExistingLayermask, gboolean useTransferAlpha)
+{
+  gint32         l_new_layer_id;
+  gint32         l_old_layermask_id;
+  gint32         l_new_layermask_id;
+
+  /* make a copy of the src_layer */
+  l_new_layer_id = gap_layer_make_duplicate(src_layer_id, image_id
+                           , name_prefix, name_suffix);
+  l_old_layermask_id = gimp_layer_get_mask(l_new_layer_id);
+
+  if (l_old_layermask_id >= 0)
+  {
+    /* handle already exiting layermask: apply or remove (e.g. ignore) */
+    if (applyExistingLayermask)
+    {
+       /* merge the already existing layermask into the alpha channel */
+       gimp_layer_remove_mask (l_new_layer_id, GIMP_MASK_APPLY);
+    }
+    else
+    {
+       gimp_layer_remove_mask (l_new_layer_id, GIMP_MASK_DISCARD);
+    }
+  }
+
+  /* create a new layermask from the alpha channel */
+  if (useTransferAlpha == TRUE)
+  {
+          l_new_layermask_id = gimp_layer_create_mask(l_new_layer_id, GIMP_ADD_ALPHA_TRANSFER_MASK);
+  }
+  else
+  {
+          l_new_layermask_id = gimp_layer_create_mask(l_new_layer_id, GIMP_ADD_ALPHA_MASK);
+  }
+
+
+  gimp_layer_add_mask(l_new_layer_id, l_new_layermask_id);
+  gap_layer_copy_paste_drawable(image_id, l_new_layer_id, l_new_layermask_id);
+  gimp_layer_remove_mask (l_new_layer_id, GIMP_MASK_DISCARD);
+  return (l_new_layer_id);
+
+}  /* end gap_layer_create_layer_from_alpha  */
+
