@@ -27,8 +27,8 @@
 
 /* revision history:
  * 2.1.0a   2005/03/10   hof: added active_layer_tracking feature
- * 2.1.0a   2004/12/04   hof: added gap_lib_shorten_filename
- * 2.1.0a   2004/04/18   hof: added gap_lib_fprintf_gdouble
+ * 2.1.0a   2004/12/04   hof: added gap_lib (base)_shorten_filename
+ * 2.1.0a   2004/04/18   hof: added gap_lib (base)_fprintf_gdouble
  * 1.3.26a  2004/02/01   hof: added: gap_lib_alloc_ainfo_from_name
  * 1.3.25a  2004/01/20   hof: - removed xvpics support (gap_lib_get_video_paste_name)
  * 1.3.21e  2003/11/04   hof: - gimprc
@@ -119,7 +119,7 @@
 
 
 #ifdef G_OS_WIN32
-#include <process.h>		/* For _getpid() */
+#include <process.h>            /* For _getpid() */
 #endif
 
 /* GAP includes */
@@ -134,6 +134,22 @@
 #include "gap_thumbnail.h"
 #include "gap_vin.h"
 
+typedef struct
+{
+  gdouble  quality;
+  gdouble  smoothing;
+  gboolean optimize;
+  gboolean progressive;
+  gboolean baseline;
+  gint     subsmp;
+  gint     restart;
+  gint     dct;
+  gboolean preview;
+  gboolean save_exif;
+  gboolean save_thumbnail;
+  gboolean save_xmp;
+  gboolean use_orig_quality;
+} GAPJpegSaveVals;
 
 extern      int gap_debug; /* ==0  ... dont print debug infos */
 
@@ -160,7 +176,15 @@ static void         p_do_active_layer_tracking(gint32 image_id
 
 static int          p_save_old_frame(GapAnimInfo *ainfo_ptr, GapVinVideoInfo *vin_ptr);
 static int          p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_name);
-static gint32       p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_mode, gboolean enable_thumbnailsave);
+static gint32       p_lib_save_jpg_non_interactive(gint32 image_id, gint32 l_drawable_id,
+                         const char *sav_name,
+                         const GAPJpegSaveVals *save_vals);
+static gint32       p_lib_save_named_image_1(gint32 image_id, const char *sav_name, GimpRunMode run_mode, gboolean enable_thumbnailsave
+                         , const char *l_basename
+                         , const char *l_extension
+                         );
+static gint32       p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_mode,
+                        gboolean enable_thumbnailsave, const GAPJpegSaveVals *jpg_save_vals);
 static char*        p_gzip (char *orig_name, char *new_name, char *zip);
 
 
@@ -226,12 +250,12 @@ p_set_active_layer_by_pos(gint32 image_id
       l_name = gimp_drawable_get_name(l_matching_layer_id);
       printf("p_set_active_layer_by_pos SET layer_id %d '%s' as ACTIVE\n"
             , (int)l_matching_layer_id
-	    , l_name
-	    );
+            , l_name
+            );
       if(l_name)
       {
         g_free(l_name);
-      }	    
+      }     
     }
     return (TRUE);
   }
@@ -304,79 +328,79 @@ p_set_active_layer_by_name(gint32 image_id
 
         if(g_utf8_validate(l_layer_name, -1, NULL))
         {
-	  const char *uni_ref_ptr;
-	  const char *uni_nam_ptr;
+          const char *uni_ref_ptr;
+          const char *uni_nam_ptr;
 
           uni_ref_ptr = ref_layer_name;
-	  uni_nam_ptr = l_layer_name;
+          uni_nam_ptr = l_layer_name;
 
-	  /* check how many characters of the name are equal */
+          /* check how many characters of the name are equal */
           l_len = g_utf8_strlen(l_layer_name, -1);
           for(ii=0; ii < MIN(l_len, l_ref_len); ii++)
-	  {
-	    gunichar refname_char;
-	    gunichar layername_char;
-	    
-	    refname_char = g_utf8_get_char(uni_ref_ptr);
-	    layername_char = g_utf8_get_char(uni_nam_ptr);
+          {
+            gunichar refname_char;
+            gunichar layername_char;
+            
+            refname_char = g_utf8_get_char(uni_ref_ptr);
+            layername_char = g_utf8_get_char(uni_nam_ptr);
 
-	    if(g_unichar_toupper(layername_char) == g_unichar_toupper(refname_char))
-	    {
-	      /* best score for matching character */
-	      l_score += 8;
-	      if(layername_char == refname_char)
-	      {
-		if(ii==0)
-		{
-	          /* prepare bonus for matching in case sensitivity */
-	          l_case_bonus = 4;
-		}
-	      }
-	      else
-	      {
-		/* lost the bonus for exact matching in case sensitivity */
-		l_case_bonus = 0;
-	      }
-	    }
-	    else
-	    {
+            if(g_unichar_toupper(layername_char) == g_unichar_toupper(refname_char))
+            {
+              /* best score for matching character */
+              l_score += 8;
+              if(layername_char == refname_char)
+              {
+                if(ii==0)
+                {
+                  /* prepare bonus for matching in case sensitivity */
+                  l_case_bonus = 4;
+                }
+              }
+              else
+              {
+                /* lost the bonus for exact matching in case sensitivity */
+                l_case_bonus = 0;
+              }
+            }
+            else
+            {
               break;
-	    }
-	    uni_ref_ptr = g_utf8_find_next_char(uni_ref_ptr, NULL);
-	    uni_nam_ptr = g_utf8_find_next_char(uni_nam_ptr, NULL);
-	  }
+            }
+            uni_ref_ptr = g_utf8_find_next_char(uni_ref_ptr, NULL);
+            uni_nam_ptr = g_utf8_find_next_char(uni_nam_ptr, NULL);
+          }
 
-	  l_score += l_case_bonus;
-	  if(l_len == l_ref_len)
-	  {
-	    /* extra score for equal length */
-	    l_score += 2;
-	  }
+          l_score += l_case_bonus;
+          if(l_len == l_ref_len)
+          {
+            /* extra score for equal length */
+            l_score += 2;
+          }
         }
 
-	g_free(l_layer_name);
+        g_free(l_layer_name);
       }
       
       if(l_score == l_max_score)
       {
-	/* stackposition is checked as secondary criterium
-	 * (score +1) in case there are more names matching
-	 * in the same number of characters
-	 */
-	l_is_onion = gap_onion_base_check_is_onion_layer(l_layer_id);
-	if(!l_is_onion)
-	{
+        /* stackposition is checked as secondary criterium
+         * (score +1) in case there are more names matching
+         * in the same number of characters
+         */
+        l_is_onion = gap_onion_base_check_is_onion_layer(l_layer_id);
+        if(!l_is_onion)
+        {
           if(l_pos == ref_layer_stackpos)
           {
             l_score += 1;
           }
           l_pos++;
-	}
+        }
       }
       if(l_score > l_max_score)
       {
         l_matching_layer_id = l_layer_id;
-	l_max_score = l_score;
+        l_max_score = l_score;
       }
     }
     
@@ -394,12 +418,12 @@ p_set_active_layer_by_name(gint32 image_id
       l_name = gimp_drawable_get_name(l_matching_layer_id);
       printf("p_set_active_layer_by_name SET layer_id %d '%s' as ACTIVE\n"
             , (int)l_matching_layer_id
-	    , l_name
-	    );
+            , l_name
+            );
       if(l_name)
       {
         g_free(l_name);
-      }	    
+      }     
     }
     return (TRUE);
   }
@@ -499,172 +523,7 @@ p_do_active_layer_tracking(gint32 image_id
 }  /* end p_do_active_layer_tracking */
 
 
-/* -----------------------------
- * gap_lib_shorten_filename
- * -----------------------------
- * resulting string is built from prefix filename  and suffix
- *    filename will be shortened when
- *    prefix + " " + filename + " " + suffix 
- *    is longer then max_chars.
- * examples:
- *    gap_lib_shorten_filenam("prefix", "this_is_a_very_long_filename", NULL, 20)
- *    returns:  "prefix ...g_filename"
- *
- *    gap_lib_shorten_filenam("prefix", "shortname", NULL, 20)
- *    returns:  "prefix shortname"
- *
- * the caller is responsible to g_free the returned string
- */
-char *
-gap_lib_shorten_filename(const char *prefix
-                        ,const char *filename
-			,const char *suffix
-			,gint32 max_chars
-			)
-{
-  gint len_prefix;
-  gint len_fname;
-  const char *pfx;
-  char       *fnam;
-  char       *ret_string;
-  
-  len_prefix = 0;
-  len_fname = 0;
-  ret_string = NULL;
-  pfx = prefix;
-  if(prefix)
-  {
-    len_prefix = strlen(prefix);
-    if((len_prefix + 10) > max_chars)
-    {
-      pfx = NULL;
-      len_prefix = 0;
-    }
-    else
-    {
-      len_prefix++;  /* for the space between prefix and fname */
-    }
-  }
-
-  
-  if(filename)
-  {
-    fnam = NULL;
-    
-    if(suffix)
-    {
-      fnam = g_strdup_printf("%s %s", filename, suffix);
-    }
-    else
-    {
-      fnam = g_strdup(filename);
-    }
-
-
-    len_fname = strlen(fnam);
-    if((len_fname + len_prefix) <= max_chars)
-    {
-      if(pfx)
-      {
-        ret_string = g_strdup_printf("%s %s"
-	                            ,pfx
-				    ,fnam
-				    );
-      }
-      else
-      {
-        ret_string = g_strdup_printf("%s"
-				    ,fnam
-				    );
-      }
-    }
-    else
-    {
-      gint fname_idx;
-      gint len_rest;
-      
-      len_rest = (max_chars - len_prefix - 3);
-      fname_idx = len_fname - len_rest;
-      
-      if(pfx)
-      {
-        ret_string = g_strdup_printf("%s ...%s"
-	                            ,pfx
-				    ,&fnam[fname_idx]
-				    );
-      }
-      else
-      {
-        ret_string = g_strdup_printf("...%s"
-				    ,&fnam[fname_idx]
-				    );
-      }
-    }
- 
-    g_free(fnam);
-    return (ret_string);
-     
-  }
-
-  ret_string = g_strdup(prefix);
-  return(ret_string);
-}  /* end gap_lib_shorten_filename */			
-
-
-/* ============================================================================
- * p_strdup_*_underscore
- *   duplicate string and if last char is no underscore add one at end.
- *   duplicate string and delete last char if it is the underscore
- * ============================================================================
- */
-char *
-gap_lib_strdup_add_underscore(char *name)
-{
-  int   l_len;
-  char *l_str;
-  if(name == NULL)
-  {
-    return(g_strdup("\0"));
-  }
-
-  l_len = strlen(name);
-  l_str = g_malloc(l_len+1);
-  strcpy(l_str, name);
-  if(l_len > 0)
-  {
-    if (name[l_len-1] != '_')
-    {
-       l_str[l_len    ] = '_';
-       l_str[l_len +1 ] = '\0';
-    }
-
-  }
-  return(l_str);
-}
-
-char *
-gap_lib_strdup_del_underscore(char *name)
-{
-  int   l_len;
-  char *l_str;
-  if(name == NULL)
-  {
-    return(g_strdup("\0"));
-  }
-
-  l_len = strlen(name);
-  l_str = g_strdup(name);
-  if(l_len > 0)
-  {
-    if (l_str[l_len-1] == '_')
-    {
-       l_str[l_len -1 ] = '\0';
-    }
-
-  }
-  return(l_str);
-}
-
+                
 
 /* ============================================================================
  * gap_lib_file_exists
@@ -701,7 +560,7 @@ gap_lib_file_exists(const char *fname)
   }
 
   return(1);
-}	/* end gap_lib_file_exists */
+}       /* end gap_lib_file_exists */
 
 /* ============================================================================
  * gap_lib_searchpath_for_exefile
@@ -745,15 +604,15 @@ gap_lib_searchpath_for_exefile(const char *exefile, const char *path)
       exe_fullname = g_build_filename(dirpath, exefile, NULL);
       if(g_file_test (exe_fullname, G_FILE_TEST_IS_EXECUTABLE) )
       {
-	/* the executable was found at exe_fullname,
-	 * set break flag and keep that name as return value
-	 */
+        /* the executable was found at exe_fullname,
+         * set break flag and keep that name as return value
+         */
         break_flag = TRUE;
       }
       else
       {
         g_free(exe_fullname);
-	exe_fullname = NULL;
+        exe_fullname = NULL;
       }
       dirpath = pp;
       dirpath++;       /* start of next directoryname in the path string */
@@ -804,10 +663,10 @@ gap_lib_image_file_copy(char *fname, char *fname_copy)
 int
 gap_lib_file_copy(char *fname, char *fname_copy)
 {
-  FILE	      *l_fp;
+  FILE        *l_fp;
   char                     *l_buffer;
   struct stat               l_stat_buf;
-  long	       l_len;
+  long         l_len;
 
   if(gap_debug) printf("gap_lib_file_copy src:%s dst:%s\n", fname, fname_copy);
 
@@ -828,7 +687,7 @@ gap_lib_file_copy(char *fname, char *fname_copy)
   }
 
   /* load File into Buffer */
-  l_fp = g_fopen(fname, "rb");		    /* open read */
+  l_fp = g_fopen(fname, "rb");              /* open read */
   if(l_fp == NULL)
   {
     fprintf (stderr, "open(read) error on '%s'\n", fname);
@@ -838,7 +697,7 @@ gap_lib_file_copy(char *fname, char *fname_copy)
   fread(l_buffer, 1, (size_t)l_len, l_fp);
   fclose(l_fp);
 
-  l_fp = g_fopen(fname_copy, "wb");		    /* open write */
+  l_fp = g_fopen(fname_copy, "wb");                 /* open write */
   if(l_fp == NULL)
   {
     fprintf (stderr, "file_copy: open(write) error on '%s' \n", fname_copy);
@@ -854,7 +713,7 @@ gap_lib_file_copy(char *fname, char *fname_copy)
   fclose(l_fp);
   g_free(l_buffer);
   return 0;           /* all done OK */
-}	/* end gap_lib_file_copy */
+}       /* end gap_lib_file_copy */
 
 
 /* ============================================================================
@@ -1143,8 +1002,8 @@ gap_lib_alloc_fname6(char *basename, long nr, char *extension, long default_digi
        while(l_nr_chk >= 0)
        {
          /* check if frame is on disk with 6-digit style framenumber
-	  * (we check 6-digit style first because this is the GAP default style)
-	  */
+          * (we check 6-digit style first because this is the GAP default style)
+          */
          g_snprintf(l_fname, l_len, "%s%06ld%s", basename, l_nr_chk, extension);
          if (gap_lib_file_exists(l_fname))
          {
@@ -1167,10 +1026,10 @@ gap_lib_alloc_fname6(char *basename, long nr, char *extension, long default_digi
             l_digits_used = 7;
             break;
          }
-	 
+         
 
 
-	 
+         
          /* check if frame is on disk with 4-digit style framenumber */
          g_snprintf(l_fname, l_len, "%s%04ld%s", basename, l_nr_chk, extension);
          if (gap_lib_file_exists(l_fname))
@@ -1509,6 +1368,8 @@ gap_lib_alloc_ainfo(gint32 image_id, GimpRunMode run_mode)
    l_ainfo_ptr->last_frame_nr = -1;
    l_ainfo_ptr->frame_cnt = 0;
    l_ainfo_ptr->run_mode = run_mode;
+   l_ainfo_ptr->frame_nr_before_curr_frame_nr = -1;   /* -1 if no frame found before curr_frame_nr */
+   l_ainfo_ptr->frame_nr_after_curr_frame_nr = -1;    /* -1 if no frame found after curr_frame_nr */
 
 
    return(l_ainfo_ptr);
@@ -1623,12 +1484,29 @@ gap_lib_dir_ainfo(GapAnimInfo *ainfo_ptr)
                  ainfo_ptr->frame_cnt++;
 
 
-                 if(gap_debug) printf("DEBUG gap_lib_dir_ainfo:  %s NR=%ld\n", l_entry, l_nr);
+                 if(gap_debug)
+                 {
+                   printf("DEBUG gap_lib_dir_ainfo:  %s NR=%ld  Curr:%ld\n", l_entry, l_nr, ainfo_ptr->curr_frame_nr);
+                 }
 
                  if (l_nr > l_maxnr)
                     l_maxnr = l_nr;
                  if (l_nr < l_minnr)
                     l_minnr = l_nr;
+                 
+                 if ((l_nr < ainfo_ptr->curr_frame_nr) && (l_nr > ainfo_ptr->frame_nr_before_curr_frame_nr))
+                 {
+                   ainfo_ptr->frame_nr_before_curr_frame_nr = l_nr;
+                 }
+                 if (l_nr > ainfo_ptr->curr_frame_nr)
+                 {
+                   if ((ainfo_ptr->frame_nr_after_curr_frame_nr < 0)
+                   || (l_nr < ainfo_ptr->frame_nr_after_curr_frame_nr))
+                   {
+                     ainfo_ptr->frame_nr_after_curr_frame_nr = l_nr;
+                   }
+                 }
+
                }
 
                g_free(l_dummy);
@@ -1646,7 +1524,7 @@ gap_lib_dir_ainfo(GapAnimInfo *ainfo_ptr)
   ainfo_ptr->first_frame_nr = MIN(l_minnr, l_maxnr);
 
   return 0;           /* OK */
-}	/* end gap_lib_dir_ainfo */
+}       /* end gap_lib_dir_ainfo */
 
 
 /* ============================================================================
@@ -1766,13 +1644,13 @@ gap_lib_chk_framechange(GapAnimInfo *ainfo_ptr)
     {
        gap_arr_msg_win(ainfo_ptr->run_mode,
          _("Operation cancelled.\n"
-	   "Current frame was changed while dialog was open."));
+           "Current frame was changed while dialog was open."));
     }
     gap_lib_free_ainfo(&l_ainfo_ptr);
   }
 
   return l_rc;
-}	/* end gap_lib_chk_framechange */
+}       /* end gap_lib_chk_framechange */
 
 /* ============================================================================
  * gap_lib_chk_framerange
@@ -1788,14 +1666,14 @@ gap_lib_chk_framerange(GapAnimInfo *ainfo_ptr)
   if(ainfo_ptr->frame_cnt == 0)
   {
      gap_arr_msg_win(ainfo_ptr->run_mode,
-	       _("Operation cancelled.\n"
+               _("Operation cancelled.\n"
                  "GAP video plug-ins only work with filenames\n"
                  "that end in numbers like _000001.xcf.\n"
                  "==> Rename your image, then try again."));
      return -1;
   }
   return 0;
-}	/* end gap_lib_chk_framerange */
+}       /* end gap_lib_chk_framerange */
 
 /* ============================================================================
  * p_gzip
@@ -1849,7 +1727,7 @@ p_gzip (char *orig_name, char *new_name, char *zip)
   g_free(l_cmd);
   return l_tmpname;
 
-}	/* end p_gzip */
+}       /* end p_gzip */
 
 /* ============================================================================
  * p_decide_save_as
@@ -1874,22 +1752,25 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
   gchar *l_ext;
   gchar *l_basename;
   long  l_number;
+  int   l_sav_rc;
 
   static GapArrButtonArg  l_argv[3];
   int               l_argc;
   int               l_save_as_mode;
   GimpRunMode      l_run_mode;
+    
 
    /* check if there are SAVE_AS_MODE settings (from privious calls within one gimp session) */
   l_save_as_mode = -1;
+  l_sav_rc = -1;
 
   l_extension = gap_lib_alloc_extension(final_sav_name);
   l_basename = gap_lib_alloc_basename(final_sav_name, &l_number);
 
   l_key_save_as_mode = g_strdup_printf("GIMP_GAP_SAVE_MODE_%s%s"
-		       ,l_basename
-		       ,l_extension
-		       );
+                       ,l_basename
+                       ,l_extension
+                       );
 
   gimp_get_data (l_key_save_as_mode, &l_save_as_mode);
 
@@ -1935,12 +1816,12 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
 
       if(strcmp(l_val_gimprc, "yes") == 0)
       {
-	l_save_as_mode = 1;
+        l_save_as_mode = 1;
         l_ask = FALSE;
       }
       if(strcmp(l_val_gimprc, "no") == 0)
       {
-	l_save_as_mode = 0;
+        l_save_as_mode = 0;
         l_ask = FALSE;
       }
 
@@ -1967,23 +1848,26 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
       l_argc             = 3;
 
       l_msg = g_strdup_printf(_("You are using another file format than xcf.\n"
-				"Save operations may result in loss of layer information.\n\n"
-				"To configure flattening for this fileformat\n"
-				"(permanent for all further sessions) please add the line:\n"
-				"(%s %s)\n"
-				"to your gimprc file.")
-			     , l_key_gimprc
-			     , "\"yes\""
-			     );
+                                "Save operations may result in loss of layer information.\n\n"
+                                "To configure flattening for this fileformat\n"
+                                "(permanent for all further sessions) please add the line:\n"
+                                "(%s %s)\n"
+                                "to your gimprc file.")
+                             , l_key_gimprc
+                             , "\"yes\""
+                             );
       l_save_as_mode =  gap_arr_buttons_dialog (_("Fileformat Warning")
-                                        	,l_msg
-						, l_argc, l_argv, -1);
+                                                ,l_msg
+                                                , l_argc, l_argv, -1);
       g_free(l_msg);
     }
 
     g_free(l_key_gimprc);
 
-    if(gap_debug) printf("DEBUG: decide SAVE_AS_MODE %d\n", (int)l_save_as_mode);
+    if(gap_debug)
+    {
+      printf("DEBUG: decide SAVE_AS_MODE %d\n", (int)l_save_as_mode);
+    }
 
     l_run_mode = GIMP_RUN_INTERACTIVE;
   }
@@ -1994,26 +1878,34 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
 
   gimp_set_data (l_key_save_as_mode, &l_save_as_mode, sizeof(l_save_as_mode));
 
-  g_free(l_basename);
-  g_free(l_extension);
   g_free(l_key_save_as_mode);
 
   if(l_save_as_mode < 0)
   {
-    return -1;
+    l_sav_rc = -1;
   }
-
-  if(l_save_as_mode == 1)
+  else
   {
-      gimp_image_flatten (image_id);
+    if(l_save_as_mode == 1)
+    {
+        gimp_image_flatten (image_id);
+    }
+
+
+    l_sav_rc = p_lib_save_named_image_1(image_id
+                             , sav_name
+                             , l_run_mode
+                             , FALSE      /* do not enable_thumbnailsave */
+                             , l_basename
+                             , l_extension
+                             );
   }
 
-  return(p_lib_save_named_image2(image_id
-                           , sav_name
-			   , l_run_mode
-			   , FALSE      /* do not enable_thumbnailsave */
-			   ));
-}	/* end p_decide_save_as */
+  g_free(l_basename);
+  g_free(l_extension);
+
+  return l_sav_rc;
+}       /* end p_decide_save_as */
 
 /* ============================================================================
  * gap_lib_gap_check_save_needed
@@ -2050,6 +1942,214 @@ gap_lib_gap_check_save_needed(gint32 image_id)
 }  /* end gap_lib_gap_check_save_needed */
 
 
+/* ------------------------------------------
+ * p_lib_save_jpg_non_interactive
+ * ------------------------------------------
+ * this procedure handles NON-Interactive save of a frame
+ * in the lossy but widly spread JPEG fileformat.
+ * The quality settings have to be provided via jpg_save_parasite
+ * paramteter that has the structure GAPJpegSaveVals.
+ * NOTE: the structure GAPJpegSaveVals must match with
+ * the structure JpegSaveVals (as defined by the jpeg file save plugin
+ * in file jpeg-save.h of the GIMP distribution)
+ */
+static gint32
+p_lib_save_jpg_non_interactive(gint32 image_id, gint32 l_drawable_id, const char *sav_name,
+  const GAPJpegSaveVals *save_vals)
+{
+  gint32     l_rc;
+  gint       l_retvals;
+
+  l_rc   = FALSE;
+
+  if(gap_debug)
+  {
+    printf("DEBUG: p_lib_save_jpg_non_interactive: '%s' imageId:%d, drawableID:%d\n"
+           "  jpg quality:%f\n"
+           "  jpg smoothing:%f\n"
+           "  jpg optimize:%d\n"
+           "  jpg progressive:%d\n"
+           "  jpg subsmp:%d\n"
+           "  jpg baseline:%d\n"
+           "  jpg restart:%d\n"
+           "  jpg dct:%d\n"
+         , sav_name
+         , (int)image_id
+         , (int)l_drawable_id
+         , (float)save_vals->quality
+         , (float)save_vals->smoothing
+         , (int)save_vals->optimize
+         , (int)save_vals->progressive
+         , (int)save_vals->subsmp
+         , (int)save_vals->baseline
+         , (int)save_vals->restart
+         , (int)save_vals->dct
+         );
+  }
+
+  /* save specified layer of current frame as jpg image
+   */
+  GimpParam *l_params;
+  l_params = gimp_run_procedure ("file_jpeg_save",
+                               &l_retvals,
+                               GIMP_PDB_INT32,    GIMP_RUN_NONINTERACTIVE,
+                               GIMP_PDB_IMAGE,    image_id,
+                               GIMP_PDB_DRAWABLE, l_drawable_id,
+                               GIMP_PDB_STRING, sav_name,
+                               GIMP_PDB_STRING, sav_name, /* raw name ? */
+                               GIMP_PDB_FLOAT,  save_vals->quality / 100.0,
+                               GIMP_PDB_FLOAT,  save_vals->smoothing,
+                               GIMP_PDB_INT32,  save_vals->optimize,
+                               GIMP_PDB_INT32,  save_vals->progressive,
+                               GIMP_PDB_STRING, "GIMP-GAP Frame",    /* comment */
+                               GIMP_PDB_INT32,  save_vals->subsmp,
+                               GIMP_PDB_INT32,  save_vals->baseline,
+                               GIMP_PDB_INT32,  save_vals->restart,
+                               GIMP_PDB_INT32,  save_vals->dct,
+                               GIMP_PDB_END);
+  if (l_params[0].data.d_status == GIMP_PDB_SUCCESS)
+  {
+     if(gap_debug)
+     {
+       printf("DEBUG: p_lib_save_jpg_non_interactive: GIMP_PDB_SUCCESS '%s\n"
+          ,sav_name
+          );
+     }
+     l_rc = TRUE;
+  }
+  gimp_destroy_params (l_params, l_retvals);
+  
+  return (l_rc);
+
+}  /* end p_lib_save_jpg_non_interactive */
+
+
+static gboolean
+p_extension_is_jpeg(const char *extension)
+{
+  if (extension != NULL)
+  {
+    const char *ext;
+    ext = extension;
+    if (*ext == '.')
+    {
+      ext++;
+    }
+    if ((*ext == 'j') || (*ext == 'J'))
+    {
+      ext++;
+      if ((*ext == 'p') || (*ext == 'P'))
+      {
+        return (TRUE);
+      }
+    }
+
+  }
+  return (FALSE);
+  
+}
+
+/* -------------------------------------
+ * p_lib_save_named_image_1
+ * -------------------------------------
+ * save non xcf frames/images.
+ * This procedure handles special case if frames have to be
+ * saved as JPEG files.
+ */
+static gint32
+p_lib_save_named_image_1(gint32 image_id, const char *sav_name, GimpRunMode run_mode, gboolean enable_thumbnailsave
+  , const char *l_basename
+  , const char *l_extension
+  )
+{
+  GAPJpegSaveVals   *jpg_save_vals;
+  gint32 l_sav_rc;
+  char *l_key_save_vals_jpg;
+  
+  
+  l_sav_rc = -1;
+  jpg_save_vals = NULL;
+  
+  l_key_save_vals_jpg = g_strdup_printf("GIMP_GAP_SAVE_VALS_JPG_%s%s"
+                       ,l_basename
+                       ,l_extension
+                       );
+
+  if(gap_debug)
+  {
+    printf("p_lib_save_named_image_1: runmode:%d  sav_name:%s\n .. l_key_save_vals_jpg:%s\n  .. base:%s\n  .. ext:%s\n"
+      ,run_mode
+      ,sav_name
+      ,l_key_save_vals_jpg
+      ,l_basename
+      ,l_extension
+      );
+  }
+
+  /* before non interactive save options check if we have already jpeg-save-options
+   * for the handled frames with the same basename and extension
+   */
+  if (run_mode != GIMP_RUN_INTERACTIVE)
+  {
+    int jpg_parsize;
+    
+    jpg_parsize = gimp_get_data_size(l_key_save_vals_jpg);
+    if(gap_debug)
+    {
+      printf("p_lib_save_named_image_1: jpg_parsize=%d\n"
+        ,jpg_parsize
+        );
+    }
+
+    if (jpg_parsize > 0)
+    {
+      jpg_save_vals = g_malloc(jpg_parsize);
+      gimp_get_data (l_key_save_vals_jpg, jpg_save_vals);
+      run_mode = GIMP_RUN_NONINTERACTIVE;
+    }
+  }
+
+  l_sav_rc = p_lib_save_named_image2(image_id
+                           , sav_name
+                           , run_mode
+                           , FALSE      /* do not enable_thumbnailsave */
+                           , jpg_save_vals
+                           );
+  if (jpg_save_vals != NULL)
+  {
+    g_free(jpg_save_vals);
+  }
+
+  /* check for jpeg specific save options after INTERACTIVE save operation
+   * (recent versions of JPEG save plugin shall store the save options
+   * in parasite data.)
+   */
+  if ((run_mode == GIMP_RUN_INTERACTIVE) && (p_extension_is_jpeg(l_extension)))
+  {
+    GimpParasite      *jpg_save_parasite;
+
+    jpg_save_parasite = gimp_image_parasite_find (image_id,
+                                      "jpeg-save-options");
+    if(gap_debug)
+    {
+      printf("DEBUG: jpg_save_parasite %d\n", (int)jpg_save_parasite);
+    }
+    if (jpg_save_parasite)
+    {
+      const GAPJpegSaveVals   *const_jpg_save_vals;
+      const_jpg_save_vals = gimp_parasite_data (jpg_save_parasite);
+      
+      /* store the jpeg save options for the handled frame basename and extension in this session */
+      gimp_set_data (l_key_save_vals_jpg, const_jpg_save_vals, sizeof(GAPJpegSaveVals));
+      gimp_parasite_free (jpg_save_parasite);
+    }
+  }
+  
+  g_free(l_key_save_vals_jpg);
+  
+  return (l_sav_rc);
+}  /* end p_lib_save_named_image_1 */
+
 /* ============================================================================
  * gap_lib_save_named_image / 2
  * ============================================================================
@@ -2057,7 +2157,8 @@ gap_lib_gap_check_save_needed(gint32 image_id)
  * gimp native XCF format.
  */
 static gint32
-p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_mode, gboolean enable_thumbnailsave)
+p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_mode, gboolean enable_thumbnailsave
+  ,const GAPJpegSaveVals *jpg_save_vals)
 {
   gint32      l_drawable_id;
   gint        l_nlayers;
@@ -2080,12 +2181,36 @@ p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_m
 
   l_drawable_id = l_layers_list[l_nlayers -1];  /* use the background layer */
 
-  l_rc = gimp_file_save(run_mode,
-                 image_id,
-		 l_drawable_id,
-		 sav_name,
-		 sav_name /* raw name ? */
-		 );
+  if ((jpg_save_vals != NULL) 
+  && (run_mode != GIMP_RUN_INTERACTIVE))
+  {
+    /* Special case: save JPG noninteractive
+     * Since GIMP-2.4.x jpeg file save plugin changed behaviour:
+     * when saved in GIMP_RUN_WITH_LAST_VALS mode it acts the same way
+     * as interactive mode (e.q. opens a dialog) 
+     * this behaviour is not acceptable when saving lots of frames.
+     * therefore GAP tries to figure out the jpeg save paramters that
+     * are available as parasite data, and perform a non interactive
+     * save operation.
+     * (This way the GIMP_GAP code gets a dependency to all future
+     * changes of JPEG file save parameter changes,
+     * but at least works for GIMP-2.4.x again)
+     */
+     l_rc = p_lib_save_jpg_non_interactive(image_id,
+                                    l_drawable_id,
+                                    sav_name,
+                                    jpg_save_vals
+                                    );
+  }
+  else
+  {
+    l_rc = gimp_file_save(run_mode,
+                   image_id,
+                   l_drawable_id,
+                   sav_name,
+                   sav_name /* raw name ? */
+                   );
+  }
 
 
   if(gap_debug)
@@ -2125,16 +2250,30 @@ p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_m
   }
   return image_id;
 
-}	/* end p_lib_save_named_image2 */
+}       /* end p_lib_save_named_image2 */
 
 gint32
 gap_lib_save_named_image(gint32 image_id, const char *sav_name, GimpRunMode run_mode)
 {
-  return(p_lib_save_named_image2(image_id
+  gchar *l_extension;
+  gchar *l_basename;
+  gint32 l_rc;
+  long  l_number;
+
+  l_extension = gap_lib_alloc_extension(sav_name);
+  l_basename = gap_lib_alloc_basename(sav_name, &l_number);
+
+  l_rc = p_lib_save_named_image_1(image_id
                             , sav_name
-			    , run_mode
-			    , TRUE      /* enable_thumbnailsave */
-			    ));
+                            , run_mode
+                            , TRUE      /* enable_thumbnailsave */
+                            , l_basename
+                            , l_extension
+                            );
+  g_free(l_extension);
+  g_free(l_basename);
+
+  return (l_rc);
 }
 
 
@@ -2171,6 +2310,8 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
       );
     return -1;
   }
+  
+  gimp_image_set_filename(image_id, sav_name);
 
   if(0 == strcmp(l_ext, ".xcf"))
   {
@@ -2227,13 +2368,13 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
      * the drawable is ignored. (we can supply a dummy value)
      */
     l_params = gimp_run_procedure ("gimp_xcf_save",
-			         &l_retvals,
-			         GIMP_PDB_INT32,    GIMP_RUN_NONINTERACTIVE,
-			         GIMP_PDB_IMAGE,    image_id,
-			         GIMP_PDB_DRAWABLE, 0,
-			         GIMP_PDB_STRING, l_tmpname,
-			         GIMP_PDB_STRING, l_tmpname, /* raw name ? */
-			         GIMP_PDB_END);
+                                 &l_retvals,
+                                 GIMP_PDB_INT32,    GIMP_RUN_NONINTERACTIVE,
+                                 GIMP_PDB_IMAGE,    image_id,
+                                 GIMP_PDB_DRAWABLE, 0,
+                                 GIMP_PDB_STRING, l_tmpname,
+                                 GIMP_PDB_STRING, l_tmpname, /* raw name ? */
+                                 GIMP_PDB_END);
     if(gap_debug)
     {
       printf("DEBUG: after   xcf  gap_lib_save_named_frame: '%s'\n", l_tmpname);
@@ -2296,9 +2437,9 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
          }
          
          if(0 == gap_lib_file_copy(l_tmpname, sav_name))
-	 {
-	    g_remove(l_tmpname);
-	 }
+         {
+            g_remove(l_tmpname);
+         }
          else
          {
             printf("ERROR in gap_lib_save_named_frame: can't rename %s to %s\n"
@@ -2337,7 +2478,7 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
 
   return l_rc;
 
-}	/* end gap_lib_save_named_frame */
+}       /* end gap_lib_save_named_frame */
 
 
 /* ============================================================================
@@ -2378,7 +2519,7 @@ p_save_old_frame(GapAnimInfo *ainfo_ptr, GapVinVideoInfo *vin_ptr)
     }
   }
   return 0;
-}	/* end p_save_old_frame */
+}       /* end p_save_old_frame */
 
 
 
@@ -2422,9 +2563,9 @@ gap_lib_load_image (char *lod_name)
   if(gap_debug) printf("DEBUG: before   gap_lib_load_image: '%s'\n", l_tmpname);
 
   l_tmp_image_id = gimp_file_load(GIMP_RUN_NONINTERACTIVE,
-		l_tmpname,
-		l_tmpname  /* raw name ? */
-		);
+                l_tmpname,
+                l_tmpname  /* raw name ? */
+                );
 
   if(gap_debug) printf("DEBUG: after    gap_lib_load_image: '%s' id=%d\n\n",
                                l_tmpname, (int)l_tmp_image_id);
@@ -2438,7 +2579,7 @@ gap_lib_load_image (char *lod_name)
 
   return l_tmp_image_id;
 
-}	/* end gap_lib_load_image */
+}       /* end gap_lib_load_image */
 
 
 
@@ -2505,7 +2646,7 @@ gap_lib_load_named_frame (gint32 old_image_id, char *lod_name)
 
    printf("GAP: Error: PDB call of gimp_displays_reconnect failed\n");
    return (-1);
-}	/* end gap_lib_load_named_frame */
+}       /* end gap_lib_load_named_frame */
 
 
 
@@ -2660,7 +2801,7 @@ gap_lib_replace_image(GapAnimInfo *ainfo_ptr)
   }
 
   return(image_id);
-}	/* end gap_lib_replace_image */
+}       /* end gap_lib_replace_image */
 
 
 
@@ -3159,115 +3300,3 @@ gap_vid_edit_paste(GimpRunMode run_mode, gint32 image_id, long paste_mode)
 }       /* end gap_vid_edit_paste */
 
 
-/* --------------------------------
- * gap_lib_fprintf_gdouble
- * --------------------------------
- * print prefix and gdouble value to file
- * (always use "." as decimalpoint, independent of LOCALE language settings)
- */
-void
-gap_lib_fprintf_gdouble(FILE *fp, gdouble value, gint digits, gint precision_digits, const char *pfx)
-{
-  gchar l_dbl_str[G_ASCII_DTOSTR_BUF_SIZE];
-  gchar l_fmt_str[20];
-  gint  l_len;
-
-  g_snprintf(l_fmt_str, sizeof(l_fmt_str), "%%.%df", (int)precision_digits);
-  g_ascii_formatd(l_dbl_str, sizeof(l_dbl_str), l_fmt_str, value);
-
-  fprintf(fp, "%s", pfx);
-
-  /* make leading blanks */
-  l_len = strlen(l_dbl_str) - (digits + 1 +  precision_digits);
-  while(l_len < 0)
-  {
-    fprintf(fp, " ");
-    l_len++;
-  }
-  fprintf(fp, "%s", l_dbl_str);
-}  /* end gap_lib_fprintf_gdouble */
-
-
-/* ============================================================================
- * gap_lib_sscan_flt_numbers
- * ============================================================================
- * scan the blank separated buffer for 2 integer and 13 float numbers.
- * always use "." as decimalpoint in the float numbers regardless to LANGUAGE settings
- * return a counter that tells how many numbers were scanned successfully
- */
-gint
-gap_lib_sscan_flt_numbers(gchar   *buf
-                  , gdouble *farr
-		  , gint     farr_max
-		  )
-{
-  gint  l_cnt;
-  gchar *nptr;
-  gchar *endptr;
-
-  l_cnt =0;
-  nptr  = buf;
-  while(l_cnt < farr_max)
-  {
-    endptr = nptr;
-    farr[l_cnt] = g_ascii_strtod(nptr, &endptr);
-    if(nptr == endptr)
-    {
-      break;  /* pointer was not advanced because no valid floatnumber was scanned */
-    }
-    nptr = endptr;
-
-    l_cnt++;  /* count successful scans */
-  }
-
-  return (l_cnt);
-}  /* end gap_lib_sscan_flt_numbers */
-
-
-/* --------------------------------
- * gap_lib_check_tooltips
- * --------------------------------
- * check and enable/disable tooltips according to global gimprc settings
- */
-gboolean
-gap_lib_check_tooltips(gboolean *old_state)
-{
-  char *value_string;
-  gboolean new_state;
-  gboolean changed;
-
-  new_state = TRUE;
-  changed = TRUE;
-  
-  value_string = gimp_gimprc_query("show-tooltips");
-  if(value_string != NULL)
-  {
-    if (strcmp(value_string, "no") == 0)
-    {
-       new_state = FALSE;
-    }
-  }
-  
-  if (old_state != NULL)
-  {
-    if(*old_state == new_state)
-    {
-      changed = FALSE;
-    }
-  }
-  
-  if (changed == TRUE)
-  {
-    if(new_state == TRUE)
-    {
-       gimp_help_enable_tooltips ();
-    }
-    else
-    {
-       gimp_help_disable_tooltips ();
-    }
-  }
-  
-  return (new_state);
-  
-}  /* end gap_lib_check_tooltips */
