@@ -49,9 +49,6 @@
 #include <gap_onion_dialog.h>
 
 
-static char *gap_onion_version = "2.1.0a; 2004/06/03";
-
-
 /* ------------------------
  * global gap DEBUG switch
  * ------------------------
@@ -67,9 +64,9 @@ GapOnionMainGlobalParams global_params;
 static void query(void);
 static void run(const gchar *name
               , gint n_params
-	      , const GimpParam *param
+              , const GimpParam *param
               , gint *nreturn_vals
-	      , GimpParam **return_vals);
+              , GimpParam **return_vals);
 
 GimpPlugInInfo PLUG_IN_INFO =
 {
@@ -151,8 +148,8 @@ query ()
                          " The configuration can be saved in the gimprc parameter file.",
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_onion_version,
-                         N_("<Image>/Video/Onionskin/Configuration..."),
+                         GAP_VERSION_WITH_DATE,
+                         N_("Configuration..."),
                          "RGB*, INDEXED*, GRAY*",
                          GIMP_PLUGIN,
                          nargs_onion_cfg, nreturn_vals,
@@ -169,8 +166,8 @@ query ()
                          " if no configuration is found, default settings are used",
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_onion_version,
-                         N_("<Image>/Video/Onionskin/Create or Replace"),
+                         GAP_VERSION_WITH_DATE,
+                         N_("Create or Replace"),
                          "RGB*, INDEXED*, GRAY*",
                          GIMP_PLUGIN,
                          nargs_onion_std, nreturn_vals,
@@ -184,8 +181,8 @@ query ()
                          " of the video.",
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_onion_version,
-                         N_("<Image>/Video/Onionskin/Delete"),
+                         GAP_VERSION_WITH_DATE,
+                         N_("Delete"),
                          "RGB*, INDEXED*, GRAY*",
                          GIMP_PLUGIN,
                          nargs_onion_std, nreturn_vals,
@@ -197,12 +194,25 @@ query ()
                          "This plugin sets visibility for all onionskin Layers in the current Videoframe.",
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_onion_version,
-                         N_("<Image>/Video/Onionskin/Toggle Visibility"),
+                         GAP_VERSION_WITH_DATE,
+                         N_("Toggle Visibility"),
                          "RGB*, INDEXED*, GRAY*",
                          GIMP_PLUGIN,
                          nargs_onion_visi, nreturn_vals,
                          args_onion_visi, return_vals);
+  {
+     /* Menu names */
+     const char *menupath_image_video = N_("<Image>/Video/");
+     const char *menupath_image_video_onionskin = N_("<Image>/Video/Onionskin/");
+ 
+     //gimp_plugin_menu_branch_register("<Image>", "Video");
+     //gimp_plugin_menu_branch_register("<Image>/Video", "Onionskin");
+
+     gimp_plugin_menu_register (GAP_PLUGIN_NAME_ONION_CFG, menupath_image_video_onionskin);
+     gimp_plugin_menu_register (GAP_PLUGIN_NAME_ONION_APPLY, menupath_image_video_onionskin);
+     gimp_plugin_menu_register (GAP_PLUGIN_NAME_ONION_DEL, menupath_image_video_onionskin);
+     gimp_plugin_menu_register (GAP_PLUGIN_NAME_ONION_VISI, menupath_image_video_onionskin);
+  }
 }       /* end query */
 
 
