@@ -41,6 +41,7 @@
 #include <libgimp/gimpui.h>
 
 #include "gap_player_main.h"
+#include "gap_player_cache.h"
 #include "gap_player_dialog.h"
 #include "gap_story_file.h"
 #include "gap_pview_da.h"
@@ -66,6 +67,7 @@ static GapPlayerMainGlobalParams global_params =
 , NULL        /* gchar        *imagename */
 , -1          /* gint32  imagewidth */
 , -1          /* gint32  imageheight */
+, 0.0         /* gdouble aspect_ratio */
 , NULL        /* GapAnimInfo *ainfo_ptr */
 , NULL        /* GapAnimInfo *stb_ptr */
 , NULL        /* t_GVA_Handle *gvahand */
@@ -190,6 +192,37 @@ static GapPlayerMainGlobalParams global_params =
 , NULL        /* cancel_vindex_button */
 , NULL        /* help_id */
 , FALSE       /* onion_delete */
+
+, NULL        /* cache_size_spinbutton_adj */
+, NULL        /* label_current_cache_values */
+, NULL        /* progress_bar_cache_usage */
+, GAP_PLAYER_CACHE_DEFAULT_MAX_BYTESIZE  /* max_player_cache */
+, GAP_PLAYER_CACHE_COMPRESSION_NONE      /* cache_compression */
+, 0.86                                   /* cache_jpeg_quality */
+
+, TRUE        /* show_go_buttons */
+, TRUE        /* show_position_scale */
+, NULL        /* show_go_buttons_checkbutton */
+, NULL        /* show_position_scale_checkbutton */
+, NULL        /* gobutton_hbox */
+, NULL        /* frame_scale_hbox */
+, GAP_STB_FLIP_NONE  /* flip_request */
+, GAP_STB_FLIP_NONE  /* flip_status */
+, 1                  /* stb_in_track */
+,-1                  /* stb_parttype */
+,-1                  /* stb_unique_id */
+, NULL               /* stb_comp_vidhand */
+
+, FALSE               /* audio_auto_offset_by_framenr */
+, 1                   /* audio_otone_atrack */
+, NULL                /* GtkWidget *audio_auto_offset_by_framenr_checkbutton */
+, NULL                /* GtkWidget *audio_otone_extract_button */
+, NULL                /* GtkWidget *audio_otone_atrack_spinbutton */
+, NULL                /* GtkObject *audio_otone_atrack_spinbutton_adj */
+, NULL                /* GtkWidget *progress_bar_audio */
+, NULL                /* GtkWidget *audio_enable_checkbutton */
+
+, NULL                /* GapDrawableVideoRef  *dvref_ptr */
 };
 
 
@@ -334,16 +367,16 @@ run (const gchar *name,          /* name of plugin */
           gpp->pv_pixelsize = MAX(gpp->pv_width, gpp->pv_height);
           
           gpp->audio_enable         = (gboolean) param[14].data.d_int32;
-	  if(param[15].data.d_string)
-	  {
+          if(param[15].data.d_string)
+          {
             g_snprintf(gpp->audio_filename, sizeof(gpp->audio_filename), "%s"
-	              , param[15].data.d_string);
-	  }
-	  else
-	  {
+                      , param[15].data.d_string);
+          }
+          else
+          {
             gpp->audio_filename[0] = '\0';
-	    gpp->audio_enable = FALSE;
-	  }
+            gpp->audio_enable = FALSE;
+          }
           gpp->audio_frame_offset   = (gint) param[16].data.d_int32;
           gpp->audio_volume         = (gdouble) param[17].data.d_float;
       }
@@ -383,4 +416,4 @@ run (const gchar *name,          /* name of plugin */
       gimp_set_data (PLUG_IN_NAME, gpp, sizeof (GapPlayerMainGlobalParams));
   }
   values[0].data.d_status = status;
-}	/* end run */
+}       /* end run */
