@@ -38,6 +38,9 @@
 #include <libgimp/gimpui.h>
 #include "gap_pview_da.h"
 #include "gap_story_file.h"
+#include "gap_player_cache.h"
+#include "gap_story_render_types.h"
+#include "gap_drawable_vref_parasite.h"
 
 #ifdef GAP_ENABLE_VIDEOAPI_SUPPORT
 #include "gap_vid_api.h"
@@ -66,6 +69,8 @@ typedef struct GapPlayerAddClip {
 /* Function Typedefs */
 typedef  void           (*GapPlayerSetRangeFptr)(GapPlayerAddClip *plac_ptr);
 
+#define GAP_PLAYER_DONT_FORCE_ASPECT 0.0
+
 typedef struct GapPlayerMainGlobalParams {
   gboolean     standalone_mode;
   GimpRunMode  run_mode;
@@ -73,6 +78,7 @@ typedef struct GapPlayerMainGlobalParams {
   gchar        *imagename;
   gint32       imagewidth;
   gint32       imageheight;
+  gdouble      aspect_ratio;  /* 0.0 use original size, else force aspect  */
 
   GapAnimInfo *ainfo_ptr;
   GapStoryBoard *stb_ptr;
@@ -208,8 +214,53 @@ typedef struct GapPlayerMainGlobalParams {
   
   gboolean    onion_delete;
   
+  /* player cache settings */
+  GtkObject *cache_size_spinbutton_adj;
+  GtkWidget *label_current_cache_values;
+  GtkWidget *progress_bar_cache_usage;
+
+  gint32     max_player_cache;    /* max bytesize to use for caching frames 
+                                   * (at pview widget size) 
+                                   * a value of 0 turns cahing OFF
+                                   */
+  GapPlayerCacheCompressionType cache_compression;
+  gdouble                       cache_jpeg_quality;
+  
+  /* layout options */
+  gboolean show_go_buttons;
+  gboolean show_position_scale;
+  GtkWidget *show_go_buttons_checkbutton;
+  GtkWidget *show_position_scale_checkbutton;
+  GtkWidget *gobutton_hbox;
+  GtkWidget *frame_scale_hbox;
+  
+  /* flags to trigger built in transformations */
+  gint32 flip_request;
+  gint32 flip_status;
+  gint32 stb_in_track;
+  
+  /* for playback of storyboard composite video */
+  gint32 stb_parttype;
+  gint32 stb_unique_id;
+  GapStoryRenderVidHandle *stb_comp_vidhand;
+
+  /* audio otone extract stuff */
+  gboolean  audio_auto_offset_by_framenr;
+  gint32    audio_otone_atrack;
+
+  GtkWidget *audio_auto_offset_by_framenr_checkbutton;
+  GtkWidget *audio_otone_extract_button;
+  GtkWidget *audio_otone_atrack_spinbutton;
+  GtkObject *audio_otone_atrack_spinbutton_adj;
+
+  GtkWidget *progress_bar_audio;
+  GtkWidget *audio_enable_checkbutton;
+
+  GapDrawableVideoRef  *dvref_ptr;
+  
 } GapPlayerMainGlobalParams;
 
+#define GAP_PLAYER_MAIN_AUSTAT_UNCHECKED       -1
 #define GAP_PLAYER_MAIN_AUSTAT_NONE             0
 #define GAP_PLAYER_MAIN_AUSTAT_SERVER_STARTED   1
 #define GAP_PLAYER_MAIN_AUSTAT_FILENAME_SET     2
