@@ -125,10 +125,10 @@ gint  gap_debug = 0;  /* 0.. no debug, 1 .. print debug messages */
  */
 static void
 p_delta_gdouble (gdouble  *val,
-		 gdouble   val_from,
-		 gdouble   val_to,
-		 gint32   total_steps,
-		 gdouble  current_step)
+                 gdouble   val_from,
+                 gdouble   val_to,
+                 gint32   total_steps,
+                 gdouble  current_step)
 {
     gdouble     delta;
 
@@ -140,10 +140,10 @@ p_delta_gdouble (gdouble  *val,
 
 static void
 p_delta_gint32 (gint32  *val,
-		 gint32   val_from,
-		 gint32   val_to,
-		 gint32   total_steps,
-		 gdouble  current_step)
+                 gint32   val_from,
+                 gint32   val_to,
+                 gint32   total_steps,
+                 gdouble  current_step)
 {
     gdouble     delta;
 
@@ -163,10 +163,10 @@ gint32
 p_gimp_levels (gint32 drawable_id,
                gint32 channel,
                gint32 low_input,
-	       gint32 high_input,
-	       gdouble gamma,
-	       gint32 low_output,
-	       gint32 high_output
+               gint32 high_input,
+               gdouble gamma,
+               gint32 low_output,
+               gint32 high_output
                    )
 {
    static char     *l_procname = "gimp_levels";
@@ -192,7 +192,7 @@ p_gimp_levels (gint32 drawable_id,
    gimp_destroy_params(return_vals, nreturn_vals);
    printf("Error: PDB call of %s failed status:%d\n", l_procname, (int)return_vals[0].data.d_status);
    return(-1);
-}	/* end p_gimp_levels */
+}       /* end p_gimp_levels */
 
 static void
 p_run_levels_tool(gint32 drawable_id, wr_levels_val_t *cuvals)
@@ -260,11 +260,11 @@ query (void)
   /* the actual installation of the bend plugin */
   gimp_install_procedure (PLUG_IN_NAME,
                           PLUG_IN_DESCRIPTION,
-  			 "This Plugin is a wrapper to call the GIMP Levels Color Tool (gimp_levels)"
-			 " it has a simplified Dialog (without preview) where you can enter the parameters"
-			 " this wrapper is useful for animated filtercalls and provides "
-			 " a PDB interface that runs in GIMP_RUN_WITH_LAST_VALUES mode"
-			 " and also provides an Iterator Procedure for animated calls"
+                         "This Plugin is a wrapper to call the GIMP Levels Color Tool (gimp_levels)"
+                         " it has a simplified Dialog (without preview) where you can enter the parameters"
+                         " this wrapper is useful for animated filtercalls and provides "
+                         " a PDB interface that runs in GIMP_RUN_WITH_LAST_VALUES mode"
+                         " and also provides an Iterator Procedure for animated calls"
                           ,
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
@@ -303,7 +303,7 @@ query (void)
 }
 
 
-static void  
+static void
 run(const gchar *name
            , gint nparams
            , const GimpParam *param
@@ -320,6 +320,13 @@ run(const gchar *name
   /* Get the runmode from the in-parameters */
   GimpRunMode run_mode = param[0].data.d_int32;
 
+
+  if(gap_debug)
+  {
+    printf("START plug-in-wr-color-levels\n");
+  }
+
+
   /* status variable, use it to check for errors in invocation usualy only
      during non-interactive calling */
   GimpPDBStatusType status = GIMP_PDB_SUCCESS;
@@ -417,11 +424,11 @@ run(const gchar *name
            wcd->show_progress = FALSE;
 
            l_cuvals.channel  = param[3].data.d_int32;
-           l_cuvals.low_input  = param[3].data.d_int32;
-           l_cuvals.high_input  = param[3].data.d_int32;
-           l_cuvals.gamma = param[4].data.d_float;
-           l_cuvals.low_output  = param[3].data.d_int32;
-           l_cuvals.high_output  = param[3].data.d_int32;
+           l_cuvals.low_input  = param[4].data.d_int32;
+           l_cuvals.high_input  = param[5].data.d_int32;
+           l_cuvals.gamma = param[6].data.d_float;
+           l_cuvals.low_output  = param[7].data.d_int32;
+           l_cuvals.high_output  = param[8].data.d_int32;
         }
         else
         {
@@ -452,16 +459,16 @@ run(const gchar *name
      /* Run the main function */
      if(wcd->run)
      {
-	gimp_image_undo_group_start (l_image_id);
-	p_run_levels_tool(l_drawable_id, &l_cuvals);
+        gimp_image_undo_group_start (l_image_id);
+        p_run_levels_tool(l_drawable_id, &l_cuvals);
         l_handled_drawable_id = l_drawable_id;
-	gimp_image_undo_group_end (l_image_id);
+        gimp_image_undo_group_end (l_image_id);
 
-	/* Store variable states for next run */
-	if (run_mode == GIMP_RUN_INTERACTIVE)
-	{
-	  gimp_set_data(PLUG_IN_NAME, &l_cuvals, sizeof(l_cuvals));
-	}
+        /* Store variable states for next run */
+        if (run_mode == GIMP_RUN_INTERACTIVE)
+        {
+          gimp_set_data(PLUG_IN_NAME, &l_cuvals, sizeof(l_cuvals));
+        }
      }
      else
      {
@@ -478,7 +485,7 @@ run(const gchar *name
   values[0].data.d_status = status;
   values[1].data.d_int32 = l_handled_drawable_id;   /* return the id of handled layer */
 
-}	/* end run */
+}       /* end run */
 
 
 /*
@@ -525,10 +532,10 @@ wr_levels_response (GtkWidget *widget,
     case GTK_RESPONSE_OK:
       if(wcd)
       {
-	if (GTK_WIDGET_VISIBLE (wcd->shell))
-	  gtk_widget_hide (wcd->shell);
+        if (GTK_WIDGET_VISIBLE (wcd->shell))
+          gtk_widget_hide (wcd->shell);
 
-	wcd->run = TRUE;
+        wcd->run = TRUE;
       }
 
     default:
@@ -536,11 +543,11 @@ wr_levels_response (GtkWidget *widget,
       if(wcd)
       {
         dialog = wcd->shell;
-	if(dialog)
-	{
+        if(dialog)
+        {
           wcd->shell = NULL;
           gtk_widget_destroy (dialog);
-	}
+        }
       }
       gtk_main_quit ();
       break;
@@ -596,7 +603,7 @@ do_dialog (wr_levels_val_t *cuvals)
   /*  The dialog1 and main vbox  */
   dialog1 = gimp_dialog_new (_("Color Levels"), "levels_wrapper",
                                NULL, 0,
-			       gimp_standard_help_func, PLUG_IN_HELP_ID, 
+                               gimp_standard_help_func, PLUG_IN_HELP_ID,
 
                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                GTK_STOCK_OK,     GTK_RESPONSE_OK,
@@ -605,14 +612,14 @@ do_dialog (wr_levels_val_t *cuvals)
 
 
   g_signal_connect (G_OBJECT (dialog1), "response",
-		    G_CALLBACK (wr_levels_response),
-		    wcd);
+                    G_CALLBACK (wr_levels_response),
+                    wcd);
 
   /* the vbox */
   vbox = gtk_vbox_new (FALSE, 2);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog1)->vbox), vbox,
-		      TRUE, TRUE, 0);
+                      TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
   dialog_vbox1 = GTK_DIALOG (dialog1)->vbox;
@@ -713,21 +720,21 @@ do_dialog (wr_levels_val_t *cuvals)
 
 
   /* SPINBUTTONS */
-  spinbutton_low_input_adj = gtk_adjustment_new (0, 0, 255, 1, 10, 10);
+  spinbutton_low_input_adj = gtk_adjustment_new (0, 0, 255, 1, 10, 0);
   spinbutton_low_input = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_low_input_adj), 1, 0);
   gtk_widget_show (spinbutton_low_input);
   gtk_table_attach (GTK_TABLE (table1), spinbutton_low_input, 1, 2, 1, 2,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  spinbutton_high_input_adj = gtk_adjustment_new (255, 0, 255, 1, 10, 10);
+  spinbutton_high_input_adj = gtk_adjustment_new (255, 0, 255, 1, 10, 0);
   spinbutton_high_input = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_high_input_adj), 1, 0);
   gtk_widget_show (spinbutton_high_input);
   gtk_table_attach (GTK_TABLE (table1), spinbutton_high_input, 1, 2, 2, 3,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  spinbutton_gamma_adj = gtk_adjustment_new (1, 0.1, 10, 0.1, 1, 10);
+  spinbutton_gamma_adj = gtk_adjustment_new (1, 0.1, 10, 0.1, 1, 0);
   spinbutton_gamma = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_gamma_adj), 0.1, 2);
   gtk_widget_show (spinbutton_gamma);
   gtk_table_attach (GTK_TABLE (table1), spinbutton_gamma, 1, 2, 3, 4,
@@ -735,14 +742,14 @@ do_dialog (wr_levels_val_t *cuvals)
                     (GtkAttachOptions) (0), 0, 0);
 
 
-  spinbutton_low_output_adj = gtk_adjustment_new (0, 0, 255, 1, 10, 10);
+  spinbutton_low_output_adj = gtk_adjustment_new (0, 0, 255, 1, 10, 0);
   spinbutton_low_output = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_low_output_adj), 1, 0);
   gtk_widget_show (spinbutton_low_output);
   gtk_table_attach (GTK_TABLE (table1), spinbutton_low_output, 1, 2, 4, 5,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
 
-  spinbutton_high_output_adj = gtk_adjustment_new (255, 0, 255, 1, 10, 10);
+  spinbutton_high_output_adj = gtk_adjustment_new (255, 0, 255, 1, 10, 0);
   spinbutton_high_output = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_high_output_adj), 1, 0);
   gtk_widget_show (spinbutton_high_output);
   gtk_table_attach (GTK_TABLE (table1), spinbutton_high_output, 1, 2, 5, 6,
