@@ -41,6 +41,7 @@
 
 
 /* Defines */
+#define PLUG_IN_NAME_ANY    "plug_in_wr_layer_rotate_any"
 #define PLUG_IN_NAME_180    "plug_in_wr_layer_rotate_180"
 #define PLUG_IN_NAME_90     "plug_in_wr_layer_rotate_90"
 #define PLUG_IN_NAME_270    "plug_in_wr_layer_rotate_270"
@@ -50,6 +51,10 @@
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
 
+#define PLUG_IN_BINARY  "gap_wr_trans"
+
+#define SCALE_WIDTH  200
+
 typedef enum
 {
    GAP_TRANS_UNDEFINED
@@ -58,16 +63,17 @@ typedef enum
   ,GAP_TRANS_ROT_90
   ,GAP_TRANS_ROT_180
   ,GAP_TRANS_ROT_270
+  ,GAP_TRANS_ROT_ANY
 } GapTransLayerMode;
 
 
 typedef struct {
-  gint32  dummy;
+  gdouble  angle_deg;
 } TransValues;
 
 static TransValues glob_vals =
 {
-  0           /* dummy */
+  0.0           /* rotation angle in degree */
 };
 
 static void  iter_query ();
@@ -78,7 +84,8 @@ static void  run (const gchar *name,          /* name of plugin */
      gint *nreturn_vals,         /* number of out-parameters */
      GimpParam ** return_vals);  /* out-parameters */
 
-static gint32 p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_mode);
+static gint32 p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_mode, TransValues *val_ptr);
+static gboolean p_dialog(GapTransLayerMode trans_mode, TransValues *val_ptr);
 
 
 /* Global Variables */
@@ -114,14 +121,25 @@ MAIN ()
 static void query (void)
 {
 
+  static GimpLastvalDef lastvalsRotAny[] =
+  {
+    GIMP_LASTVALDEF_GDOUBLE          (GIMP_ITER_TRUE,  glob_vals.angle_deg,  "angle in degree"),
+  };
+
   static GimpLastvalDef lastvals[] =
   {
-    GIMP_LASTVALDEF_GINT32          (GIMP_ITER_FALSE,  glob_vals.dummy,  "dummy"),
+    GIMP_LASTVALDEF_GDOUBLE          (GIMP_ITER_FALSE,  glob_vals.angle_deg,  "dummy"),
   };
 
   gimp_plugin_domain_register (GETTEXT_PACKAGE, LOCALEDIR);
 
   /* registration for last values buffer structure (useful for animated filter apply) */
+  gimp_lastval_desc_register(PLUG_IN_NAME_ANY,
+                             &glob_vals,
+                             sizeof(glob_vals),
+                             G_N_ELEMENTS (lastvalsRotAny),
+                             lastvalsRotAny);
+
   gimp_lastval_desc_register(PLUG_IN_NAME_90,
                              &glob_vals,
                              sizeof(glob_vals),
@@ -240,6 +258,23 @@ static void query (void)
                           global_number_out_args,
                           in_args,
                           NULL);
+
+  gimp_install_procedure (PLUG_IN_NAME_ANY,
+                          "Rotate Layer by specified angle in degree",
+                          "This plug-in is a wrapper for gimp rotate functionality, "
+                          "and provides the typical PDB interface for calling it as "
+                          "filter in animations."
+                          "(for the use with GAP Video Frame manipulation)",
+                          PLUG_IN_AUTHOR,
+                          PLUG_IN_COPYRIGHT,
+                          GAP_VERSION_WITH_DATE,
+                          N_("Rotate any angle"),
+                          PLUG_IN_IMAGE_TYPES,
+                          GIMP_PLUGIN,
+                          global_number_in_args,
+                          global_number_out_args,
+                          in_args,
+                          NULL);
   {
     /* Menu names */
     const char *menupath_image_video_layer_transform = N_("<Image>/Video/Layer/Transform/");
@@ -253,6 +288,7 @@ static void query (void)
     gimp_plugin_menu_register (PLUG_IN_NAME_90,  menupath_image_video_layer_transform);
     gimp_plugin_menu_register (PLUG_IN_NAME_180, menupath_image_video_layer_transform);
     gimp_plugin_menu_register (PLUG_IN_NAME_270, menupath_image_video_layer_transform);
+    gimp_plugin_menu_register (PLUG_IN_NAME_ANY, menupath_image_video_layer_transform);
   }
 }  /* end query */
 
@@ -329,34 +365,78 @@ run (const gchar *name,          /* name of plugin */
   {
     trans_mode = GAP_TRANS_ROT_270;
   }
+
+  if (strcmp (name, PLUG_IN_NAME_ANY) == 0)
+  {
+    trans_mode = GAP_TRANS_ROT_ANY;
+  }
   
   if(trans_mode != GAP_TRANS_UNDEFINED)
   {
     if(gimp_drawable_is_layer(drawable_id))
     {
+      gboolean run_flag;
+      
+      /* Initial values */
+      glob_vals.angle_deg = 0;
+      run_flag = TRUE;
+
+      /* Possibly retrieve data from a previous run */
+      gimp_get_data (name, &glob_vals);
+      
+      switch (run_mode)
+       {
+        case GIMP_RUN_INTERACTIVE:
+ 
+          /* Get information from the dialog */
+          run_flag = p_dialog(trans_mode, &glob_vals);
+          break;
+
+        case GIMP_RUN_NONINTERACTIVE:
+          /* check to see if invoked with the correct number of parameters */
+          if (nparams >= 4)
+          {
+             glob_vals.angle_deg = param[3].data.d_float;
+          }
+          else
+          {
+            status = GIMP_PDB_CALLING_ERROR;
+          }
+          break;
+
+        case GIMP_RUN_WITH_LAST_VALS:
+          break;
+
+        default:
+          break;
+      }
+
+
+
       /* here the action starts, we transform the drawable */
       trans_drawable_id = p_transform_layer(image_id
                                            , drawable_id
-					   , trans_mode
-					   );
+                                           , trans_mode
+                                           , &glob_vals
+                                           );
       if (trans_drawable_id < 0)
       {
-	 status = GIMP_PDB_CALLING_ERROR;
+         status = GIMP_PDB_CALLING_ERROR;
       }
       else
       {
          values[1].data.d_drawable = drawable_id;
 
-	 /* Store variable states for next run
-	  * (the parameters for the transform wrapper plugins are stored
-	  *  even if they contain just a dummy
-	  *  this is done to fullfill the GIMP-GAP LAST_VALUES conventions
-	  *  for filtermacro and animated calls)
-	  */
-	 if (run_mode == GIMP_RUN_INTERACTIVE)
-	 {
-	   gimp_set_data (name, &glob_vals, sizeof (TransValues));
-	 }
+         /* Store variable states for next run
+          * (the parameters for the transform wrapper plugins are stored
+          *  even if they contain just a dummy
+          *  this is done to fullfill the GIMP-GAP LAST_VALUES conventions
+          *  for filtermacro and animated calls)
+          */
+         if (run_mode == GIMP_RUN_INTERACTIVE)
+         {
+           gimp_set_data (name, &glob_vals, sizeof (TransValues));
+         }
       }
     }
     else
@@ -365,9 +445,9 @@ run (const gchar *name,          /* name of plugin */
        if (run_mode == GIMP_RUN_INTERACTIVE)
        {
          g_message(_("The plug-in %s\noperates only on layers\n"
-	             "(but was called on mask or channel)")
-	          , name
-		  );
+                     "(but was called on mask or channel)")
+                  , name
+                  );
        }
     }
  
@@ -385,7 +465,7 @@ run (const gchar *name,          /* name of plugin */
 
   }
   values[0].data.d_status = status;
-}	/* end run */
+}       /* end run */
 
 
 
@@ -394,7 +474,7 @@ run (const gchar *name,          /* name of plugin */
  * --------------------------
  */
 static gint32
-p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_mode)
+p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_mode, TransValues *val_ptr)
 {
   gboolean auto_center;
   gboolean clip_result;
@@ -414,7 +494,7 @@ p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_m
     
   center_x = gimp_drawable_width(drawable_id) / 2;
   center_y = gimp_drawable_height(drawable_id) / 2;
-  if(has_selection)
+  if(non_empty)
   {
     sav_selection_id = gimp_selection_save(image_id);
   }
@@ -432,57 +512,76 @@ p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_m
       axis = (gdouble)(gimp_drawable_width(drawable_id)) / 2.0;
       trans_drawable_id = gimp_drawable_transform_flip_simple(drawable_id
                                    ,GIMP_ORIENTATION_HORIZONTAL
-				   ,auto_center
-				   ,axis
-				   ,clip_result
-				   );
+                                   ,auto_center
+                                   ,axis
+                                   ,clip_result
+                                   );
       break;
     case GAP_TRANS_FLIP_VER:
       clip_result = TRUE;
       axis = (gdouble)(gimp_drawable_height(drawable_id)) / 2.0;
       trans_drawable_id = gimp_drawable_transform_flip_simple(drawable_id
                                    ,GIMP_ORIENTATION_VERTICAL
-				   ,auto_center
-				   ,axis
-				   ,clip_result
-				   );
+                                   ,auto_center
+                                   ,axis
+                                   ,clip_result
+                                   );
       break;
     case GAP_TRANS_ROT_90:
       clip_result = FALSE;
       trans_drawable_id = gimp_drawable_transform_rotate_simple(drawable_id
                                   ,GIMP_ROTATE_90
-				  ,auto_center
-				  ,center_x
-				  ,center_y
-				  ,clip_result
-				  );
+                                  ,auto_center
+                                  ,center_x
+                                  ,center_y
+                                  ,clip_result
+                                  );
       break;
     case GAP_TRANS_ROT_180:
       clip_result = FALSE;
       trans_drawable_id = gimp_drawable_transform_rotate_simple(drawable_id
                                   ,GIMP_ROTATE_180
-				  ,auto_center
-				  ,center_x
-				  ,center_y
-				  ,clip_result
-				  );
+                                  ,auto_center
+                                  ,center_x
+                                  ,center_y
+                                  ,clip_result
+                                  );
       break;
     case GAP_TRANS_ROT_270:
       clip_result = FALSE;
       trans_drawable_id = gimp_drawable_transform_rotate_simple(drawable_id
                                   ,GIMP_ROTATE_270
-				  ,auto_center
-				  ,center_x
-				  ,center_y
-				  ,clip_result
-				  );
+                                  ,auto_center
+                                  ,center_x
+                                  ,center_y
+                                  ,clip_result
+                                  );
+      break;
+    case GAP_TRANS_ROT_ANY:
+      {
+         gdouble          l_angle_rad;
+
+         clip_result = FALSE;
+         l_angle_rad = (val_ptr->angle_deg * G_PI) / 180.0;
+
+         trans_drawable_id = gimp_drawable_transform_rotate_default(drawable_id
+                                                      , l_angle_rad
+                                                      , FALSE            /* auto_center */
+                                                      , center_x
+                                                      , center_y
+                                                      , TRUE             /* interpolation (TRUE use default interpolation) */
+                                                      , clip_result
+                                                      );
+
+
+      }  /* end gap_pdb_gimp_rotate_degree */
       break;
     default:
       break;
   }
   
       
-  if((has_selection)
+  if((non_empty)
   && (sav_selection_id >= 0))
   {
     /* if there was a selection, the transform (flip or simple rotate) operation
@@ -500,7 +599,7 @@ p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_m
 
     gimp_selection_load(sav_selection_id);
     gimp_image_remove_channel(image_id, sav_selection_id);
-    gimp_drawable_delete(sav_selection_id);
+    //gimp_drawable_delete(sav_selection_id);
   }
 
   gimp_image_undo_group_end(image_id);
@@ -508,3 +607,76 @@ p_transform_layer(gint32 image_id, gint32 drawable_id, GapTransLayerMode trans_m
   return (trans_drawable_id);
 
 }  /* end p_transform_layer */
+
+
+
+/* --------------------------
+ * p_dialog
+ * --------------------------
+ */
+static gboolean
+p_dialog (GapTransLayerMode trans_mode, TransValues *val_ptr)
+{
+  GtkWidget *dialog;
+  GtkWidget *main_vbox;
+  GtkWidget *preview;
+  GtkWidget *table;
+  GtkObject *adj;
+  gboolean   run;
+
+  if(trans_mode != GAP_TRANS_ROT_ANY)
+  {
+    /* all other modes have no dialog and shall run immediate when invoked */
+    return (TRUE);
+  }
+
+  gimp_ui_init (PLUG_IN_BINARY, TRUE);
+
+  dialog = gimp_dialog_new (_("Rotate any angle"), PLUG_IN_BINARY,
+                            NULL, 0,
+                            gimp_standard_help_func, PLUG_IN_NAME_ANY,
+
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK,     GTK_RESPONSE_OK,
+
+                            NULL);
+
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_OK,
+                                           GTK_RESPONSE_CANCEL,
+                                           -1);
+
+  gimp_window_set_transient (GTK_WINDOW (dialog));
+
+  main_vbox = gtk_vbox_new (FALSE, 12);
+  gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), main_vbox);
+  gtk_widget_show (main_vbox);
+
+
+  /* Controls */
+  table = gtk_table_new (3, 3, FALSE);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+  gtk_box_pack_start (GTK_BOX (main_vbox), table, FALSE, FALSE, 0);
+  gtk_widget_show (table);
+
+  adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 0,
+                              _("Rotate angle:"), SCALE_WIDTH, 7,
+                              val_ptr->angle_deg, -3600.0, 3600.0, 1.0, 15.0, 2,
+                              TRUE, 0, 0,
+                              NULL, NULL);
+  g_signal_connect (adj, "value-changed",
+                    G_CALLBACK (gimp_double_adjustment_update),
+                    &val_ptr->angle_deg);
+
+  /* Done */
+
+  gtk_widget_show (dialog);
+
+  run = (gimp_dialog_run (GIMP_DIALOG (dialog)) == GTK_RESPONSE_OK);
+
+  gtk_widget_destroy (dialog);
+
+  return run;
+}  /* end p_dialog */
