@@ -101,21 +101,21 @@ static t_GVA_RetCode             p_gva_worker_get_next_frame(t_GVA_Handle  *gvah
 static t_GVA_RetCode             p_gva_worker_seek_frame(t_GVA_Handle  *gvahand, gdouble pos, t_GVA_PosUnit pos_unit);
 static t_GVA_RetCode             p_gva_worker_seek_audio(t_GVA_Handle  *gvahand, gdouble pos, t_GVA_PosUnit pos_unit);
 static t_GVA_RetCode             p_gva_worker_get_audio(t_GVA_Handle  *gvahand
-        			    ,gint16 *output_i            /* preallocated buffer large enough for samples * siezeof gint16 */
-        			    ,gint32 channel              /* audiochannel 1 upto n */
-        			    ,gdouble samples             /* number of samples to read */
-        			    ,t_GVA_AudPos mode_flag      /* specify the position where to start reading audio from */
-        			    );
+                                    ,gint16 *output_i            /* preallocated buffer large enough for samples * siezeof gint16 */
+                                    ,gint32 channel              /* audiochannel 1 upto n */
+                                    ,gdouble samples             /* number of samples to read */
+                                    ,t_GVA_AudPos mode_flag      /* specify the position where to start reading audio from */
+                                    );
 static t_GVA_RetCode             p_gva_worker_count_frames(t_GVA_Handle  *gvahand);
 static t_GVA_RetCode             p_gva_worker_get_video_chunk(t_GVA_Handle  *gvahand
-                        	    , gint32 frame_nr
-                        	    , unsigned char *chunk
-                        	    , gint32 *size
-                        	    , gint32 max_size);
+                                    , gint32 frame_nr
+                                    , unsigned char *chunk
+                                    , gint32 *size
+                                    , gint32 max_size);
 static t_GVA_Handle *            p_gva_worker_open_read(const char *filename, gint32 vid_track, gint32 aud_track
-                		    ,const char *preferred_decoder
-                		    ,gboolean disable_mmx
-                		    );
+                                    ,const char *preferred_decoder
+                                    ,gboolean disable_mmx
+                                    );
 
 /* ---------------------------
  * GVA_percent_2_frame
@@ -777,7 +777,14 @@ p_guess_total_frames(t_GVA_Handle *gvahand)
  * p_register_all_decoders
  * ---------------------------
  * build the GVA_global_decoder_list
- * with one element for each available decoder
+ * with one element for each available decoder.
+ *
+ * in case the caller does not specifiy a prefered_decoder
+ * the order of registered decoders is relevant, because
+ * the 1st one that can handle the video is picked at open.
+ *
+ * This is typical the last one that is added to begin of the list
+ * (currently ffmpeg)
  */
 static void
 p_register_all_decoders(void)
@@ -805,9 +812,8 @@ p_register_all_decoders(void)
   }
 #endif
 
-#ifdef ENABLE_GVA_LIBAVFORMAT
-  p_ffmpeg_init();
-  dec_elem = p_ffmpeg_new_dec_elem();
+#ifdef ENABLE_GVA_LIBMPEG3
+  dec_elem = p_mpeg3_new_dec_elem();
   if(dec_elem)
   {
      dec_elem->next = GVA_global_decoder_list;
@@ -815,8 +821,9 @@ p_register_all_decoders(void)
   }
 #endif
 
-#ifdef ENABLE_GVA_LIBMPEG3
-  dec_elem = p_mpeg3_new_dec_elem();
+#ifdef ENABLE_GVA_LIBAVFORMAT
+  p_ffmpeg_init();
+  dec_elem = p_ffmpeg_new_dec_elem();
   if(dec_elem)
   {
      dec_elem->next = GVA_global_decoder_list;
@@ -862,8 +869,8 @@ p_gva_worker_close(t_GVA_Handle  *gvahand)
 
       if(gvahand->filename)
       {
-	 g_free(gvahand->filename);
-	 gvahand->filename = NULL;
+         g_free(gvahand->filename);
+         gvahand->filename = NULL;
       }
 
       /* free image buffer and row_pointers */
@@ -905,16 +912,16 @@ p_gva_worker_get_next_frame(t_GVA_Handle  *gvahand)
       if(fcache->fc_current)
       {
         /* if fcache framenumber is negative, we can reuse
-	 * that EMPTY element without advance
-	 */
+         * that EMPTY element without advance
+         */
         if(fcache->fc_current->framenumber >= 0)
-	{
+        {
           /* advance current write position to next element in the fcache ringlist */
           fcache->fc_current = fcache->fc_current->next;
           fcache->fc_current->framenumber = -1;
           gvahand->frame_data = fcache->fc_current->frame_data;
           gvahand->row_pointers = fcache->fc_current->row_pointers;
-	}
+        }
 
         /* CALL decoder specific implementation of GET_NEXT_FRAME procedure */
         l_rc = (*dec_elem->fptr_get_next_frame)(gvahand);
@@ -960,22 +967,22 @@ p_gva_worker_seek_frame(t_GVA_Handle  *gvahand, gdouble pos, t_GVA_PosUnit pos_u
       if(fcache->fc_current)
       {
         /* if fcache framenumber is negative, we can reuse
-	 * that EMPTY element without advance
-	 */
+         * that EMPTY element without advance
+         */
         if(fcache->fc_current->framenumber >= 0)
-	{
+        {
           /* advance current write position to next element in the fcache ringlist
-	   * Some of the seek procedure implementations do dummy reads
-	   * therefore we provide a fcache element, but leave the
-	   * framenumber -1 because this element is invalid in most cases
-	   */
+           * Some of the seek procedure implementations do dummy reads
+           * therefore we provide a fcache element, but leave the
+           * framenumber -1 because this element is invalid in most cases
+           */
           fcache->fc_current = fcache->fc_current->next;
           fcache->fc_current->framenumber = -1;
           gvahand->frame_data = fcache->fc_current->frame_data;
           gvahand->row_pointers = fcache->fc_current->row_pointers;
-	}
+        }
       }
-	
+        
       /* CALL decoder specific implementation of SEEK_FRAME procedure */
       l_rc = (*dec_elem->fptr_seek_frame)(gvahand, pos, pos_unit);
       fcache->fcache_locked = FALSE;
@@ -1085,6 +1092,36 @@ p_gva_worker_count_frames(t_GVA_Handle  *gvahand)
 }  /* end p_gva_worker_count_frames */
 
 
+/* -------------------------------
+ * p_gva_worker_check_seek_support
+ * -------------------------------
+ */
+static t_GVA_SeekSupport
+p_gva_worker_check_seek_support(t_GVA_Handle  *gvahand)
+{
+  t_GVA_SeekSupport l_rc;
+
+  l_rc = GVA_SEEKSUPP_NONE;
+  if(gvahand)
+  {
+    t_GVA_DecoderElem *dec_elem;
+
+    dec_elem = (t_GVA_DecoderElem *)gvahand->dec_elem;
+
+    if(dec_elem)
+    {
+      if(dec_elem->fptr_seek_support == NULL)
+      {
+         printf("p_gva_worker_check_seek_support: Method not implemented in decoder %s\n", dec_elem->decoder_name);
+         return(GVA_SEEKSUPP_NONE);
+      }
+      l_rc = (*dec_elem->fptr_seek_support)(gvahand);
+    }
+  }
+  return(l_rc);
+}  /* end p_gva_worker_check_seek_support */
+
+
 /* ----------------------------
  * p_gva_worker_get_video_chunk
  * ----------------------------
@@ -1124,6 +1161,41 @@ p_gva_worker_get_video_chunk(t_GVA_Handle  *gvahand
 }  /* end p_gva_worker_get_video_chunk */
 
 
+/* ----------------------------
+ * p_gva_worker_get_codec_name
+ * ----------------------------
+ */
+static char *
+p_gva_worker_get_codec_name(t_GVA_Handle  *gvahand
+                            ,t_GVA_CodecType codec_type
+                            ,gint32 track_nr
+                            )
+{
+  char *codec_name;
+
+  codec_name = NULL;
+  if(gvahand)
+  {
+    t_GVA_DecoderElem *dec_elem;
+
+    dec_elem = (t_GVA_DecoderElem *)gvahand->dec_elem;
+
+    if(dec_elem)
+    {
+      if(dec_elem->fptr_get_codec_name == NULL)
+      {
+         printf("p_gva_worker_get_codec_name: Method not implemented in decoder %s\n", dec_elem->decoder_name);
+         return(NULL);
+      }
+      codec_name =  (*dec_elem->fptr_get_codec_name)(gvahand
+                                               , codec_type
+                                               , track_nr
+                                               );
+    }
+  }
+  return(codec_name);
+}  /* end p_gva_worker_get_codec_name */
+
 /* --------------------------
  * p_gva_worker_open_read
  * --------------------------
@@ -1180,6 +1252,7 @@ p_gva_worker_open_read(const char *filename, gint32 vid_track, gint32 aud_track
   gvahand->do_gimp_progress = FALSE;          /* WARNING: dont try to set this TRUE if you call the API from a pthread !! */
   gvahand->all_frames_counted = FALSE;
   gvahand->all_samples_counted = FALSE;
+  gvahand->critical_timecodesteps_found = FALSE;
   gvahand->cancel_operation = FALSE;
   gvahand->filename = g_strdup(filename);
   gvahand->current_frame_nr = 0;
@@ -1349,9 +1422,17 @@ GVA_get_next_frame(t_GVA_Handle  *gvahand)
 {
   t_GVA_RetCode l_rc;
 
-  if(gap_debug) printf("GVA_get_next_frame: START handle:%d\n", (int)gvahand);
+  if(gap_debug)
+  {
+    printf("GVA_get_next_frame: START handle:%d\n", (int)gvahand);
+  }
+
   l_rc = p_gva_worker_get_next_frame(gvahand);
-  if(gap_debug) printf("GVA_get_next_frame: END rc:%d\n", (int)l_rc);
+
+  if(gap_debug)
+  {
+    printf("GVA_get_next_frame: END rc:%d\n", (int)l_rc);
+  }
 
   return(l_rc);
 }
@@ -1361,9 +1442,19 @@ GVA_seek_frame(t_GVA_Handle  *gvahand, gdouble pos, t_GVA_PosUnit pos_unit)
 {
   t_GVA_RetCode l_rc;
 
-  if(gap_debug) printf("GVA_seek_frame: START handle:%d, pos%.4f unit:%d\n", (int)gvahand, (float)pos, (int)pos_unit);
+  if(gap_debug)
+  {
+    printf("GVA_seek_frame: START handle:%d, pos%.4f unit:%d\n"
+      , (int)gvahand, (float)pos, (int)pos_unit);
+  }
+
   l_rc = p_gva_worker_seek_frame(gvahand, pos, pos_unit);
-  if(gap_debug) printf("GVA_seek_frame: END rc:%d\n", (int)l_rc);
+
+  if(gap_debug)
+  {
+    printf("GVA_seek_frame: END rc:%d\n"
+      , (int)l_rc);
+  }
 
   return(l_rc);
 }
@@ -1414,6 +1505,18 @@ GVA_count_frames(t_GVA_Handle  *gvahand)
   return(l_rc);
 }
 
+t_GVA_SeekSupport
+GVA_check_seek_support(t_GVA_Handle  *gvahand)
+{
+  t_GVA_SeekSupport l_rc;
+
+  if(gap_debug) printf("GVA_check_seek_support: START handle:%d\n", (int)gvahand);
+  l_rc = p_gva_worker_check_seek_support(gvahand);
+  if(gap_debug) printf("GVA_check_seek_support: END rc:%d\n", (int)l_rc);
+
+  return(l_rc);
+}
+
 t_GVA_RetCode
 GVA_get_video_chunk(t_GVA_Handle  *gvahand
                    , gint32 frame_nr
@@ -1463,6 +1566,42 @@ GVA_has_video_chunk_proc(t_GVA_Handle  *gvahand)
   return(l_rc);
 }
 
+
+char *
+GVA_get_codec_name(t_GVA_Handle  *gvahand
+                  ,t_GVA_CodecType codec_type
+                  ,gint32 track_nr
+                  )
+{
+  char *codec_name;
+
+  if(gap_debug)
+  {
+    printf("GVA_get_video_chunk: START handle:%d, codec_type:%d track_nr:%d\n"
+                      , (int)gvahand
+                      , (int)codec_type
+                      , (int)track_nr
+                      );
+  }
+
+  codec_name = p_gva_worker_get_codec_name(gvahand, codec_type, track_nr);
+  if(gap_debug)
+  {
+    printf("GVA_get_codec_name: END codec_name:");
+    if (codec_name)
+    {
+      printf("%s", codec_name);
+    }
+    else
+    {
+      printf("NULL");
+    }
+    printf("\n");
+  }
+
+  return(codec_name);
+}
+
 /* -------------------------------------------------------------------------
  * Converter Procedures (Framebuffer <--> GIMP
  * -------------------------------------------------------------------------
@@ -1511,6 +1650,7 @@ GVA_gimp_image_to_rowbuffer(t_GVA_Handle *gvahand, gint32 image_id)
      if(gap_debug) printf("GVA_gimp_image_to_rowbuffer: FLATTEN Image\n");
 
      l_layer_id = gimp_image_flatten(image_id);
+     gimp_drawable_detach (drawable);
      drawable = gimp_drawable_get (l_layer_id);
   }
 
@@ -1534,17 +1674,17 @@ GVA_gimp_image_to_rowbuffer(t_GVA_Handle *gvahand, gint32 image_id)
    */
   gimp_pixel_rgn_init (&pixel_rgn, drawable, 0, 0
                       , drawable->width, drawable->height
-		      , FALSE     /* dirty */
-		      , FALSE     /* shadow */
-		       );
+                      , FALSE     /* dirty */
+                      , FALSE     /* shadow */
+                       );
   gimp_pixel_rgn_get_rect (&pixel_rgn, gvahand->frame_data
                           , 0
-			  , 0
+                          , 0
                           , gvahand->width
                           , gvahand->height);
 
   gimp_drawable_detach(drawable);
-
+  
   if (gap_debug)  printf("DEBUG: after copy data rows \n");
 
 
@@ -1683,6 +1823,43 @@ p_mix_rows( gint32 width
 
 
 
+/* ------------------------------------
+ * p_calculate_mix_threshold
+ * ------------------------------------
+ */
+static gint32
+p_calculate_mix_threshold(gdouble threshold)
+{
+  gint32  l_threshold;
+  gint32  l_mix_threshold;
+
+  /* expand threshold range from 0.0-1.0  to 0 - MIX_MAX_THRESHOLD */
+  threshold = CLAMP(threshold, 0.0, 1.0);
+  l_threshold = (gdouble)MIX_MAX_THRESHOLD * (threshold * threshold * threshold);
+  l_mix_threshold = CLAMP((gint32)l_threshold, 0, MIX_MAX_THRESHOLD);
+}
+
+
+/* ------------------------------------
+ * p_calculate_interpolate_flag
+ * ------------------------------------
+ */
+static gint32
+p_calculate_interpolate_flag(gint32 deinterlace)
+{
+  gint32  l_interpolate_flag;
+ 
+  l_interpolate_flag = 0;
+  if (deinterlace == 1)
+  {
+    l_interpolate_flag = 1;
+  }
+  return l_interpolate_flag;  
+}
+
+
+
+
 /* ------------------------------------
  * GVA_delace_frame
  * ------------------------------------
@@ -1704,84 +1881,206 @@ guchar *
 GVA_delace_frame(t_GVA_Handle *gvahand
                 , gint32 deinterlace
                 , gdouble threshold
-		)
+                )
 {
-    guchar *l_framedata_copy;
-    guchar *l_row_ptr_dest;
-    gint32  l_row;
-    gint32  l_interpolate_flag;
-    gint32  l_row_bytewidth;
-    gint32  l_threshold;
-    gint32  l_mix_threshold;
+  guchar *l_framedata_copy;
+  guchar *l_row_ptr_dest;
+  gint32  l_row;
+  gint32  l_interpolate_flag;
+  gint32  l_row_bytewidth;
+  gint32  l_mix_threshold;
 
-    if(gvahand->fc_row_pointers == NULL)
+  if(gvahand->fc_row_pointers == NULL)
+  {
+    return (NULL);
+  }
+  l_row_bytewidth = gvahand->width * gvahand->frame_bpp;
+  l_framedata_copy = g_malloc(l_row_bytewidth * gvahand->height);
+
+
+  l_interpolate_flag = p_calculate_interpolate_flag(deinterlace);
+  l_mix_threshold = p_calculate_mix_threshold(threshold);
+
+  l_row_ptr_dest = l_framedata_copy;
+  for(l_row = 0; l_row < gvahand->height; l_row++)
+  {
+    if ((l_row & 1) == l_interpolate_flag)
     {
-      return (NULL);
-    }
-    l_row_bytewidth = gvahand->width * gvahand->frame_bpp;
-    l_framedata_copy = g_malloc(l_row_bytewidth * gvahand->height);
-
-
-    l_interpolate_flag = 0;
-    if (deinterlace == 1)
-    {
-      l_interpolate_flag = 1;
-    }
-    
-    /* expand threshold range from 0.0-1.0  to 0 - MIX_MAX_THRESHOLD */
-    threshold = CLAMP(threshold, 0.0, 1.0);
-    l_threshold = (gdouble)MIX_MAX_THRESHOLD * (threshold * threshold * threshold);
-    l_mix_threshold = CLAMP((gint32)l_threshold, 0, MIX_MAX_THRESHOLD);
-
-    l_row_ptr_dest = l_framedata_copy;
-    for(l_row = 0; l_row < gvahand->height; l_row++)
-    {
-      if ((l_row & 1) == l_interpolate_flag)
+      if(l_row == 0)
       {
-        if(l_row == 0)
-        {
-           /* we have no prvious row, so we just copy the next row */
-           memcpy(l_row_ptr_dest, gvahand->fc_row_pointers[1],  l_row_bytewidth);
-        }
-        else
-        {
-          if(l_row == gvahand->height -1)
-          {
-            /* we have no next row, so we just copy the prvious row */
-            memcpy(l_row_ptr_dest, gvahand->fc_row_pointers[gvahand->height -2],  l_row_bytewidth);
-          }
-          else
-          {
-            /* we have both prev and next row within valid range
-             * and can calculate an interpolated row
-             */
-            p_mix_rows ( gvahand->width
-                         , gvahand->frame_bpp
-                         , l_row_bytewidth
-                         , l_mix_threshold
-                         , gvahand->fc_row_pointers[l_row -1]
-                         , gvahand->fc_row_pointers[l_row +1]
-                         , l_row_ptr_dest
-                         );
-          }
-        }
+         /* we have no prvious row, so we just copy the next row */
+         memcpy(l_row_ptr_dest, gvahand->fc_row_pointers[1],  l_row_bytewidth);
       }
       else
       {
-        /* copy original row */
-        memcpy(l_row_ptr_dest, gvahand->fc_row_pointers[l_row],  l_row_bytewidth);
+        if(l_row == gvahand->height -1)
+        {
+          /* we have no next row, so we just copy the prvious row */
+          memcpy(l_row_ptr_dest, gvahand->fc_row_pointers[gvahand->height -2],  l_row_bytewidth);
+        }
+        else
+        {
+          /* we have both prev and next row within valid range
+           * and can calculate an interpolated row
+           */
+          p_mix_rows ( gvahand->width
+                       , gvahand->frame_bpp
+                       , l_row_bytewidth
+                       , l_mix_threshold
+                       , gvahand->fc_row_pointers[l_row -1]
+                       , gvahand->fc_row_pointers[l_row +1]
+                       , l_row_ptr_dest
+                       );
+        }
       }
-      l_row_ptr_dest += l_row_bytewidth;
+    }
+    else
+    {
+      /* copy original row */
+      memcpy(l_row_ptr_dest, gvahand->fc_row_pointers[l_row],  l_row_bytewidth);
+    }
+    l_row_ptr_dest += l_row_bytewidth;
+
+  }
+
+  return(l_framedata_copy);
+}  /* end GVA_delace_frame */
+
+
+/* ------------------------------------
+ * p_gva_deinterlace_drawable
+ * ------------------------------------
+ */
+static void
+p_gva_deinterlace_drawable (GimpDrawable *drawable, gint32 deinterlace, gdouble threshold)
+{
+  GimpPixelRgn  srcPR, destPR;
+  guchar       *dest;
+  guchar       *dest_buffer = NULL;
+  guchar       *upper;
+  guchar       *lower;
+  gint          row, col;
+  gint          x, y;
+  gint          width, height;
+  gint          bytes;
+  gint x2, y2;
+  gint32  l_row_bytewidth;
+  gint32  l_interpolate_flag;
+  gint32  l_mix_threshold;
+
+
+  l_interpolate_flag = p_calculate_interpolate_flag(deinterlace);
+  l_mix_threshold = p_calculate_mix_threshold(threshold);
+
+  bytes = drawable->bpp;
+
+  gimp_drawable_mask_bounds (drawable->drawable_id, &x, &y, &x2, &y2);
+  width  = x2 - x;
+  height = y2 - y;
+  l_row_bytewidth = width * drawable->bpp;
+  dest = g_new (guchar, l_row_bytewidth);
+
+  gimp_pixel_rgn_init (&destPR, drawable, x, y, width, height, TRUE, TRUE);
+
+  gimp_pixel_rgn_init (&srcPR, drawable,
+                       x, MAX (y - 1, 0),
+                       width, MIN (height + 1, drawable->height),
+                       FALSE, FALSE);
+
+  /*  allocate buffers for upper and lower row  */
+  upper = g_new (guchar, l_row_bytewidth);
+  lower = g_new (guchar, l_row_bytewidth);
+
+  for (row = y; row < y + height; row++)
+  {
+    /*  Only do interpolation if the row:
+     *  (1) Isn't one we want to keep
+     *  (2) Has both an upper and a lower row
+     *  Otherwise, just duplicate the source row
+     */
+    if (((row & 1) == l_interpolate_flag) &&
+        (row - 1 >= 0) && (row + 1 < drawable->height))
+    {
+      gimp_pixel_rgn_get_row (&srcPR, upper, x, row - 1, width);
+      gimp_pixel_rgn_get_row (&srcPR, lower, x, row + 1, width);
+ 
+      p_mix_rows ( width
+                 , drawable->bpp
+                 , l_row_bytewidth
+                 , l_mix_threshold
+                 , upper
+                 , lower
+                 , dest
+                 );
 
     }
+    else
+    {
+      /* copy current row 1:1 */
+      gimp_pixel_rgn_get_row (&srcPR, dest, x, row, width);
+    }
 
-    return(l_framedata_copy);
-}  /* end GVA_delace_frame */
+    gimp_pixel_rgn_set_row (&destPR, dest, x, row, width);
+  }
+
+
+  /*  update the deinterlaced region  */
+  gimp_drawable_flush (drawable);
+  gimp_drawable_merge_shadow (drawable->drawable_id, TRUE);
+  gimp_drawable_update (drawable->drawable_id, x, y, width, height);
+
+  g_free (lower);
+  g_free (upper);
+  g_free (dest);
+
+}  /* end p_gva_deinterlace_drawable */
+
+
+
+/* ------------------------------------
+ * GVA_delace_drawable
+ * ------------------------------------
+ * deinterlaced the specified drawable.
+ *
+ * IN: drawable_id     the drawable to be deinterlaced.
+ * IN: do_scale  FALSE: deliver frame at original size (ignore bpp, width and height parameters)
+ *               TRUE: deliver frame at size specified by width, height, bpp
+ *                     scaling is done fast in low quality 
+ * IN: deinterlace   0: no deinterlace (NOP), 1 pick odd lines, 2 pick even lines
+ * IN: threshold     0.0 hard, 1.0 smooth interpolation at deinterlacing
+ *                   threshold is ignored if do_scaing == TRUE
+ *
+ */
+void
+GVA_delace_drawable(gint32 drawable_id
+                , gint32 deinterlace
+                , gdouble threshold
+                )
+{
+  GimpDrawable      *drawable;
+
+  if (deinterlace != 0)
+  {
+    drawable = gimp_drawable_get(drawable_id);
+    if (drawable)
+    {
+      p_gva_deinterlace_drawable (drawable, deinterlace, threshold);
+      gimp_drawable_detach(drawable);
+    }
+  }
+}  /* end GVA_delace_drawable */
 
 
 /* ------------------------------------
  * GVA_image_set_aspect
  * ------------------------------------
+ * if aspect_ratio is known convert the aspect
+ * to image X and Y resolution in DPI 
+ * this allows GIMP to scale the display to correct aspect
+ * when View option "Dot for Dot" is turned off.
+ * Note that the resolution is just a guess based on typical 
+ * monitor resolution in DPI. 
+ * (videos usually have no DPI resoulution information, just aspect ratio)
  */
 void
 GVA_image_set_aspect(t_GVA_Handle *gvahand, gint32 image_id)
@@ -1791,24 +2090,37 @@ GVA_image_set_aspect(t_GVA_Handle *gvahand, gint32 image_id)
   {
     gdouble xresolution;
     gdouble yresolution;
+    gdouble xresolutionMoni;
+    gdouble yresolutionMoni;
     gdouble asymetric;
 
     asymetric = ((gdouble)gvahand->width / (gdouble)gvahand->height)
               / gvahand->aspect_ratio;
 
-    yresolution = 72.0;
+    gimp_get_monitor_resolution(&xresolutionMoni, &yresolutionMoni);
+    
+    if (yresolutionMoni > 0)
+    {
+       yresolution = yresolutionMoni;
+    }
+    else
+    {
+       yresolution = 72.0;
+    }
     xresolution = yresolution * asymetric;
 
-    /* set resolution in DPI according to aspect ratio */
+    /* set resolution in DPI according to aspect ratio
+     * assuming a typical monitor resolution
+     */
     gimp_image_set_unit (image_id, GIMP_UNIT_INCH);
     gimp_image_set_resolution (image_id, xresolution, yresolution);
 
     if(gap_debug)
     {
       printf("API: resolution x/y %f / %f\n"
-	, (float)xresolution
-	, (float)yresolution
-	);
+        , (float)xresolution
+        , (float)yresolution
+        );
     }
   }
 }  /* end GVA_image_set_aspect */
@@ -1860,11 +2172,20 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
   static gchar *odd_even_tab[8] = {"\0", "_odd", "_even", "_odd", "_even", "\0", "\0", "\0" };
 
 
-  if(gap_debug) printf("GVA_frame_to_gimp_layer_2 framenumber: %d\n", (int)framenumber);
+  if(gap_debug)
+  {
+    printf("GVA_frame_to_gimp_layer_2 framenumber: %d\n", (int)framenumber);
+  }
+
   l_new_layer_id = -1;
   if (GVA_search_fcache(gvahand, framenumber) != GVA_RET_OK)
   {
-     if(gap_debug) printf("frame %d not found in fcache!  %d\n", (int)framenumber , (int)gvahand->current_frame_nr );
+     if(gap_debug)
+     {
+       printf("frame %d not found in fcache!  %d\n"
+         , (int)framenumber
+         , (int)gvahand->current_frame_nr );
+     }
 
      return (-2);
   }
@@ -1884,9 +2205,9 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
        /* resize to image to framesize */
        gimp_image_resize(*image_id
                        , gvahand->width
-		       , gvahand->height
-		       , 0
-		       , 0);
+                       , gvahand->height
+                       , 0
+                       , 0);
        GVA_image_set_aspect(gvahand, *image_id);
      }
   }
@@ -1899,7 +2220,10 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
      old_layer_id = -1;
   }
 
-  gimp_image_undo_disable(*image_id);
+  if (gimp_image_undo_is_enabled(*image_id))
+  {
+    gimp_image_undo_disable(*image_id);
+  }
 
   if(gvahand->framerate > 0)
   {
@@ -1920,7 +2244,7 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
                                     , gvahand->width
                                     , gvahand->height
                                     , GIMP_RGBA_IMAGE
-				    , 100.0, GIMP_NORMAL_MODE);
+                                    , 100.0, GIMP_NORMAL_MODE);
   }
   else
   {
@@ -1929,7 +2253,7 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
                                     , gvahand->width
                                     , gvahand->height
                                     , GIMP_RGB_IMAGE
-				    , 100.0, GIMP_NORMAL_MODE);
+                                    , 100.0, GIMP_NORMAL_MODE);
   }
   g_free(layername);
 
@@ -1941,7 +2265,8 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
    *
    */
   if (gap_debug)
-  {  printf("DEBUG: before copy data rows gvahand->height=%d  gvahand->width=%d\n"
+  {
+     printf("DEBUG: before copy data rows gvahand->height=%d  gvahand->width=%d\n"
             , (int)gvahand->height
             ,(int)gvahand->width);
   }
@@ -1960,21 +2285,21 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
       if (gap_debug)  printf("DEBUG: FILL In the ALPHA CHANNEL\n");
       for (i=(gvahand->width * gvahand->height)-1; i>=0; i--)
       {
-  	 gvahand->fc_frame_data[3+(i*4)] = 255;
+         gvahand->fc_frame_data[3+(i*4)] = 255;
       }
   }
 
 
   gimp_pixel_rgn_init (&pixel_rgn, drawable, 0, 0
                       , drawable->width, drawable->height
-		      , TRUE      /* dirty */
-		      , FALSE     /* shadow */
-		       );
+                      , TRUE      /* dirty */
+                      , FALSE     /* shadow */
+                       );
   if ((deinterlace == 0) || (gvahand->height < 2))
   {
     gimp_pixel_rgn_set_rect (&pixel_rgn, gvahand->fc_frame_data
                           , 0
-			  , 0
+                          , 0
                           , gvahand->width
                           , gvahand->height);
   }
@@ -1984,20 +2309,23 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
     
     l_framedata_copy = GVA_delace_frame(gvahand
                                        ,deinterlace
-				       ,threshold
-				       );
+                                       ,threshold
+                                       );
     if(l_framedata_copy)
     {
       gimp_pixel_rgn_set_rect (&pixel_rgn, l_framedata_copy
                             , 0
-			    , 0
+                            , 0
                             , gvahand->width
                             , gvahand->height);
       g_free(l_framedata_copy);
     }
   }
 
-  if (gap_debug)  printf("DEBUG: after copy data rows (NO SHADOW)\n");
+  if (gap_debug)
+  {
+    printf("DEBUG: after copy data rows (NO SHADOW)\n");
+  }
 
   gimp_drawable_flush (drawable);
   gimp_drawable_detach(drawable);
@@ -2029,8 +2357,10 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
   gimp_drawable_set_visible(l_new_layer_id, TRUE);
 
   /* clear undo stack */
-  gimp_image_undo_enable(*image_id);
-  gimp_image_undo_disable(*image_id);
+  if (gimp_image_undo_is_enabled(*image_id))
+  {
+    gimp_image_undo_disable(*image_id);
+  }
 
   /* debug code to display a copy of the image */
   /*
@@ -2043,6 +2373,10 @@ GVA_frame_to_gimp_layer_2(t_GVA_Handle *gvahand
    * }
    */
 
+  if (gap_debug)
+  {
+    printf("END GVA_frame_to_gimp_layer_2: return value:%d\n", (int)l_new_layer_id);
+  }
 
   return(l_new_layer_id); /* return the newly created layer_id (-1 on error) */
 }  /* end GVA_frame_to_gimp_layer_2 */
@@ -2214,7 +2548,7 @@ GVA_frame_to_gimp_layer(t_GVA_Handle *gvahand
  * ------------------------------------
  *  HINT:
  *  for the calling program it is easier to call
- * 	GVA_fetch_frame_to_buffer
+ *      GVA_fetch_frame_to_buffer
  *
  * IN: gvahand  videohandle
  * IN: do_scale  FALSE: deliver frame at original size (ignore bpp, width and height parameters)
@@ -2244,9 +2578,9 @@ GVA_frame_to_buffer(t_GVA_Handle *gvahand
                 , gint32 framenumber
                 , gint32 deinterlace
                 , gdouble threshold
-		, gint32 *bpp
-		, gint32 *width
-		, gint32 *height
+                , gint32 *bpp
+                , gint32 *width
+                , gint32 *height
                 )
 {
   gint32  frame_size;
@@ -2265,8 +2599,8 @@ GVA_frame_to_buffer(t_GVA_Handle *gvahand
 
   if(do_scale)
   {
-    guchar	 *src_row, *src, *dest;
-    gint	 row, col;
+    guchar       *src_row, *src, *dest;
+    gint         row, col;
     gint32       deinterlace_mask;
     gint         *arr_src_col;
 
@@ -2317,23 +2651,23 @@ GVA_frame_to_buffer(t_GVA_Handle *gvahand
     {
       for ( col = 0; col < (*width); col++ )
       {
-	arr_src_col[ col ] = ( col * gvahand->width / (*width) ) * gvahand->frame_bpp;
+        arr_src_col[ col ] = ( col * gvahand->width / (*width) ) * gvahand->frame_bpp;
       }
 
       dest = frame_data;
       /* copy row by row */
       for ( row = 0; row < *height; row++ )
       {
-	  src_row = gvahand->fc_row_pointers[(row * gvahand->height / (*height)) & deinterlace_mask];
-	  for ( col = 0; col < (*width); col++ )
-	  {
-	      src = &src_row[ arr_src_col[col] ];
-	      dest[0] = src[0];
-	      dest[1] = src[1];
-	      dest[2] = src[2];
-	      dest[3] = 255;
-	      dest += (*bpp);
-	  }
+          src_row = gvahand->fc_row_pointers[(row * gvahand->height / (*height)) & deinterlace_mask];
+          for ( col = 0; col < (*width); col++ )
+          {
+              src = &src_row[ arr_src_col[col] ];
+              dest[0] = src[0];
+              dest[1] = src[1];
+              dest[2] = src[2];
+              dest[3] = 255;
+              dest += (*bpp);
+          }
       }
       g_free(arr_src_col);
     }
@@ -2355,7 +2689,7 @@ GVA_frame_to_buffer(t_GVA_Handle *gvahand
       frame_data = g_malloc(frame_size);
       if(frame_data == NULL)
       {
-	return (NULL);
+        return (NULL);
       }
       memcpy(frame_data, gvahand->fc_frame_data, frame_size);
     }
@@ -2363,11 +2697,11 @@ GVA_frame_to_buffer(t_GVA_Handle *gvahand
     {
       frame_data = GVA_delace_frame(gvahand
                                    ,deinterlace
-				   ,threshold
-				   );
+                                   ,threshold
+                                   );
       if(frame_data == NULL)
       {
-	return (NULL);
+        return (NULL);
       }
     }
 
@@ -2381,17 +2715,17 @@ GVA_frame_to_buffer(t_GVA_Handle *gvahand
     {
        gint i;
 
-	if (gap_debug)  printf("DEBUG: FILL In the ALPHA CHANNEL\n");
-	for (i=((*width) * (*height))-1; i>=0; i--)
-	{
-  	   frame_data[3+(i*4)] = 255;
-	}
+        if (gap_debug)  printf("DEBUG: FILL In the ALPHA CHANNEL\n");
+        for (i=((*width) * (*height))-1; i>=0; i--)
+        {
+           frame_data[3+(i*4)] = 255;
+        }
     }
   }
 
   return(frame_data);
   
-}	/* end GVA_frame_to_buffer */
+}       /* end GVA_frame_to_buffer */
 
 
 /* ------------------------------------
@@ -2429,9 +2763,9 @@ GVA_fetch_frame_to_buffer(t_GVA_Handle *gvahand
                 , gint32 framenumber
                 , gint32 deinterlace
                 , gdouble threshold
-		, gint32 *bpp
-		, gint32 *width
-		, gint32 *height
+                , gint32 *bpp
+                , gint32 *width
+                , gint32 *height
                 )
 {
   guchar *frame_data;
@@ -2443,19 +2777,46 @@ GVA_fetch_frame_to_buffer(t_GVA_Handle *gvahand
              , framenumber
              , deinterlace
              , threshold
-	     , bpp
-	     , width
-	     , height
+             , bpp
+             , width
+             , height
              );
 
   if(frame_data == NULL)
   {
-    if(framenumber != gvahand->current_frame_nr +1)
+    gint32 l_delta;
+    gint32 l_readsteps;
+    
+    l_readsteps = 1;
+    l_delta = framenumber - gvahand->current_frame_nr;
+    l_rc = GVA_RET_OK;
+
+    if((l_delta >= 1) && (l_delta <= 10))
+    {
+      /* target framenumber is very near to the current_frame_nr
+       * in this case positioning via sequential read is faster than seek
+       */
+      l_readsteps = l_delta;
+    }
+    else
     {
       l_rc = GVA_seek_frame(gvahand, framenumber, GVA_UPOS_FRAMES);
     }
 
-    l_rc = GVA_get_next_frame(gvahand);
+    while ((l_readsteps > 0) && (l_rc == GVA_RET_OK))
+    {
+      l_rc = GVA_get_next_frame(gvahand);
+      if(gap_debug)
+      {
+        printf("GVA_fetch_frame_to_buffer: l_readsteps:%d framenumber;%d curr:%d l_rc:%d\n"
+          , (int)l_readsteps
+          , (int)framenumber
+          , (int)gvahand->current_frame_nr
+          , (int)l_rc
+          );
+      }
+      l_readsteps--;
+    }
 
     if(l_rc == GVA_RET_OK)
     {
@@ -2464,9 +2825,9 @@ GVA_fetch_frame_to_buffer(t_GVA_Handle *gvahand
                  , framenumber
                  , deinterlace
                  , threshold
-		 , bpp
-		 , width
-		 , height
+                 , bpp
+                 , width
+                 , height
                  );
     }
   }
