@@ -57,11 +57,25 @@ typedef enum t_GVA_PosUnit
 
 typedef enum t_GVA_RetCode
 {
-  GVA_RET_OK    = 0
- ,GVA_RET_EOF   = 1   /* not implemented yet */
- ,GVA_RET_ERROR = 2
+  GVA_RET_OK                      = 0
+ ,GVA_RET_EOF                     = 1
+ ,GVA_RET_ERROR                   = 2
 } t_GVA_RetCode;
 
+
+typedef enum t_GVA_SeekSupport
+{
+  GVA_SEEKSUPP_NONE    = 0      /* no fast random positioning possible for this video
+                                 * (with the current decoder)
+                                 * The caller still can use GVA_seek
+                                 * but in this case seek will be emulated via
+                                 * very slow sequential read loop.
+                                 */
+, GVA_SEEKSUPP_VINDEX  = 1      /* creating a video index will provide random positioning */
+, GVA_SEEKSUPP_NATIVE  = 2      /* random positioning supported even without creating a video index */
+} t_GVA_SeekSupport;
+
+
 #define GVA_MAX_FCACHE_SIZE 1000
 
 /*
@@ -147,7 +161,9 @@ typedef struct t_GVA_VideoindexHdr
 
 typedef enum
 {
-  GVA_IDX_TT_GINT64
+  GVA_IDX_TT_WITHOUT_TIMECODE_GINT64     /* only used in old format */
+ ,GVA_IDX_TT_WITHOUT_TIMECODE_GDOUBLE    /* only used in old format */
+ ,GVA_IDX_TT_GINT64
  ,GVA_IDX_TT_GDOUBLE
  ,GVA_IDX_TT_UNDEFINED
 } t_GVA_IndexTabType;
@@ -158,6 +174,15 @@ typedef union
   gdouble             offset_gdouble;
 } t_GVA_UnionElem;
 
+typedef struct t_GVA_IndexElemWithoutTimecode   /* old format */
+{
+  gint32  seek_nr;
+  guint16 frame_length;
+  guint16 checksum;
+
+  t_GVA_UnionElem uni;
+} t_GVA_IndexElemWithoutTimecode;
+
 typedef struct t_GVA_IndexElem
 {
   gint32  seek_nr;
@@ -165,6 +190,7 @@ typedef struct t_GVA_IndexElem
   guint16 checksum;
 
   t_GVA_UnionElem uni;
+  gint64 timecode_dts;
 } t_GVA_IndexElem;
 
 typedef struct t_GVA_Videoindex  /* nick: vindex */
@@ -208,8 +234,8 @@ typedef struct t_GVA_Handle  /* nickname: gvahand */
   gpointer progress_cb_user_data;
   t_GVA_progress_callback_fptr fptr_progress_callback; /* if != NULL: The API calls this user procedure with current progress
                                                         * if the procedure returns TRUE
-							* the API does cancel current seek operations immediate.
-							*/
+                                                        * the API does cancel current seek operations immediate.
+                                                        */
 
 
   /* PUBLIC information (read only outside the API) */
@@ -236,6 +262,8 @@ typedef struct t_GVA_Handle  /* nickname: gvahand */
   gint32  samplerate;           /* audio samples per sec */
   gint32  audio_cannels;        /* number of channel (in the selected aud_track) */
 
+  gboolean critical_timecodesteps_found;
+  
 
   gdouble percentage_done;      /* 0.0 <= percentage_done <= 1.0 */
 
@@ -264,6 +292,11 @@ typedef struct t_GVA_Handle  /* nickname: gvahand */
   gboolean gva_thread_save;
 } t_GVA_Handle;
 
+typedef enum
+{
+  GVA_VIDEO_CODEC
+ ,GVA_AUDIO_CODEC
+} t_GVA_CodecType;
 
 /* Function Typedefs */
 typedef  gboolean       (*t_check_sig_fptr)(char *filename);
@@ -279,14 +312,19 @@ typedef  t_GVA_RetCode  (*t_get_audio_fptr)(t_GVA_Handle *gvahand
                              ,gdouble samples
                              ,t_GVA_AudPos mode_flag
                         );
-typedef  t_GVA_RetCode  (*t_count_frames_fptr)(t_GVA_Handle *gvahand);
-typedef  t_GVA_RetCode  (*t_get_video_chunk_fptr)(t_GVA_Handle *gvahand
+typedef  t_GVA_RetCode     (*t_count_frames_fptr)(t_GVA_Handle *gvahand);
+typedef  t_GVA_SeekSupport (*t_seek_support_fptr)(t_GVA_Handle *gvahand);
+typedef  t_GVA_RetCode     (*t_get_video_chunk_fptr)(t_GVA_Handle *gvahand
                              ,gint32 frame_nr
                              ,unsigned char *chunk
                              ,gint32 *sizes
                              ,gint32 max_size
-                        );
+                           );
 
+typedef  char *           (*t_get_codec_name_fptr)(t_GVA_Handle *gvahand
+                             ,t_GVA_CodecType codec_type
+                             ,gint32 track_nr
+                           );
 
 
 /* List Element Description for a Decoder */
@@ -306,7 +344,9 @@ typedef struct t_GVA_DecoderElem
   t_seek_audio_fptr             fptr_seek_audio;
   t_get_audio_fptr              fptr_get_audio;
   t_count_frames_fptr           fptr_count_frames;
+  t_seek_support_fptr           fptr_seek_support;
   t_get_video_chunk_fptr        fptr_get_video_chunk;
+  t_get_codec_name_fptr         fptr_get_codec_name;
 } t_GVA_DecoderElem;
 
 
@@ -335,7 +375,8 @@ t_GVA_RetCode   GVA_get_audio(t_GVA_Handle  *gvahand
                              ,t_GVA_AudPos mode_flag      /* specify the position where to start reading audio from */
                              );
 
-t_GVA_RetCode   GVA_count_frames(t_GVA_Handle  *gvahand);
+t_GVA_RetCode     GVA_count_frames(t_GVA_Handle  *gvahand);
+t_GVA_SeekSupport GVA_check_seek_support(t_GVA_Handle  *gvahand);
 
 void            GVA_set_fcache_size(t_GVA_Handle *gvahand
                  ,gint32 frames_to_keep_cahed
@@ -380,24 +421,29 @@ guchar *       GVA_frame_to_buffer(t_GVA_Handle *gvahand
                 , gint32 framenumber
                 , gint32 deinterlace
                 , gdouble threshold
-		, gint32 *bpp
-		, gint32 *width
-		, gint32 *height
+                , gint32 *bpp
+                , gint32 *width
+                , gint32 *height
                 );
 guchar *       GVA_fetch_frame_to_buffer(t_GVA_Handle *gvahand
                 , gboolean do_scale
                 , gint32 framenumber
                 , gint32 deinterlace
                 , gdouble threshold
-		, gint32 *bpp
-		, gint32 *width
-		, gint32 *height
+                , gint32 *bpp
+                , gint32 *width
+                , gint32 *height
                 );
 guchar *       GVA_delace_frame(t_GVA_Handle *gvahand
                 , gint32 deinterlace
                 , gdouble threshold
-		);
-		
+                );
+
+void           GVA_delace_drawable(gint32 drawable_id
+                , gint32 deinterlace
+                , gdouble threshold
+                );
+                
 gint32          GVA_percent_2_frame(gint32 total_frames, gdouble percent);
 gdouble         GVA_frame_2_percent(gint32 total_frames, gdouble framenr);
 
@@ -411,11 +457,32 @@ t_GVA_RetCode   GVA_get_video_chunk(t_GVA_Handle  *gvahand
                    , unsigned char *chunk
                    , gint32 *size
                    , gint32 max_size);
+
+char *         GVA_get_codec_name(t_GVA_Handle  *gvahand
+                   ,t_GVA_CodecType codec_type
+                   ,gint32 track_nr
+                   );
+
 gint           GVA_util_check_mpg_frame_type(unsigned char *buffer, gint32 buf_size);
 void           GVA_util_fix_mpg_timecode(unsigned char *buffer
                          ,gint32 buf_size
                          ,gdouble master_framerate
                          ,gint32  master_frame_nr
                          );
+gint32         GVA_util_calculate_mpeg_frameheader_size(unsigned char *buffer
+                         ,gint32 buf_size
+                         );
+gboolean       GVA_util_check_jpg_picture(unsigned char *buffer
+                         ,gint32 buf_size
+                         ,gint32 max_check_size
+                         ,gint32 *hdr_size
+                         );
+gboolean       GVA_util_check_png_picture(unsigned char *buffer
+                         ,gint32 buf_size
+                         ,gint32 max_check_size
+                         ,gint32 *hdr_size
+                         );
+void           GVA_md5_string(char *name, const char *uri);
+gchar*         GVA_filename_to_uri(const char *filename);
 
 #endif
