@@ -30,6 +30,10 @@
 
 #include <config.h>
 
+#include <time.h>
+
+#include <glib/gstdio.h>
+
 #include <gtk/gtk.h>
 #include "gap-intl.h"
 
@@ -39,6 +43,167 @@
 #include "gap_gve_story.h"
 #include "gap_cme_callbacks.h"
 
+static void            p_start_encoder_status_poll_timer(GapCmeGlobalParams *gpp);
+static void            p_remove_encoder_status_poll_timer(GapCmeGlobalParams *gpp);
+static gint32          p_drop_chache_and_start_video_encoder(GapCmeGlobalParams *gpp);
+static void            on_encoder_status_poll_timer(gpointer   user_data);
+
+
+static void
+p_start_encoder_status_poll_timer(GapCmeGlobalParams *gpp)
+{
+  if(gpp)
+  {
+    gpp->encoder_status_poll_timertag =
+       (gint32) g_timeout_add(250, (GSourceFunc) on_encoder_status_poll_timer, gpp);
+  }
+}
+static void
+p_remove_encoder_status_poll_timer(GapCmeGlobalParams *gpp)
+{
+  if(gpp)
+  {
+    if(gpp->encoder_status_poll_timertag >= 0)
+    {
+      g_source_remove(gpp->encoder_status_poll_timertag);
+      gpp->productive_encoder_timertag = -1;
+    }
+  }
+}
+
+static void
+on_encoder_status_poll_timer(gpointer   user_data)
+{
+  GapCmeGlobalParams *gpp;
+
+  if(gap_debug)
+  {
+    printf("\n on_encoder_status_poll_timer: START\n");
+  }
+
+  gpp = (GapCmeGlobalParams *)user_data;
+  
+  if(gpp)
+  {
+    p_remove_encoder_status_poll_timer(gpp);
+    gap_cme_gui_update_encoder_status(gpp);
+    
+    if(gpp->video_encoder_run_state == GAP_CME_ENC_RUN_STATE_RUNNING)
+    {
+      /* restart timer for next poll cycle */
+      p_start_encoder_status_poll_timer(gpp);
+    }
+  }
+  
+}  /* end on_encoder_status_poll_timer */
+
+static void
+on_productive_encoder_start(gpointer   user_data)
+{
+  GapCmeGlobalParams *gpp;
+
+  if(gap_debug)
+  {
+    printf("\n on_productive_encoder_start: START\n");
+  }
+
+  gpp = (GapCmeGlobalParams *)user_data;
+  
+  if(gpp)
+  {
+    if(gpp->productive_encoder_timertag >= 0)
+    {
+      if(gap_debug)
+      {
+        printf("MAIN on_productive_encoder_start remove productive_encoder_timertag:%d\n", (int)gpp->productive_encoder_timertag);
+      }
+      g_source_remove(gpp->productive_encoder_timertag);
+      gpp->productive_encoder_timertag = -1;
+    }
+
+    if(gap_debug)
+    {
+      printf("MAIN on_productive_encoder_start VIDEO ENCODER START ------------------\n");
+    }
+
+    gap_cme_gui_start_video_encoder_as_thread(gpp);
+
+
+    if(gap_debug)
+    {
+      printf("MAIN on_productive_encoder_start VIDEO ENCODER finished ------------------\n");
+    }
+    p_start_encoder_status_poll_timer(gpp);
+  }
+  
+}  /* end on_productive_encoder_start */
+
+/* ----------------------------------------
+ * p_drop_chache_and_start_video_encoder
+ * ----------------------------------------
+ */
+static gint32
+p_drop_chache_and_start_video_encoder(GapCmeGlobalParams *gpp)
+{
+  /* delete images in the cache
+   * (the cache may have been filled while parsing
+   * storyboard file in the common dialog
+   */
+  gap_gve_story_drop_image_cache();
+  if(gap_debug)
+  {
+    printf("MAIN after gap_gve_story_drop_image_cache ------------------\n");
+  }
+
+  /* start timer (encoder start after 800 millisecs) */
+  gpp->productive_encoder_timertag =
+    (gint32) g_timeout_add(800, (GSourceFunc) on_productive_encoder_start, gpp);
+
+
+}  /* end p_drop_chache_and_start_video_encoder */
+
+
+/* ------------------------------------------
+ * p_switch_gui_to_running_encoder_state
+ * ------------------------------------------
+ * disable video output entry and all existing notebook tabs,
+ * except the last one (the encoder status frame)
+ * (that is updated while encoder thread is running via polling)
+ * then establish the encoding state.
+ */
+static void
+p_switch_gui_to_running_encoder_state(GapCmeGlobalParams *gpp)
+{
+  GtkWidget *label;
+  GtkWidget *frame;
+  GtkWidget *notebook;
+  gint idx;
+  gint npages;
+ 
+  gtk_widget_set_sensitive(gpp->cme__entry_video, FALSE);
+  gtk_widget_set_sensitive(gpp->cme__button_video_filesel, FALSE);
+
+  frame = gpp->cme__encoder_status_frame;
+  notebook = gpp->cme__notebook;
+
+  gtk_widget_show(frame);
+  npages = gtk_notebook_get_n_pages(GTK_NOTEBOOK (notebook));
+  for (idx = 0; idx < npages -1; idx++)
+  {
+    gtk_widget_set_sensitive(gtk_notebook_get_nth_page(GTK_NOTEBOOK (notebook), idx), FALSE);
+  }
+
+  /* store encoder start time */
+  gpp->encoder_started_on_utc_seconds = time(NULL);
+
+  /* show last tab (-1) of the notbook */
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), -1);
+
+  gpp->video_encoder_run_state =  GAP_CME_ENC_RUN_STATE_RUNNING;
+
+}  /* end p_switch_gui_to_running_encoder_state */
+
+
 /* ------------------------------------------------------ */
 /* BEGIN callbacks                                        */
 /* ------------------------------------------------------ */
@@ -65,38 +230,68 @@ on_cme__response (GtkWidget *widget,
     case GTK_RESPONSE_OK:
       if(gpp)
       {
-        if(gpp->val.gui_proc_thread)
+        switch(gpp->video_encoder_run_state)
         {
-          if(gap_cme_gui_check_gui_thread_is_active(gpp)) return;
+          case GAP_CME_ENC_RUN_STATE_READY:
+            if(gpp->val.gui_proc_thread)
+            {
+              if(gap_cme_gui_check_gui_thread_is_active(gpp))
+              {
+                return;
+              }
+            }
+            if(gpp->ow__dialog_window != NULL)
+            {
+              /* Overwrite dialog is already open
+               * but the User pressed the OK button in the qte main dialog again.
+               */
+              gtk_window_present(GTK_WINDOW(gpp->ow__dialog_window));
+              return;
+            }
+            if(FALSE == gap_cme_gui_check_encode_OK (gpp))
+            {
+              return;  /* can not start, illegal parameter value combinations */
+            }
+            gpp->val.run = TRUE;
+            p_switch_gui_to_running_encoder_state(gpp);
+            p_drop_chache_and_start_video_encoder(gpp);
+            return;
+            break;
+          case GAP_CME_ENC_RUN_STATE_RUNNING:
+            return;  /* ignore further clicks on OK button while encoder is running */
+            break;
+          case GAP_CME_ENC_RUN_STATE_FINISHED:
+            /* close the master encoder window if OK button clicked after while encoder has finished */
+            break;
         }
-        if(gpp->ow__dialog_window != NULL)
-        {
-          /* Overwrite dialog is already open
-           * but the User pressed the OK button in the qte main dialog again.
-           */
-          gtk_window_present(GTK_WINDOW(gpp->ow__dialog_window));
-          return;
-        }
-        if(FALSE == gap_cme_gui_check_encode_OK (gpp))
-        {
-          return;  /* can not start, illegal parameter value combinations */
-        }
-        gpp->val.run = TRUE;
-      }
+      }  
+      
+
       /* now run into the default case, to close the shell_window (dont break) */
+      
     default:
       dialog = NULL;
       if(gpp)
       {
+        gap_gve_misc_set_master_encoder_cancel_request(&gpp->encStatus, TRUE);
+
         gap_cme_gui_remove_poll_timer(gpp);
+        p_remove_encoder_status_poll_timer(gpp);
         dialog = gpp->shell_window;
         if(dialog)
         {
           gpp->shell_window = NULL;
           gtk_widget_destroy (dialog);
         }
+
+        gtk_main_quit ();
+
       }
-      gtk_main_quit ();
+      else
+      {
+        gtk_main_quit ();
+      }
+
       break;
   }
 }  /* end on_cme__response */
@@ -135,11 +330,14 @@ on_cme__combo_enocder  (GtkWidget     *widget,
   {
      if(gap_debug)
      {
-	printf("CB: on_cme__combo_encoder index: %d, %s, plugin: %s\n"
+        printf("CB: on_cme__combo_encoder index: %d, %s, plugin: %s\n"
                , (int)l_ecp->menu_nr
                , l_ecp->menu_name
                , l_ecp->vid_enc_plugin);
      }
+
+    gtk_label_set_text(GTK_LABEL(gpp->cme__label_active_encoder_name), l_ecp->menu_name);
+
      /* copy the selected ecp record */
      memcpy(&gpp->val.ecp_sel, l_ecp, sizeof(GapGveEncList));
      gap_cme_gui_upd_wgt_sensitivity(gpp);
@@ -244,7 +442,12 @@ on_cme__combo_outsamplerate  (GtkWidget     *widget,
 
   gimp_int_combo_box_get_active (GIMP_INT_COMBO_BOX (widget), &value);
 
-  if(gap_debug) printf("CB: on_cme__combo_outsamplerate value: %d\n", (int)value);
+  if(gap_debug)
+  {
+    printf("CB: on_cme__combo_outsamplerate value: %d\n", (int)value);
+  }
+
+
 
   if(gpp->cme__spinbutton_samplerate_adj)
   {
@@ -264,7 +467,7 @@ on_cme__combo_vid_norm  (GtkWidget     *widget,
 {
   gint       value;
 
-  if(gap_debug) printf("CB: on_cme__combo_outsamplerate\n");
+  if(gap_debug) printf("CB: on_cme__combo_vid_norm\n");
 
   if(gpp == NULL) return;
 
@@ -688,7 +891,7 @@ on_cme__spinbutton_framerate_changed   (GtkEditable     *editable,
 
    if((gint)adj->value != gpp->val.framerate)
    {
-     gpp->val.framerate = (gint)adj->value;
+     gpp->val.framerate = adj->value;
      gap_cme_gui_update_vid_labels (gpp);
    }
  }
@@ -720,7 +923,7 @@ on_cme__entry_audio1_changed           (GtkEditable     *editable,
     {
       if(g_file_test(gpp->val.tmp_audfile, G_FILE_TEST_EXISTS))
       {
-        remove(gpp->val.tmp_audfile);
+        g_remove(gpp->val.tmp_audfile);
       }
       gpp->val.tmp_audfile[0] = '\0';
     }
@@ -769,13 +972,46 @@ on_cme__spinbutton_samplerate_changed  (GtkEditable     *editable,
  adj = GTK_ADJUSTMENT(gpp->cme__spinbutton_samplerate_adj);
  if(adj)
  {
-   if(gap_debug) printf("samplerate spin value: %f\n", (float)adj->value );
-
-   if((gint)adj->value != gpp->val.samplerate)
+   gint gintValue;
+   
+   if(gap_debug)
    {
-     gpp->val.samplerate = (gint)adj->value;
+     printf("samplerate spin value: %f\n", (float)adj->value );
+   }
+   gintValue = (gint)adj->value;
+   
+   if(gintValue != gpp->val.samplerate)
+   {
+     gpp->val.samplerate = gintValue;
      gap_cme_gui_update_aud_labels (gpp);
    }
+
+   switch (gintValue)
+   {
+     case 8000:
+     case 11025:
+     case 12000:
+     case 16000:
+     case 22050:
+     case 24000:
+     case 32000:
+     case 44100:
+     case 48000:
+       if (gpp->cme__combo_outsamplerate != NULL)
+       {
+         if(gap_debug)
+         {
+           printf("detected a commonly used samplerate value: %d\n", (int)gintValue );
+         }
+         gimp_int_combo_box_set_active (GIMP_INT_COMBO_BOX (gpp->cme__combo_outsamplerate)
+             , gintValue);
+       }
+       break;
+     default:
+       break;
+   }
+
+
  }
 
 }
@@ -995,7 +1231,7 @@ on_cme__button_stb_audio_clicked     (GtkButton       *button,
       if(g_file_test(gpp->val.storyboard_file, G_FILE_TEST_EXISTS))
       {
         gpp->storyboard_create_composite_audio = TRUE;
-	gap_cme_gui_check_storyboard_file(gpp);
+        gap_cme_gui_check_storyboard_file(gpp);
       }
     }
   }
