@@ -10,7 +10,7 @@
  *  - selection and execution of the desired videoencoder Plug-In.
  *
  * videoencoder plug-ins are registered in the gimp-PDB like any other plug-in
- * but have special names (starting with the prefix: plug_in_gap_enc_ )
+ * but have special names (starting with the prefix: plug-in-gap-enc- )
  * and must provide an API (PDB-procedures) for query their name and other properties.
  * (the Master uses this API to identify all available videoencoders dynamically at runtime)
  */
@@ -51,10 +51,10 @@
 
 #include "gap-intl.h"
 
+#include "gap_libgapbase.h"
 #include "gap_cme_main.h"
 #include "gap_cme_gui.h"
 
-#include "gap_file_util.h"
 #include "gap_gve_sox.h"
 #include "gap_gve_story.h"
 #include "gap_libgimpgap.h"
@@ -129,12 +129,12 @@ query ()
                                },
     {GIMP_PDB_STRING,   "filtermacro_file", "macro to apply on each handled frame."
                                             " filtermacro_files are textfiles with filter plugin names and LASTVALUE bufferdump,"
-					    " usually created by gimp-gap filermacro dialog "
-					    " (menu: Filters->Filtermacro)"},
+                                            " usually created by gimp-gap filermacro dialog "
+                                            " (menu: Filters->Filtermacro)"},
     {GIMP_PDB_STRING,   "storyboard_file", "textfile with list of one or more images, framesequences, videoclips or audioclips (see storyboard docs for more information)"},
     {GIMP_PDB_INT32,    "input_mode", "0 ... image is one of the frames to encode, range_from/to params refere to numberpart of the other frameimages on disc. \n"
                                       "1 ... image is multilayer, range_from/to params refere to layer index. \n"
-				      "2 ... image is ignored, input is specified by storyboard_file parameter."},
+                                      "2 ... image is ignored, input is specified by storyboard_file parameter."},
   };
   static int nargs_qt_enc = sizeof(args_qt_enc) / sizeof(args_qt_enc[0]);
 
@@ -157,151 +157,21 @@ query ()
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
                          GAP_VERSION_WITH_DATE,
-                         N_("Master Videoencoder"),
+                         N_("Master Videoencoder..."),
                          "RGB*, INDEXED*, GRAY*",
                          GIMP_PLUGIN,
                          nargs_qt_enc, nreturn_vals,
                          args_qt_enc, return_vals);
 
   //gimp_plugin_menu_branch_register("<Image>", "Video");
-  //gimp_plugin_menu_branch_register("<Image>/Video", "Encode");
-  
-  gimp_plugin_menu_register (GAP_CME_PLUGIN_NAME_VID_ENCODE_MASTER, N_("<Image>/Video/Encode/"));
+
+  gimp_plugin_menu_register (GAP_CME_PLUGIN_NAME_VID_ENCODE_MASTER, N_("<Image>/Video/"));
 
 }       /* end query */
 
 
-/* ----------------------------------------
- * p_call_encoder_procedure
- * ----------------------------------------
- */
-static gint
-p_call_encoder_procedure(GapCmeGlobalParams *gpp)
-{
-  GimpParam* l_params;
-  gint   l_retvals;
-  gint             l_nparams;
-  gint             l_nreturn_vals;
-  GimpPDBProcType   l_proc_type;
-  gchar            *l_proc_blurb;
-  gchar            *l_proc_help;
-  gchar            *l_proc_author;
-  gchar            *l_proc_copyright;
-  gchar            *l_proc_date;
-  GimpParamDef    *l_paramdef;
-  GimpParamDef    *l_return_vals;
-  char *l_msg;
-  gint  l_use_encoderspecific_params;
-  gint  l_rc;
-  gchar            *l_16bit_wav_file;
-  gint32           dummy_layer_id;
-
-  l_rc = -1;
-
-  l_use_encoderspecific_params = 0;  /* run with default values */
 
 
-  if(gpp->val.ecp_sel.vid_enc_plugin[0] == '\0')
-  {
-     printf("p_call_encoder_procedure: No encoder available (exit)\n");
-     return -1;
-  }
-
-  if(gpp->val.ecp_sel.gui_proc[0] != '\0')
-  {
-    l_use_encoderspecific_params = 1;  /* run with encoder specific values */
-  }
-
-  if(gap_debug)
-  {
-     printf("p_call_encoder_procedure %s: START\n", gpp->val.ecp_sel.vid_enc_plugin);
-     printf("  videoname: %s\n", gpp->val.videoname);
-     printf("  audioname1: %s\n", gpp->val.audioname1);
-     printf("  basename: %s\n", gpp->ainfo.basename);
-     printf("  extension: %s\n", gpp->ainfo.extension);
-     printf("  range_from: %d\n", (int)gpp->val.range_from);
-     printf("  range_to: %d\n", (int)gpp->val.range_to);
-     printf("  framerate: %f\n", (float)gpp->val.framerate);
-     printf("  samplerate: %d\n", (int)gpp->val.samplerate);
-     printf("  wav_samplerate: %d\n", (int)gpp->val.wav_samplerate1);
-     printf("  vid_width: %d\n", (int)gpp->val.vid_width);
-     printf("  vid_height: %d\n", (int)gpp->val.vid_height);
-     printf("  vid_format: %d\n", (int)gpp->val.vid_format);
-     printf("  image_ID: %d\n", (int)gpp->val.image_ID);
-     printf("  l_use_encoderspecific_params: %d\n", (int)l_use_encoderspecific_params);
-     printf("  filtermacro_file: %s\n", gpp->val.filtermacro_file);
-     printf("  storyboard_file: %s\n", gpp->val.storyboard_file);
-     printf("  input_mode: %d\n", gpp->val.input_mode);
-  }
-
-  if(FALSE == gimp_procedural_db_proc_info (gpp->val.ecp_sel.vid_enc_plugin,
-                          &l_proc_blurb,
-                          &l_proc_help,
-                          &l_proc_author,
-                          &l_proc_copyright,
-                          &l_proc_date,
-                          &l_proc_type,
-                          &l_nparams,
-                          &l_nreturn_vals,
-                          &l_paramdef,
-                          &l_return_vals))
-  {
-     l_msg = g_strdup_printf(_("Required Plugin %s not available"), gpp->val.ecp_sel.vid_enc_plugin);
-     if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
-     {
-       g_message(l_msg);
-     }
-     g_free(l_msg);
-     return -1;
-  }
-
-  l_16bit_wav_file = &gpp->val.audioname1[0];
-  if(gpp->val.tmp_audfile[0] != '\0')
-  {
-     l_16bit_wav_file = &gpp->val.tmp_audfile[0];
-  }
-
-
-  /* generic call of GAP video encoder plugin */
-  dummy_layer_id = gap_image_get_any_layer(gpp->val.image_ID);
-  l_params = gimp_run_procedure (gpp->val.ecp_sel.vid_enc_plugin,
-                     &l_retvals,
-                     GIMP_PDB_INT32,  gpp->val.run_mode,
-                     GIMP_PDB_IMAGE,  gpp->val.image_ID,
-                     GIMP_PDB_DRAWABLE, dummy_layer_id,
-                     GIMP_PDB_STRING, gpp->val.videoname,
-                     GIMP_PDB_INT32,  gpp->val.range_from,
-                     GIMP_PDB_INT32,  gpp->val.range_to,
-                     GIMP_PDB_INT32,  gpp->val.vid_width,
-                     GIMP_PDB_INT32,  gpp->val.vid_height,
-                     GIMP_PDB_INT32,  gpp->val.vid_format,
-                     GIMP_PDB_FLOAT,  gpp->val.framerate,
-                     GIMP_PDB_INT32,  gpp->val.samplerate,
-                     GIMP_PDB_STRING, l_16bit_wav_file,
-                     GIMP_PDB_INT32,  l_use_encoderspecific_params,
-                     GIMP_PDB_STRING, gpp->val.filtermacro_file,
-                     GIMP_PDB_STRING, gpp->val.storyboard_file,
-                     GIMP_PDB_INT32,  gpp->val.input_mode,
-                     GIMP_PDB_END);
-  if(l_params[0].data.d_status == GIMP_PDB_SUCCESS)
-  {
-    l_rc = 0;
-  }
-  g_free(l_params);
-
-  if(l_rc < 0)
-  {
-     l_msg = g_strdup_printf(_("Call of Required Plugin %s failed"), gpp->val.ecp_sel.vid_enc_plugin);
-     if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
-     {
-       g_message(l_msg);
-     }
-     g_free(l_msg);
-  }
-
-
-  return (l_rc);
-}  /* end p_call_encoder_procedure */
 
 /* ----------------------------------------
  * gap_cme_main_get_global_params
@@ -396,9 +266,12 @@ run (const gchar *name,          /* name of plugin */
 
       if (gpp->val.run_mode == GIMP_RUN_NONINTERACTIVE)
       {
-        if (n_params == GAP_VENC_NUM_STANDARD_PARAM)
+        /* the masterencoder is called without the master_encoder_id parameter
+         * (therefore its number of arguments is GAP_VENC_NUM_STANDARD_PARAM -1)
+         */
+        if (n_params >= GAP_VENC_NUM_STANDARD_PARAM -1)
         {
-	  l_copy_parameters = TRUE;
+          l_copy_parameters = TRUE;
         }
         else
         {
@@ -407,26 +280,26 @@ run (const gchar *name,          /* name of plugin */
       }
       else 
       {
-	if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
-	{
-          if (n_params == GAP_VENC_NUM_STANDARD_PARAM)
+        if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
+        {
+          if (n_params >= GAP_VENC_NUM_STANDARD_PARAM -1)
           {
-	    l_copy_parameters = TRUE;
-	  }
-	  /* dont complain on less parameters at INTERCATIVE calls */ 
-	}
-	else
-	{
+            l_copy_parameters = TRUE;
+          }
+          /* dont complain on less parameters at INTERCATIVE calls */ 
+        }
+        else
+        {
            values[0].data.d_status = GIMP_PDB_CALLING_ERROR;
-	}
+        }
       }
       
       if(l_copy_parameters)
       {
            if(param[3].data.d_string)
-	   {
-	     g_snprintf(gpp->val.videoname, sizeof(gpp->val.videoname), "%s", param[3].data.d_string);
-	   }
+           {
+             g_snprintf(gpp->val.videoname, sizeof(gpp->val.videoname), "%s", param[3].data.d_string);
+           }
            if (param[4].data.d_int32 >= 0) { gpp->val.range_from =    param[4].data.d_int32; }
            if (param[5].data.d_int32 >= 0) { gpp->val.range_to   =    param[5].data.d_int32; }
            if (param[6].data.d_int32 > 0)  { gpp->val.vid_width  =    param[6].data.d_int32; }
@@ -435,22 +308,22 @@ run (const gchar *name,          /* name of plugin */
            gpp->val.framerate   = MAX(param[9].data.d_float, 1.0);
            gpp->val.samplerate  = param[10].data.d_int32;
            if(param[11].data.d_string) 
-	   { 
-	     g_snprintf(gpp->val.audioname1, sizeof(gpp->val.audioname1), "%s", param[11].data.d_string);
-	   }
-	   if(param[12].data.d_string)
-	   {
+           { 
+             g_snprintf(gpp->val.audioname1, sizeof(gpp->val.audioname1), "%s", param[11].data.d_string);
+           }
+           if(param[12].data.d_string)
+           {
              g_snprintf(gpp->val.ecp_sel.vid_enc_plugin, sizeof(gpp->val.ecp_sel.vid_enc_plugin), "%s", param[12].data.d_string);
-	   }
-	   if(param[13].data.d_string)
-	   {
+           }
+           if(param[13].data.d_string)
+           {
              g_snprintf(gpp->val.filtermacro_file, sizeof(gpp->val.filtermacro_file), "%s", param[13].data.d_string);
-	   }
-	   if(param[14].data.d_string)
-	   {
+           }
+           if(param[14].data.d_string)
+           {
              g_snprintf(gpp->val.storyboard_file, sizeof(gpp->val.storyboard_file), "%s", param[14].data.d_string);
-	   }
-	   
+           }
+           
            if (param[15].data.d_int32 >= 0) { gpp->val.input_mode  =   param[15].data.d_int32; }
       }
 
@@ -458,20 +331,24 @@ run (const gchar *name,          /* name of plugin */
       {
          if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
          {
-            if(gap_debug) printf("MAIN before gap_cme_gui_master_encoder_dialog ------------------\n");
+            if(gap_debug)
+            {
+               printf("MAIN before gap_cme_gui_master_encoder_dialog ------------------\n");
+            }
+            
+            /* note that the dialog alrady performs the encoding (as worker thread) */
             l_rc = gap_cme_gui_master_encoder_dialog (gpp);
-            if(gap_debug) printf("MAIN after gap_cme_gui_master_encoder_dialog ------------------\n");
-	    if(l_rc < 0)
-	    {
+            
+            
+            if(gap_debug)
+            {
+              printf("MAIN after gap_cme_gui_master_encoder_dialog ------------------\n");
+            }
+            if(l_rc < 0)
+            {
               values[0].data.d_status = GIMP_PDB_CANCEL;
-	    }
-
-            /* delete images in the cache
-             * (the cache may have been filled while parsing
-             * storyboard file in the common dialog
-             */
-             gap_gve_story_drop_image_cache();
-            if(gap_debug) printf("MAIN after gap_gve_story_drop_image_cache ------------------\n");
+            }
+            
          }
          else
          {
@@ -480,65 +357,9 @@ run (const gchar *name,          /* name of plugin */
              * but in noninteractive modes we have to resample now.
              */
             l_rc =   gap_gve_sox_chk_and_resample(&gpp->val);
-         }
-
-
-         if (l_rc >= 0 )
-         {
-            char *l_tmpname;
-            gint32 l_tmp_image_id;
-
-            l_tmpname = NULL;
-            l_tmp_image_id = -1;
-
-            if((gpp->ainfo.last_frame_nr - gpp->ainfo.first_frame_nr == 0)
-            && (gpp->val.storyboard_file[0] == '\0'))
+            if (l_rc >= 0 )
             {
-              char *l_current_name;
-
-              if((strcmp(gpp->ainfo.extension, ".xcf") == 0)
-              || (strcmp(gpp->ainfo.extension, ".xjt") == 0))
-              {
-                /* for xcf and xjt just save without making a temp copy */
-                l_tmpname = gimp_image_get_filename(gpp->val.image_ID);
-              }
-              else
-              {
-                /* prepare encoder params to run the encoder on the (saved) duplicate of the image */
-                g_snprintf(gpp->ainfo.basename, sizeof(gpp->ainfo.basename), "%s", l_tmpname);
-
-                /* save a temporary copy of the image */
-                l_tmp_image_id = gimp_image_duplicate(gpp->val.image_ID);
-
-                /* l_tmpname = gimp_temp_name("xcf"); */
-                l_current_name = gimp_image_get_filename(gpp->val.image_ID);
-                l_tmpname = g_strdup_printf("%s_temp_copy.xcf", l_current_name);
-                gimp_image_set_filename (l_tmp_image_id, l_tmpname);
-                gpp->ainfo.extension[0] = '\0';
-                gpp->val.image_ID = l_tmp_image_id;
-                g_free(l_current_name);
-              }
-
-              gimp_file_save(GIMP_RUN_NONINTERACTIVE
-                            , gpp->val.image_ID
-                            , 1 /* dummy layer_id */
-                            ,l_tmpname
-                            ,l_tmpname
-                            );
-
-            }
-
-            /* ------------------------------------------- HERE WE GO, start Video Encoder ---- */
-            l_rc = p_call_encoder_procedure(gpp);
-
-            if(l_tmp_image_id >= 0)
-            {
-              gap_image_delete_immediate(l_tmp_image_id);
-              g_remove(l_tmpname);
-            }
-            if(l_tmpname)
-            {
-              g_free(l_tmpname);
+               l_rc = gap_cme_gui_start_video_encoder(gpp);
             }
          }
 
@@ -547,23 +368,34 @@ run (const gchar *name,          /* name of plugin */
            g_remove(gpp->val.tmp_audfile);
          }
 
-         /* is the encoder specific gui_thread still open ? */
-         if(gpp->val.gui_proc_thread != NULL)
-         {
-            /* wait until thread exits */
-            g_thread_join(gpp->val.gui_proc_thread);
-	    gpp->val.gui_proc_thread = NULL;
-         }
       }
+
+      /* wait 8 seconds to give the encoder process a chance to exit 
+       * (and/or accept a possible cancel request)
+       */
+      usleep(800000);
+
+      if(gap_debug)
+      {
+        printf("MAIN cleanup ------------------\n");
+      }
+
+      /* clean up removes the communication file and the cancel request file (if there is any)
+       * note that this shall happen after the encoder process has exited.
+       * (otherwise the files used for communication may be created again after the
+       * following cleanup
+       */
+      gap_gve_misc_cleanup_GapGveMasterEncoder(gpp->encStatus.master_encoder_id);
   }
   else
   {
       values[0].data.d_status = GIMP_PDB_CALLING_ERROR;
   }
 
- if((l_rc < 0) && (values[0].data.d_status == GIMP_PDB_SUCCESS))
- {
+
+  if((l_rc < 0) && (values[0].data.d_status == GIMP_PDB_SUCCESS))
+  {
     values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
- }
+  }
 
 }  /* end run */
