@@ -43,13 +43,6 @@
 #include <libgimp/gimpui.h>
 
 
-/* names of the supported AVI Codecs */
-#define GAP_AVI_CODEC_RAW  "RAW "   /* refers to 4 byte code "RGB " */
-#define GAP_AVI_CODEC_RGB  "RGB "
-#define GAP_AVI_CODEC_JPEG "JPEG"
-/* ??? not sure what to use for the correct 4cc codec names for xvid divx MPEG 4 */
-#define GAP_AVI_CODEC_XVID "XVID"
-#define GAP_AVI_CODEC_DIVX "div5"
 
 
 
@@ -57,7 +50,7 @@
 #include "gap_gvetypes.h"
 
 
-#include "gap_file_util.h"
+#include "gap_libgapbase.h"
 #include "gap_libgimpgap.h"
 #include "gap_audio_wav.h"
 #include "gap_arr_dialog.h"    /* for the GUI provisorium */
@@ -73,7 +66,6 @@
 
 
 static gint p_avi_encode(GapGveAviGlobalParams *gpp);
-static gint p_avi_encode_dialog(GapGveAviGlobalParams *gpp);
 
 
 /* Includes for extra LIBS */
@@ -148,7 +140,8 @@ query ()
     {GIMP_PDB_STRING, "storyboard_file", "textfile with list of one or more framesequences"},
     {GIMP_PDB_INT32,  "input_mode", "0 ... image is one of the frames to encode, range_from/to params refere to numberpart of the other frameimages on disc. \n"
                                     "1 ... image is multilayer, range_from/to params refere to layer index. \n"
-				    "2 ... image is ignored, input is specified by storyboard_file parameter."},
+                                    "2 ... image is ignored, input is specified by storyboard_file parameter."},
+    {GIMP_PDB_INT32, "master_encoder_id", "id of the master encoder that called this plug-in (typically the pid)"},
   };
   static int nargs_avi_enc = sizeof(args_avi_enc) / sizeof(args_avi_enc[0]);
 
@@ -158,8 +151,8 @@ query ()
     {GIMP_PDB_INT32, "run_mode", "interactive, non-interactive"},
     {GIMP_PDB_STRING, "key_stdpar", "key to get standard video encoder params via gimp_get_data"},
     {GIMP_PDB_STRING, "codec_name", "identifier of the codec. one of the strings \"JPEG\", \"RGB\", \"DIVX\" "},
-    {GIMP_PDB_INT32, "dont_recode_frames", "=1: store the frames _directly_ into the AVI. "
-                                 "(works only for codec_name JPEG and input frames must be 4:2:2 JPEG !)"},
+    {GIMP_PDB_INT32, "jpeg_dont_recode_frames", "=1: store the frames _directly_ into the AVI where possible. "
+                                 "(works only for codec_name MJPG or JPEG and input frames must be 4:2:2 JPEG !)"},
     {GIMP_PDB_INT32, "jpeg_interlaced", "=1: store two JPEG frames, for the odd/even lines"},
     {GIMP_PDB_INT32, "jpeg_quality", "the quality of the coded jpegs (0 - 100%)"},
     {GIMP_PDB_INT32, "jpeg_odd_even", "if jpeg_interlaced: odd frames first ?"},
@@ -179,7 +172,12 @@ query ()
     {GIMP_PDB_INT32, "APP0_marker", "=1: write APP0 marker for each frame into the AVI. "
                                  "( The APP0 marker is evaluated by some Windows programs for AVIs)"},
 
-    {GIMP_PDB_INT32, "raw_vflip", "=1: flip vertically (only for codec_name RAW and RGB )"}
+    {GIMP_PDB_INT32, "raw_vflip", "=1: flip vertically (only for codec_name RAW and RGB )"},
+
+    {GIMP_PDB_INT32, "png_dont_recode_frames", "=1: store the frames _directly_ into the AVI where possible. "
+                                 "(works only for codec_name PNG )"},
+    {GIMP_PDB_INT32, "png_interlaced", "=1: interlaced png frames, 0= no interlace"},
+    {GIMP_PDB_INT32, "png_compression", "the compression of the coded pngs (0 - 9) where 9 is best and 0 is fast "}
   };
   static int nargs_avi_enc_par = sizeof(args_avi_enc_par) / sizeof(args_avi_enc_par[0]);
 
@@ -206,7 +204,7 @@ query ()
 
   gimp_install_procedure(GAP_PLUGIN_NAME_AVI_ENCODE,
                          _("avi video encoding for anim frames. Menu: @AVI@"),
-                         _("This plugin does fake video encoding of animframes."
+                         _("This plugin handles video encoding for the AVI videoformat."
                          " the (optional) audiodata must be a raw datafile(s) or .wav (RIFF WAVEfmt ) file(s)"
                          " .wav files can be mono (1) or stereo (2channels) audiodata must be 16bit uncompressed."
                          " IMPORTANT:  you should first call "
@@ -368,7 +366,7 @@ run (const gchar *name,          /* name of plugin */
              g_snprintf(epp->codec_name, sizeof(epp->codec_name), "%s", param[2+1].data.d_string);
            }
            l_ii = 2+2;
-           epp->dont_recode_frames = param[l_ii++].data.d_int32;
+           epp->jpeg_dont_recode_frames = param[l_ii++].data.d_int32;
            epp->jpeg_interlaced    = param[l_ii++].data.d_int32;
            epp->jpeg_quality       = param[l_ii++].data.d_int32;
            epp->jpeg_odd_even      = param[l_ii++].data.d_int32;
@@ -388,6 +386,10 @@ run (const gchar *name,          /* name of plugin */
 
            epp->raw_vflip                      = param[l_ii++].data.d_int32;
 
+           epp->png_dont_recode_frames = param[l_ii++].data.d_int32;
+           epp->png_interlaced    = param[l_ii++].data.d_int32;
+           epp->png_compression   = param[l_ii++].data.d_int32;
+
         }
       }
       else
@@ -395,7 +397,6 @@ run (const gchar *name,          /* name of plugin */
         /* try to read encoder specific params */
         p_gimp_get_data(l_encoder_key, epp, sizeof(GapGveAviValues));
 
-        ///////  if(0 != p_avi_encode_dialog(gpp))
         if(0 != gap_enc_avi_gui_dialog(gpp))
         {
           l_set_it = FALSE;
@@ -481,6 +482,8 @@ run (const gchar *name,          /* name of plugin */
         if (param[13].data.d_string[0] != '\0') { g_snprintf(gpp->val.filtermacro_file, sizeof(gpp->val.filtermacro_file), "%s", param[13].data.d_string); }
         if (param[14].data.d_string[0] != '\0') { g_snprintf(gpp->val.storyboard_file, sizeof(gpp->val.storyboard_file), "%s", param[14].data.d_string); }
         if (param[15].data.d_int32 >= 0) { gpp->val.input_mode   =    param[15].data.d_int32; }
+        
+        gpp->val.master_encoder_id = param[16].data.d_int32;
       }
 
       if (values[0].data.d_status == GIMP_PDB_SUCCESS)
@@ -543,8 +546,8 @@ gap_enc_avi_main_init_default_params(GapGveAviValues *epp)
 {
   if(gap_debug) printf("gap_enc_avi_main_init_default_params\n");
 
-  g_snprintf(epp->codec_name, sizeof(epp->codec_name), GAP_AVI_CODEC_JPEG);
-  epp->dont_recode_frames = 0;
+  g_snprintf(epp->codec_name, sizeof(epp->codec_name), GAP_AVI_CODEC_MJPG);
+  epp->jpeg_dont_recode_frames = 0;
   epp->jpeg_interlaced    = 0;
   epp->jpeg_quality       = 84;
   epp->jpeg_odd_even      = 0;
@@ -568,205 +571,18 @@ gap_enc_avi_main_init_default_params(GapGveAviValues *epp)
 }  /* end gap_enc_avi_main_init_default_params */
 
 
-/* ============================================================================
- * p_avi_encode_dialog
- *
- *   return  0 .. OK
- *          -1 .. in case of Error or cancel
- * ============================================================================
- */
-static gint
-p_avi_encode_dialog(GapGveAviGlobalParams *gpp)
+gint32
+p_dimSizeOfRawFrame(GapGveAviGlobalParams *gpp)
 {
-#define ARGC_AVI_DIALOG_PARAMS_MAX 28
-  gint argc_avi_dialog_params;
-  static GapArrArg  argv[ARGC_AVI_DIALOG_PARAMS_MAX];
-  GapGveAviValues *epp;
-  gint  l_ii;
+  gint32 sizeOfRawFrame;
 
-  gint idx_app_mark;
-  gint xvid_bitrate;
-  gint xvid_rcdelay;
-  gint xvid_rcperiod;
-  gint xvid_rcbuffer;
-  gint xvid_maxq;
-  gint xvid_minq;
-  gint xvid_keyint;
-  gint xvid_qpreset;
-
-
-  epp = &gpp->evl;
-
-
-  l_ii = 0;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_LABEL);
-  argv[l_ii].label_txt = _("AVI encoding options");
-
-  l_ii = 1;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_TEXT);
-  argv[l_ii].label_txt = _("CODEC Name:");
-  argv[l_ii].help_txt =_("4 char codec code name. One of: RGB (raw uncompressed) JPEG,  XVID");
-  argv[l_ii].text_buf_len = sizeof(epp->codec_name);
-  argv[l_ii].text_buf_ret = epp->codec_name;
-
-  /* --------------- JPEG options ----------------------- */
-
-  l_ii = 2;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_TOGGLE);
-  argv[l_ii].label_txt =_("Don't recode");
-  argv[l_ii].help_txt =_("Don't recode the input JPEG frames (works for 4:2:2 JPEG only, may result in unreadable Video)");
-  argv[l_ii].int_ret = epp->dont_recode_frames;
-
-  l_ii = 3;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_TOGGLE);
-  argv[l_ii].label_txt = _("Interlaced Frames");
-  argv[l_ii].help_txt = _("Generate interlaced JPEGs (two frames for odd/even lines)");
-  argv[l_ii].int_ret = epp->jpeg_interlaced;
-
-  l_ii = 4;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_TOGGLE);
-  argv[l_ii].label_txt = _("Odd Frames first");
-  argv[l_ii].help_txt = _("Check if you want the odd frames to be coded first (only for interlaced JPEGs)");
-  argv[l_ii].int_ret = epp->jpeg_odd_even;
-
-  l_ii = 5;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("JPEG quality:");
-  argv[l_ii].help_txt  = _("The quality setting of the generated JPEG frames (100=best)");
-  argv[l_ii].int_min   = 0;
-  argv[l_ii].int_max   = 100;
-  argv[l_ii].int_ret   = epp->jpeg_quality;
-
-  /* --------------- XVID options ----------------------- */
-
-  l_ii++;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_LABEL);
-  argv[l_ii].label_txt = _("options for the XVID CODEC");
-
-  l_ii++;
-  xvid_bitrate = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("KBitrate:");
-  argv[l_ii].help_txt  = _("Kilobitrate for XVID Codec (1 = 1000 Bit/sec) -1 for default");
-  argv[l_ii].int_min   = -1;
-  argv[l_ii].int_max   = 9999;
-  argv[l_ii].int_ret   = epp->xvid.rc_bitrate / 1000;
-
-  l_ii++;
-  xvid_rcdelay = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("rc_reaction_delay:");
-  argv[l_ii].help_txt  = _("for XVID Codec  -1 for default");
-  argv[l_ii].int_min   = -1;
-  argv[l_ii].int_max   = 100;
-  argv[l_ii].int_ret   = epp->xvid.rc_reaction_delay_factor;
-
-  l_ii++;
-  xvid_rcperiod = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("rc_avg_period:");
-  argv[l_ii].help_txt  = _("for XVID Codec  -1 for default");
-  argv[l_ii].int_min   = -1;
-  argv[l_ii].int_max   = 1000;
-  argv[l_ii].int_ret   = epp->xvid.rc_averaging_period;
-
-  l_ii++;
-  xvid_rcbuffer = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("rc_buffer:");
-  argv[l_ii].help_txt  = _("for XVID Codec  -1 for default");
-  argv[l_ii].int_min   = -1;
-  argv[l_ii].int_max   = 100;
-  argv[l_ii].int_ret   = epp->xvid.rc_buffer;
-
-  l_ii++;
-  xvid_maxq = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("max_quantizer:");
-  argv[l_ii].help_txt  = _("for XVID Codec  upper limit for quantize Range 1 == BEST Quality ");
-  argv[l_ii].int_min   = 1;
-  argv[l_ii].int_max   = 31;
-  argv[l_ii].int_ret   = epp->xvid.max_quantizer;
-
-  l_ii++;
-  xvid_minq = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("min_quantizer:");
-  argv[l_ii].help_txt  = _("for XVID Codec  lower limit for quantize Range 1 == BEST Quality ");
-  argv[l_ii].int_min   = 1;
-  argv[l_ii].int_max   = 31;
-  argv[l_ii].int_ret   = epp->xvid.min_quantizer;
-
-  l_ii++;
-  xvid_keyint = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("key_interval:");
-  argv[l_ii].help_txt  = _("for XVID Codec  max distance for keyframes (I-frames) ");
-  argv[l_ii].int_min   = 1;
-  argv[l_ii].int_max   = 500;
-  argv[l_ii].int_ret   = epp->xvid.max_key_interval;
-
-
-  l_ii++;
-  xvid_qpreset = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_INT_PAIR);
-  argv[l_ii].constraint = TRUE;
-  argv[l_ii].label_txt = _("quality:");
-  argv[l_ii].help_txt  = _("for XVID Codec select algoritm presets where 0==low quality(fast) 6==best(slow) ");
-  argv[l_ii].int_min   = 0;
-  argv[l_ii].int_max   = 6;
-  argv[l_ii].int_ret   = epp->xvid.quality_preset;
-
-
-  /* --------------- APP0 Marker ----------------------- */
-  l_ii++;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_LABEL);
-  argv[l_ii].label_txt = _("APP0 Marker for each frame");
-
-  l_ii++;
-  idx_app_mark = l_ii;
-  gap_arr_arg_init(&argv[l_ii], GAP_ARR_WGT_TOGGLE);
-  argv[l_ii].label_txt =_("APP0 Marker:");
-  argv[l_ii].help_txt =_("Write APP0 Marker for each encoded frame."
-                         " (The APP0 marker is evaluated by some Windows programs for AVIs");
-  argv[l_ii].int_ret = epp->APP0_marker;
-
-  argc_avi_dialog_params = l_ii + 1;
-
-  if(TRUE == gap_arr_ok_cancel_dialog("GAP AVI Encode",
-                                 "Settings :",
-                                  argc_avi_dialog_params, argv))
-  {
-      epp->dont_recode_frames       = (long)(argv[2].int_ret);
-      epp->jpeg_interlaced          = (long)(argv[3].int_ret);
-      epp->jpeg_odd_even            = (long)(argv[4].int_ret);
-      epp->jpeg_quality             = (long)(argv[5].int_ret);
-
-      epp->xvid.rc_bitrate               = (long)(argv[xvid_bitrate].int_ret)  * 1000;
-      epp->xvid.rc_reaction_delay_factor = (long)(argv[xvid_rcdelay].int_ret);
-      epp->xvid.rc_averaging_period      = (long)(argv[xvid_rcperiod].int_ret);
-      epp->xvid.rc_buffer                = (long)(argv[xvid_rcbuffer].int_ret);
-      epp->xvid.max_quantizer            = (long)(argv[xvid_maxq].int_ret);
-      epp->xvid.min_quantizer            = (long)(argv[xvid_minq].int_ret);
-      epp->xvid.max_key_interval         = (long)(argv[xvid_keyint].int_ret);
-      epp->xvid.quality_preset           = (long)(argv[xvid_qpreset].int_ret);
-      epp->APP0_marker                   = (long)(argv[idx_app_mark].int_ret);
-
-      return 0;
-  }
-  else
-  {
-      return -1;
-  }
-}    /* end p_avi_encode_dialog */
+  /* size of uncompressed RGBA frame + safety of 1000 bytes should be
+   * more than enough
+   */
+  sizeOfRawFrame = 1000 + (gpp->val.vid_width * gpp->val.vid_height * 4);
+  
+  return (sizeOfRawFrame);
+}  /* end p_dimSizeOfRawFrame */
 
 
 /* ============================================================================
@@ -783,6 +599,7 @@ p_avi_encode_dialog(GapGveAviGlobalParams *gpp)
 static gint
 p_avi_encode(GapGveAviGlobalParams *gpp)
 {
+#define AUDIO_CHUNK_ADVANCE_FRAMES 16
   GapGveAviValues   *epp;
   avi_t               *l_avifile;
   static GapGveStoryVidHandle *l_vidhand = NULL;
@@ -796,7 +613,6 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
 
   FILE *l_fp_inwav = NULL;
   gint32 l_FRAME_size;
-  gint32 datasize;
   gint32 audio_size = 0;
   gint32 audio_stereo = 0;
   long  l_sample_rate = 22050;
@@ -806,14 +622,29 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
   long  l_samples = 0;
 
   guchar *buffer; /* Holding misc. file contents */
+  unsigned char *l_video_chunk_ptr;
+  gint32         l_maxSizeOfRawFrame;
+  gint32         l_max_master_frame_nr;
+  gint32         l_cnt_encoded_frames;
+  gint32         l_cnt_reused_frames;
+  gint32         l_check_flags;
+  gint32         l_out_frame_nr;
+  
+  gdouble        audio_samples_per_frame;
+  gint32         audio_samples_per_frame_gint32;
+  gint32         audio_bytes_per_frame_gint32;
+  gint32         audio_bytes_done_in_advance = 0;
+  gint32         l_frames_to_go;
 
   gint32 wavsize = 0; /* Data size of the wav file */
   long audio_margin = 8192; /* The audio chunk size */
-  long audio_filled_100 = 0;
-  long audio_per_frame_x100 = -1;
-  long frames_per_second_x100 = 2500;
-  gdouble frames_per_second_x100f = 2500;
+
+
   char databuffer[300000]; /* For transferring audio data */
+  gint32   l_video_frame_chunk_size;
+  gint32   l_video_frame_chunk_hdr_size;
+  gboolean l_dont_recode_frames;
+  GapGveMasterEncoderStatus encStatus;
 
 #ifdef ENABLE_LIBXVIDCORE
   GapGveXvidControl      *xvid_control = NULL;
@@ -839,22 +670,37 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
      printf("  input_mode: %d\n", gpp->val.input_mode);
 
      printf("  codec_name:%s:\n", epp->codec_name);
+     printf("  master_encoder_id:%d:\n", gpp->val.master_encoder_id);
   }
 
+  l_maxSizeOfRawFrame = p_dimSizeOfRawFrame(gpp);
+  l_video_chunk_ptr = g_malloc0(l_maxSizeOfRawFrame);
+
+  l_out_frame_nr = 0;
   l_rc = 0;
   l_layer_id = -1;
+  l_cnt_encoded_frames = 0;
+  l_cnt_reused_frames = 0;
+  l_tmp_image_id = -1;
+  l_check_flags = GAP_VID_CHCHK_FLAG_SIZE;
+  l_video_frame_chunk_size = 0;
+  l_video_frame_chunk_hdr_size = 0;
+  l_dont_recode_frames = FALSE;
+
 
   /* make list of frameranges */
-  { gint32 l_total_framecount;
-  l_vidhand = gap_gve_story_open_vid_handle (gpp->val.input_mode
-                                       ,gpp->val.image_ID
-				       ,gpp->val.storyboard_file
-                                       ,gpp->ainfo.basename
-                                       ,gpp->ainfo.extension
-                                       ,gpp->val.range_from
-                                       ,gpp->val.range_to
-                                       ,&l_total_framecount
-                                       );
+  {
+    gint32 l_total_framecount;
+    l_vidhand = gap_gve_story_open_vid_handle (gpp->val.input_mode
+                                         ,gpp->val.image_ID
+                                         ,gpp->val.storyboard_file
+                                         ,gpp->ainfo.basename
+                                         ,gpp->ainfo.extension
+                                         ,gpp->val.range_from
+                                         ,gpp->val.range_to
+                                         ,&l_total_framecount
+                                         );
+    l_vidhand->do_gimp_progress = FALSE;
   }
 
   /* TODO check for overwrite */
@@ -870,7 +716,10 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
   l_percentage = 0.0;
   if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
   {
-    gimp_progress_init(_("AVI Video Encoding .."));
+    gap_gve_misc_initGapGveMasterEncoderStatus(&encStatus
+       , gpp->val.master_encoder_id
+       , abs(gpp->val.range_to - gpp->val.range_from) + 1   /* total_frames */
+       );
   }
 
 
@@ -890,21 +739,33 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
 
     /* open WAVE file and set position to the 1.st audio databyte */
     l_fp_inwav = gap_audio_wav_open_seek_data(gpp->val.audioname1);
+    
+    if(gap_debug)
+    {
+      printf("Audiocheck results for file:%s\n", gpp->val.audioname1);
+      printf("  wavsize:%d\n", (int)wavsize);
+      printf("  l_samples:%d\n", (int)l_samples);
+      printf("  l_bytes_per_sample:%d\n", (int)l_bytes_per_sample);
+      printf("  l_channels:%d\n", (int)l_channels);
+      printf("  l_sample_rate:%d\n", (int)l_sample_rate);
+      printf("  audio_size (in bits):%d\n", (int)audio_size);
+      printf("  audio_stereo:%d\n", (int)audio_stereo);
+    }
   }
 
 
   /* Calculations for encoding the sound into the avi
    */
+  audio_samples_per_frame = l_sample_rate / MAX(1.0, gpp->val.framerate);
+  audio_samples_per_frame_gint32 = (audio_samples_per_frame + 0.5);
+  audio_bytes_per_frame_gint32 = audio_samples_per_frame_gint32 * l_bytes_per_sample;
 
-  /* ORIGINAL CODE:
-   *  frames_per_second_x100 = (norm == 0) ? 2500 : 2997;
-   *  audio_per_frame_x100 = (100 * 100 * l_sample_rate * audio_size / 8 *
-   *                        ((audio_stereo == TRUE) ? 2 : 1)) / frames_per_second_x100;
-   */
-
-  frames_per_second_x100f = (100.0 * gpp->val.framerate) + 0.5;
-  frames_per_second_x100 = frames_per_second_x100f;
-  audio_per_frame_x100 = (100 * 100 * l_sample_rate * l_bytes_per_sample) / MAX(1,frames_per_second_x100);
+  if(gap_debug)
+  {
+    printf("  audio_samples_per_frame:%f\n", (float)audio_samples_per_frame);
+    printf("  audio_samples_per_frame_gint32:%d\n", (int)audio_samples_per_frame_gint32);
+    printf("  audio_bytes_per_frame_gint32:%d\n", (int)audio_bytes_per_frame_gint32);
+  }
 
 
   /* build AVI 4 byte codec name
@@ -926,11 +787,11 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
       printf("AVI 4byte code for codec_name: %s\n", codec_name);
     }
     AVI_set_video( l_avifile
-        	 , gpp->val.vid_width
-        	 , gpp->val.vid_height
-        	 , gpp->val.framerate
-        	 , codec_name           /* char *compressor  one of "RGB", "JPEG"  ... */
-        	 );
+                 , gpp->val.vid_width
+                 , gpp->val.vid_height
+                 , gpp->val.framerate
+                 , codec_name           /* char *compressor  one of "RGB", "JPEG"  ... */
+                 );
 
     g_free(codec_name);
   }
@@ -941,15 +802,26 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
                , l_sample_rate
                , (int)l_bits
                , (int)WAVE_FORMAT_PCM    /* format 1 == pcm */
-               , (long)0                 /* mp3rate (WHAT else shall i use if NO MP3 is supplied ???) */
+               , (long)((l_sample_rate * 8) / 1000)    /* mp3rate,
+                                          * as seen seen in some AVI files)
+                                          * note that some mplayer versions freezes on attempt
+                                          * to playback AVI files with mp3rate 0
+                                          */
                );
+
+    //l_avifile->must_use_index = 1;
   }
 
-  if(gap_debug) printf("next is INIT Encoder Instance ?\n");
+  if(gap_debug)
+  {
+    printf("next is INIT Encoder Instance ?\n");
+  }
 
 #ifdef ENABLE_LIBXVIDCORE
   if ((strcmp(epp->codec_name, GAP_AVI_CODEC_RGB) != 0)
   && (strcmp(epp->codec_name, GAP_AVI_CODEC_RAW) != 0)
+  && (strcmp(epp->codec_name, GAP_AVI_CODEC_PNG) != 0)
+  && (strcmp(epp->codec_name, GAP_AVI_CODEC_MJPG) != 0)
   && (strcmp(epp->codec_name, GAP_AVI_CODEC_JPEG) != 0))
   {
     if(gap_debug) printf("INIT Encoder Instance (HANDLE) for XVID (OpenDivX)\n");
@@ -963,7 +835,10 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
       printf("ERROR creation of XVID encoder instance FAILED\n");
       l_rc = -1;
     }
-    if(gap_debug)  printf("creation of XVID encoder instance DONE OK\n");
+    if(gap_debug)
+    {
+      printf("creation of XVID encoder instance DONE OK\n");
+    }
   }
 #endif
 
@@ -983,125 +858,115 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
   }
   l_begin = gpp->val.range_from;
   l_end   = gpp->val.range_to;
+  l_max_master_frame_nr = abs(l_end - l_begin) + 1;
+  l_frames_to_go = l_max_master_frame_nr;
+
+
+  l_frames_to_go = l_max_master_frame_nr;
 
   l_cur_frame_nr = l_begin;
   while(l_rc >= 0)
   {
     if(l_cur_frame_nr == l_begin) /* setup things first if this is the first frame */
     {
-      /* (light) check if dont_recode_frames is possible */
-      if (epp->dont_recode_frames)
+      /* jpeg/mjpeg codec specific check flags setup */
+      if (epp->jpeg_dont_recode_frames)
       {
-        /* DONT_RECODE works only if:
-         *  - input is a series of JPEG frames all encoded with YUV 4:2:2
-         *  - framesize is same as videosize
-         *  - codec_name is "JPEG"
-         */
-        if(gpp->val.storyboard_file)
+        if ((strcmp(epp->codec_name, GAP_AVI_CODEC_JPEG) == 0)
+        ||  (strcmp(epp->codec_name, GAP_AVI_CODEC_MJPG) == 0))
         {
-          if(*gpp->val.storyboard_file != '\0')
-          {
-            /* storyboard returns image_id of a composite image. We MUST recode here !
-             */
-            epp->dont_recode_frames = FALSE;
-          }
+           l_check_flags |= (GAP_VID_CHCHK_FLAG_JPG | GAP_VID_CHCHK_FLAG_FULL_FRAME);
+           l_dont_recode_frames = TRUE;
         }
-
-        if (strcmp(epp->codec_name, GAP_AVI_CODEC_JPEG) != 0)
+      }
+      /* png codec specific check flags setup */
+      if (epp->png_dont_recode_frames)
+      {
+        if (strcmp(epp->codec_name, GAP_AVI_CODEC_PNG) == 0)
         {
-           /* must recode the frame other codecs than JPEG */
-           epp->dont_recode_frames = FALSE;
+           l_check_flags |= (GAP_VID_CHCHK_FLAG_PNG | GAP_VID_CHCHK_FLAG_FULL_FRAME);
+           l_dont_recode_frames = TRUE;
         }
-
-        if ((strcmp(gpp->ainfo.extension, ".jpg")  != 0)
-        &&  (strcmp(gpp->ainfo.extension, ".jpeg") != 0)
-        &&  (strcmp(gpp->ainfo.extension, ".JPG")  != 0)
-        &&  (strcmp(gpp->ainfo.extension, ".JPEG") != 0))
-        {
-             /* we MUST recode if frame is no JPG,
-              * (if image does not fit in size or is not JPG or is not YUV 4:2:2
-              *  there wold be the need of recoding too
-              *  but this code does just a 'light' check for extensions)
-              */
-              epp->dont_recode_frames = FALSE;
-        }
-
+      }
+      
+      if(gap_debug)
+      {
+        printf("l_dont_recode_frames:%d\n", l_dont_recode_frames);
       }
     }     /* end setup of 1.st frame (l_cur_frame_nr == l_begin) */
 
 
-    /* must fetch the frame into gimp_image if we have to recode */
-    if (!epp->dont_recode_frames)
+
+    /* encode VIDEO PART, call the frame fetcher */
     {
-      /* load the current frame image, and transform (flatten, convert to RGB, scale, macro, etc..) */
-      l_tmp_image_id = gap_gve_story_fetch_composite_image(l_vidhand
-                                             , l_cur_frame_nr
-                                             , (gint32)  gpp->val.vid_width
-                                             , (gint32)  gpp->val.vid_height
-                                             , gpp->val.filtermacro_file
-                                             , &l_layer_id           /* output */
-                                             );
-      if(l_tmp_image_id < 0)
+      gboolean l_fetch_ok;
+      gboolean l_force_keyframe;
+    
+      l_out_frame_nr++;
+
+
+      l_fetch_ok = gap_story_render_fetch_composite_image_or_chunk(l_vidhand
+                                           , l_cur_frame_nr
+                                           , (gint32)  gpp->val.vid_width
+                                           , (gint32)  gpp->val.vid_height
+                                           , gpp->val.filtermacro_file
+                                           , &l_layer_id           /* output */
+                                           , &l_tmp_image_id       /* output */
+                                           , l_dont_recode_frames                  /* dont_recode_flag */
+                                           , NULL                  /* GapCodecNameElem *vcodec_list NULL == no checks */
+                                           , &l_force_keyframe
+                                           , l_video_chunk_ptr
+                                           , &l_video_frame_chunk_size  /* actual chunk size (incl. header) */
+                                           , l_maxSizeOfRawFrame        /* IN max size */
+                                           , gpp->val.framerate
+                                           , l_max_master_frame_nr
+                                           , &l_video_frame_chunk_hdr_size
+                                           , l_check_flags
+                                           );
+      if(l_fetch_ok != TRUE)
       {
          l_rc = -1;
       }
     }
-
+    
+    
     /* this block is done foreach handled video frame */
     if(l_rc == 0)
     {
-      /* encode one VIDEO FRAME */
-      if (epp->dont_recode_frames)
+      if (l_video_frame_chunk_size > 0)
       {
-        char *l_frame_filename;
+        /* 1:1 lossless copy one VIDEO FRAME */
+        l_cnt_reused_frames++;
 
-
-        if(gap_debug) printf("DONT_RECODE_FRAMES packing input frame 1:1 into AVI\n");
-
-        /* the DONT_RECODE_FRAMES option is fast,
-         * - but works only if input is JPEG with size is same as videosize
-         * - of course there is no support for filtermacros and storyboard stuff
-         *   because the processing of gap_gve_story_fetch_composite_image is passed by in that case!
-         */
-        /* build the frame name */
-        /* Use the gap functions to generate the frame filename */
-        l_frame_filename = gap_lib_alloc_fname(gpp->ainfo.basename,
-                                        l_cur_frame_nr,
-                                        gpp->ainfo.extension);
-        /* can't find the frame ? */
-        if(l_frame_filename == NULL)
+        if (gap_debug)
         {
-          l_rc = -1;
+          printf("DEBUG: 1:1 copy of frame %d (fetch as chunk OK) chunk_ptr:%d  chunk_size:%d chunk_hdr_size:%d\n"
+              , (int)l_cur_frame_nr
+              , (int)l_video_chunk_ptr
+              , (int)l_video_frame_chunk_size
+              , (int)l_video_frame_chunk_hdr_size
+              );
         }
-        else
-        {
-          l_FRAME_size = gap_file_get_filesize(l_frame_filename);
-          buffer = gap_file_load_file(l_frame_filename);
-          if (buffer == NULL)
-          {
-             printf("gap_avi: Failed opening encoded input frame %s.",
-                                       l_frame_filename);
-             l_rc = -1;
-          }
-          else
-          {
-            if (gap_debug) printf("gap_avi: Writing frame nr. %ld, size %d\n", l_cur_frame_nr, l_FRAME_size);
+        l_FRAME_size = l_video_frame_chunk_size - l_video_frame_chunk_hdr_size;
+        buffer = l_video_chunk_ptr + l_video_frame_chunk_hdr_size;
+
+        AVI_write_frame(l_avifile, buffer, l_FRAME_size, TRUE /* all frames are keyframe for JPEG codec */);
 
-            AVI_write_frame(l_avifile, buffer, l_FRAME_size, TRUE /* all frames are keyframe for JPEG codec */);
-          }
-        }
-        if(l_frame_filename)
-        {
-          g_free(l_frame_filename);
-        }
       }
       else
       {
+        /* encode one VIDEO FRAME */
         gint32 l_nn;
         int    l_keyframe;
         guchar *l_app0_buffer;
         gint32  l_app0_len;
 
+        l_cnt_encoded_frames++;
+        if (gap_debug)
+        {
+          printf("DEBUG: saving recoded frame %d (fetch as chunk FAILED)\n", (int)l_cur_frame_nr);
+        }
+
         l_keyframe = TRUE;  /* TRUE: keyframe is independent image (I frame or uncompressed)
                              * FALSE: for dependent frames (P and B frames)
                              */
@@ -1128,12 +993,19 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
           }
         }
 
-        if (strcmp(epp->codec_name, GAP_AVI_CODEC_JPEG) == 0)
+        if ((strcmp(epp->codec_name, GAP_AVI_CODEC_JPEG) == 0)
+        || (strcmp(epp->codec_name, GAP_AVI_CODEC_MJPG) == 0))
         {
           /* Compress the picture into a JPEG */
           buffer = gap_gve_jpeg_drawable_encode_jpeg(l_drawable, epp->jpeg_interlaced,
                                         &l_FRAME_size, epp->jpeg_quality, epp->jpeg_odd_even, FALSE, l_app0_buffer, l_app0_len);
         }
+        else if (strcmp(epp->codec_name, GAP_AVI_CODEC_PNG) == 0)
+        {
+          /* Compress the picture into a PNG */
+          buffer = gap_gve_png_drawable_encode_png(l_drawable, epp->png_interlaced,
+                                        &l_FRAME_size, epp->png_compression, l_app0_buffer, l_app0_len);
+        }
         else
         {
           if ((strcmp(epp->codec_name, GAP_AVI_CODEC_RAW) == 0)
@@ -1143,14 +1015,14 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
 
             /* fill buffer with raw 24bit data, optional flipped.
              * it seems that some AVI players (for instance the WinDVD player)
-	     *  require the inverse row order than gimp,
-	     *  and other players (like gmplayer on unix) does not need vflipped images.
+             *  require the inverse row order than gimp,
+             *  and other players (like gmplayer on unix) does not need vflipped images.
              */
             l_vflip = FALSE;
             if(epp->raw_vflip != 0)
-	    {
-	      l_vflip = TRUE;
-	    }
+            {
+              l_vflip = TRUE;
+            }
             buffer = gap_gve_raw_BGR_drawable_encode(l_drawable, &l_FRAME_size, l_vflip, l_app0_buffer, l_app0_len);
           }
 #ifdef ENABLE_LIBXVIDCORE
@@ -1166,76 +1038,138 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
         if(buffer)
         {
           /* store the compressed video frame */
-          if (gap_debug) printf("GAP_AVI: Writing frame nr. %d, size %d\n",
-                        	(int)l_cur_frame_nr, (int)l_FRAME_size);
+          if (gap_debug)
+          {
+            printf("GAP_AVI: Writing frame nr. %d, size %d  l_keyframe:%d\n"
+                 , (int)l_cur_frame_nr
+                 , (int)l_FRAME_size
+                 , (int)l_keyframe
+                 );
+          }
           AVI_write_frame(l_avifile, buffer, l_FRAME_size, l_keyframe);
           /* free the (un)compressed Frame data buffer */
           g_free(buffer);
         }
-	else
-	{
-	  /* the CODEC delivered a NULL buffer
-	   * there is something essential wrong (TERMINATE)
-	   */
-	  g_message(_("ERROR: GAP AVI encoder CODEC %s delivered empty buffer at frame %d")
-	           , epp->codec_name
-		   , (int)l_cur_frame_nr
-		   );
-	  l_rc = -1;
-	}
+        else
+        {
+          /* the CODEC delivered a NULL buffer
+           * there is something essential wrong (TERMINATE)
+           */
+          g_message(_("ERROR: GAP AVI encoder CODEC %s delivered empty buffer at frame %d")
+                   , epp->codec_name
+                   , (int)l_cur_frame_nr
+                   );
+          l_rc = -1;
+        }
 
+        gimp_drawable_detach (l_drawable);
         /* destroy the tmp image */
         gimp_image_delete(l_tmp_image_id);
       }
-
-      /* encode AUDIO PART */
-      /* As long as there is a video frame, "fill" the fake audio buffer */
-      if (l_fp_inwav)
-      {
-        audio_filled_100 += audio_per_frame_x100;
-      }
-
-      /* Now "empty" the fake audio buffer, until it goes under the margin again */
-      while ((audio_filled_100 >= (audio_margin * 100)) && (wavsize > 0))
-      {
-        if (gap_debug) printf("Audio processing: Audio buffer at %ld bytes.\n", audio_filled_100);
-        if (wavsize >= audio_margin)
-        {
-            datasize = fread(databuffer, 1, audio_margin, l_fp_inwav);
-            if (datasize != audio_margin)
-            {
-              printf("Warning: Read from wav file failed. (non-critical)\n");
-            }
-            wavsize -= audio_margin;
-        }
-        else
-        {
-            datasize = fread(databuffer, 1, wavsize, l_fp_inwav);
-            if (datasize != wavsize)
-            {
-              printf("Warning: Read from wav file failed. (non-critical)\n");
-            }
-            wavsize = 0;
-        }
-
-        if (gap_debug) printf("Now saving audio frame datasize:%d\n", (int)datasize);
-
-        /*XXX ?? - TODO check if write in portions or all at once */
-        /* XX     - check if we should use write or append Procedure ? */
-
-        AVI_write_audio(l_avifile, databuffer, datasize);
-        /*AVI_append_audio(l_avifile, databuffer, datasize);*/
-
-        audio_filled_100 -= audio_margin * 100;
-      }
+      
+      
     }     /* end if l_rc == 0 */
 
 
+
+
+
+
+      /* encode AUDIO PART */
+      /* As long as there is a video frame, write audio chunks.
+       * set AUDIO_CHUNK_ADVANCE_FRAMES = 1 triggers writing of an audio chunk for each handled frame.
+       * values > 1 do write one longer audio chunk in advance for duration of the defined number of frames,
+       * in this case the next audio chunk is written after the number of video frames reached.
+       * in case the audio input is shorter than video playtime write the rest
+       * and stop writing audio for all further frame.
+       * in case the audio input is longer than video playtime it is truncated.
+       * (e.g. the remaining audio is not written to the resulting video file).
+       */
+      if ((l_fp_inwav) && (wavsize > 0))
+      {
+        gint32 datasize;
+        gint32 l_frames_advance;
+        
+        
+        l_frames_advance = MIN(AUDIO_CHUNK_ADVANCE_FRAMES, l_frames_to_go);
+        audio_margin = MIN((audio_bytes_per_frame_gint32 * l_frames_advance), sizeof(databuffer) -1);
+        
+        if(gap_debug)
+        {
+          printf("audio_bytes_per_frame:%d  audio_margin: %d (to_go:%d advance:%d)\n"
+             , (int)audio_bytes_per_frame_gint32
+             , (int)audio_margin
+             , (int)l_frames_to_go
+             , (int)l_frames_advance
+             );
+        }
+
+        datasize = 0;
+        if (audio_bytes_done_in_advance <= 0)
+        {
+          if (wavsize >= audio_margin)
+          {
+              datasize = fread(databuffer, 1, audio_margin, l_fp_inwav);
+              if (datasize != audio_margin)
+              {
+                printf("Warning: Read %d bytes from wav file failed. (got %d bytes)\n"
+                      ,(int)audio_margin
+                      ,(int)datasize
+                      );
+              }
+              wavsize -= audio_margin;
+          }
+          else
+          {
+              datasize = fread(databuffer, 1, wavsize, l_fp_inwav);
+              if (datasize != wavsize)
+              {
+                printf("Warning: Read rest of %d bytes from wav file failed. (got %d bytes)\n"
+                      ,(int)wavsize
+                      ,(int)datasize
+                      );
+              }
+              wavsize = 0;
+          }
+        }
+        if (datasize > 0)
+        {
+          if(gap_debug)
+          {
+            printf("Now saving audio frame datasize:%d\n", (int)datasize);
+          }
+          AVI_write_audio(l_avifile, databuffer, datasize);
+
+          if(gap_debug)
+          {
+            printf("audio chunk written\n");
+          }
+          audio_bytes_done_in_advance = datasize;
+        }
+        audio_bytes_done_in_advance -= audio_bytes_per_frame_gint32;
+      }
+
+
+
+
     l_percentage += l_percentage_step;
-    if(gap_debug) printf("PROGRESS: %f\n", (float) l_percentage);
+    if(gap_debug)
+    {
+      printf("PROGRESS: %f\n", (float) l_percentage);
+    }
     if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
     {
-      gimp_progress_update (l_percentage);
+      encStatus.frames_processed++;
+      encStatus.frames_encoded = l_cnt_encoded_frames;
+      encStatus.frames_copied_lossless = l_cnt_reused_frames;
+
+      gap_gve_misc_do_master_encoder_progress(&encStatus);
+    }
+
+    /* terminate on cancel reqeuset (CANCEL button was pressed in the master encoder dialog) */
+    if(gap_gve_misc_is_master_encoder_cancel_request(&encStatus))
+    {
+       break;
     }
 
     /* advance to next frame */
@@ -1244,9 +1178,12 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
        break;
     }
     l_cur_frame_nr += l_step;
+    l_frames_to_go--;
 
   }  /* end loop foreach frame */
 
+
+
   if(l_avifile != NULL)
   {
     AVI_close(l_avifile);
@@ -1270,5 +1207,13 @@ p_avi_encode(GapGveAviGlobalParams *gpp)
     gap_gve_story_close_vid_handle(l_vidhand);
   }
 
+  /* statistics */
+  if(gap_debug)
+  {
+    printf("encoded       frames: %d\n", (int)l_cnt_encoded_frames);
+    printf("1:1 copied    frames: %d\n", (int)l_cnt_reused_frames);
+    printf("total handled frames: %d\n", (int)l_cnt_encoded_frames + l_cnt_reused_frames);
+  }
+  g_free(l_video_chunk_ptr);
   return l_rc;
 }    /* end p_avi_encode */
